{##
  This file contains a Jinja2 front-matter template that adds version and authorship information.
  Changing the Jinja2 templates in this file may cause incompatibility with Manubot updates.
  Pandoc automatically inserts title from metadata.yaml, so it is not included in this template.
##}

{## Uncomment & edit the following line to reference to a preprinted or published version of the manuscript.
_A DOI-citable version of this manuscript is available at <https://doi.org/DOI_HERE>_.
##}

{## Template to insert build date, source, and cross-references to merged or individual reviews ##}
<small><em>
This manuscript
{% if manubot.ci_source is defined and manubot.ci_source.provider == "appveyor" -%}
([permalink]({{manubot.ci_source.artifact_url}}))
{% elif manubot.html_url_versioned is defined -%}
([permalink]({{manubot.html_url_versioned}}))
{% endif -%}
was automatically generated
{% if manubot.ci_source is defined -%}
from [{{manubot.ci_source.repo_slug}}@{{manubot.ci_source.commit | truncate(length=7, end='', leeway=0)}}](https://github.com/{{manubot.ci_source.repo_slug}}/tree/{{manubot.ci_source.commit}})
{% endif -%}
on {{manubot.generated_date_long}}.
{% if manubot.pdf_url_versioned is defined -%}
It is also available as a [PDF]({{manubot.pdf_url_versioned}}).
{% endif -%}
{% if individual is defined -%}
It represents one section of a larger evolving review on SARS-CoV-2 and COVID-19 available at <https://greenelab.github.io/covid19-review/>
{% else -%}
Snapshots of individual sections have been published [@individual-pathogenesis; @individual-nutraceuticals; @individual-pharmaceuticals; @individual-methods] or posted as preprints [@individual-diagnostics; @individual-vaccines-traditional; @individual-vaccines-novel].
{% endif -%}
</em></small>

{##
{% if manubot.date_long != manubot.generated_date_long -%}
Published: {{manubot.date_long}}
{% endif %}
##}

<!-- include the Font Awesome library, per: https://fontawesome.com/start -->
<link rel="stylesheet" href="https://use.fontawesome.com/releases/v5.13.0/css/all.css">
[
[]{.fas .fa-info-circle .fa-lg} **This in progress manuscript is not intended for the general public.**<br>
This is a review paper that is authored by scientists for an audience of scientists to discuss research that is in progress.
If you are interested in guidelines on testing, therapies, or other issues related to your health, you should not use this document.
Instead, you should collect information from your local health department, the [CDC's guidance](https://www.cdc.gov/coronavirus/2019-ncov/index.html), or your own government.
]{.banner .lightred}

## Authors {.unnumbered}

{## Template for listing authors, simplified for the individual manuscripts ##}
{% for author in manubot.authors %}
+ **{{author.name}}**<br>
  {%- if author.orcid is defined and author.orcid is not none %}
    {%- if individual is not defined %} ![ORCID icon](images/orcid.svg){.inline_icon width=16 height=16} {%- endif %}
    [{{author.orcid}}](https://orcid.org/{{author.orcid}})
  {%- endif %}
  {%- if author.github is defined and author.github is not none %}
    {%- if individual is not defined %} · ![GitHub icon](images/github.svg){.inline_icon width=16 height=16} {%- endif %}
    [{{author.github}}](https://github.com/{{author.github}})
  {%- endif %}
  {%- if author.twitter is defined and author.twitter is not none %}
    {%- if individual is not defined %} · ![Twitter icon](images/twitter.svg){.inline_icon width=16 height=16} {%- endif %}
    [{{author.twitter}}](https://twitter.com/{{author.twitter}})
  {%- endif %}<br>
  <small>
  {%- if author.affiliations is defined and author.affiliations|length %}
     {{author.affiliations | join('; ')}}
  {%- endif %}
  {%- if author.funders is defined and author.funders|length %}
     · Funded by {{author.funders | join('; ')}}
  {%- endif %}
  </small>
{% endfor %}

{## Template for listing consortium members ##}
**COVID-19 Review Consortium:**
{% for member in consortiummembers %}{{ member }}{% if not loop.last %}, {% endif %}{% endfor %}

{## Author order note ##}
{%- if individual is defined %}
Authors with similar contributions are ordered alphabetically.
{% else %}
Authors are ordered arbitrarily.
{%- endif %}
