## Pathogenesis, Symptomatology, and Transmission of SARS-CoV-2 through Analysis of Viral Genomics and Structure

### Abstract

The novel coronavirus SARS-CoV-2, which emerged in late 2019, has since spread around the world and infected hundreds of millions of people with coronavirus disease 2019 (COVID-19).
While this viral species was unknown prior to January 2020, its similarity to other coronaviruses that infect humans has allowed for rapid insight into the mechanisms that it uses to infect human hosts, as well as the ways in which the human immune system can respond.
Here, we contextualize SARS-CoV-2 among other coronaviruses and identify what is known and what can be inferred about its behavior once inside a human host.
Because the genomic content of coronaviruses, which specifies the virus's structure, is highly conserved, early genomic analysis provided a significant head start in predicting viral pathogenesis and in understanding potential differences among variants.
The pathogenesis of the virus offers insights into symptomatology, transmission, and individual susceptibility.
Additionally, prior research into interactions between the human immune system and coronaviruses has identified how these viruses can evade the immune system's protective mechanisms.
We also explore systems-level research into the regulatory and proteomic effects of SARS-CoV-2 infection and the immune response.
Understanding the structure and behavior of the virus serves to contextualize the many facets of the COVID-19 pandemic and can influence efforts to control the virus and treat the disease.

### Importance

COVID-19 involves a number of organ systems and can present with a wide range of symptoms.
From how the virus infects cells to how it spreads between people, the available research suggests that these patterns are very similar to those seen in the closely related viruses SARS-CoV-1 and possibly MERS-CoV.
Understanding the pathogenesis of the SARS-CoV-2 virus also contextualizes how the different biological systems affected by COVID-19 connect.
Exploring the structure, phylogeny, and pathogenesis of the virus therefore helps to guide interpretation of the broader impacts of the virus on the human body and on human populations.
For this reason, an in-depth exploration of viral mechanisms is critical to a robust understanding of SARS-CoV-2 and, potentially, future emergent HCoV.

### Introduction

The current coronavirus disease 2019 (COVID-19) pandemic, caused by the _Severe acute respiratory syndrome-related coronavirus 2_ (SARS-CoV-2) virus, represents an acute global health crisis.
Symptoms of the disease can range from mild to severe or fatal [@url:https://www.cdc.gov/coronavirus/2019-ncov/symptoms-testing/symptoms.html] and can affect a variety of organs and systems [@doi:10.23750/abm.v91i1.9397].
Outcomes of infection can include acute respiratory distress (ARDS) and acute lung injury, as well as damage to other organ systems [@doi:10.23750/abm.v91i1.9397; @doi:10.1002/ctm2.16].
Understanding the progression of the disease, including these diverse symptoms, depends on understanding how the virus interacts with the host.
Additionally, the fundamental biology of the virus can provide insights into how it is transmitted among people, which can, in turn, inform efforts to control its spread.
As a result, a thorough understanding of the pathogenesis of SARS-CoV-2 is a critical foundation on which to build an understanding of COVID-19 and the pandemic as a whole.

The rapid identification and release of the genomic sequence of the virus in January 2020 [@doi:10.46234/ccdcw2020.017] provided early insight into the virus in a comparative genomic context.
The viral genomic sequence clusters with known coronaviruses (order *Nidovirales*, family *Coronaviridae*, subfamily *Orthocoronavirinae*).
Phylogenetic analysis of the coronaviruses reveals four major subclades, each corresponding to a genus: the alpha, beta, gamma, and delta coronaviruses.
Among them, alpha and beta coronaviruses infect mammalian species, gamma coronaviruses infect avian species, and delta coronaviruses infect both mammalian and avian species [@doi:10.1146/annurev-virology-110615-042301].
The novel virus now known as SARS-CoV-2 was identified as a beta coronavirus belonging to the B lineage based on phylogenetic analysis of a polymerase chain reaction (PCR) amplicon fragment from five patients along with the full genomic sequence [@doi:10/ggjs7j].
This lineage also includes the _Severe acute respiratory syndrome-related coronavirus_ (SARS-CoV-1) that caused the 2002-2003 outbreak of Severe Acute Respiratory Syndrome (SARS) in humans [@doi:10/ggjs7j].
(Note that these subclades are not to be confused with variants of concern within SARS-CoV-2 labeled with Greek letters; i.e., the Delta variant of SARS-CoV-2 is still a beta coronavirus.)

Because viral structure and mechanisms of pathogenicity are highly conserved within the order, this phylogenetic analysis provided a basis for forming hypotheses about how the virus interacts with hosts, including which tissues, organs, and systems would be most susceptible to SARS-CoV-2 infection.
Coronaviruses that infect humans (HCoV) are not common, but prior research into other HCoV such as SARS-CoV-1 and _Middle East respiratory syndrome-related coronavirus_ (MERS-CoV), as well as other viruses infecting humans such as a variety of influenza species, established a strong foundation that accelerated the pace of SARS-CoV-2 research.

Coronaviruses are large viruses that can be identified by their distinctive "crown-like" shape (Figure @fig:genome-structure).
Their spherical virions are made from lipid envelopes ranging from 100 to 160 nanometers in which peplomers (protruding structures) of two to three spike (S) glycoproteins are anchored, creating the crown [@isbn:978-0781760607; @doi:10/dvvg2h].
These spikes, which are critical to both viral pathogenesis and to the response by the host immune response, have been visualized using cryo-electron microscopy [@doi:10.1126/science.abb2507].
Because they induce the human immune response, they are also the target of many proposed therapeutic agents [@individual-pharmaceuticals; @individual-nutraceuticals].
Viral pathogenesis is typically broken down into three major components: entry, replication, and spread [@isbn:0-9631172-1-1 {chap. 45}].
However, in order to draw a more complete picture of pathogenesis, it is also necessary to examine how infection manifests clinically, identify systems-level interactions between the virus and the human body, and consider the possible effects of variation or evolutionary change on pathogenesis and virulence.
Thus, clinical medicine and traditional biology are both important pieces of the puzzle of SARS-CoV-2 presentation and pathogenesis.

### Coronavirus Structure and Pathogenesis

#### Structure of Coronaviruses

Genome structure is highly conserved among coronaviruses, meaning that the relationship between the SARS-CoV-2 genome and its pathogenesis can be inferred from prior research in related viral species.
The genomes of viruses in the *Nidovirales* order share several fundamental characteristics.
They are non-segmented, which means the viral genome is a single continuous strand of RNA, and are enveloped, which means that the genome and capsid are encased by a lipid bilayer.
Coronaviruses have large positive-sense RNA (ssRNA+) genomes ranging from 27 to 32 kilobases in length [@doi:10.1007/978-1-4939-2438-7_1; @doi:10/ggjr43].
The SARS-CoV-2 genome lies in the middle of this range at 29,903 bp [@doi:10/ggjr43].
Genome organization is highly conserved within the order [@doi:10.1007/978-1-4939-2438-7_1].
There are three major genomic regions: one containing the replicase gene, one containing the genes encoding structural proteins, and interspersed accessory genes [@doi:10.1007/978-1-4939-2438-7_1] (Figure @fig:genome-structure).
The replicase gene comprises about two-thirds of the genome and consists of two open reading frames that are translated with ribosomal frameshifting [@doi:10.1007/978-1-4939-2438-7_1].
This polypeptide is then translated into 16 non-structural proteins (nsp), except in gammacoronaviruses where nsp1 is absent, that form the replication machinery used to synthesize viral RNA [@doi:10.1002/jmv.25681].
The remaining third of the genome encodes structural proteins, including the spike (S), membrane, envelope, and nucleocapsid proteins.
Additional accessory genes are sometimes present between these two regions, depending on the species or strain.
Much attention has been focused on the S protein, which is a critical structure involved in cell entry.

![**Structure of SARS-CoV-2 capsid and genome.**
A) The genomic structure of coronaviruses is highly conserved and includes three main regions.
Open reading frames (ORF) 1a and 1b contain two polyproteins that encode the non-structural proteins (nsp).
The nsp include enzymes such as RNA-dependent RNA Polymerase (RdRp).
The last third of the genome encodes structural proteins, including the spike (S), envelope (E), membrane (M) and nucleocapsid (N) proteins.
Accessory genes can also be interspersed throughout the genome [@doi:10.1007/978-1-4939-2438-7_1].
B) The physical structure of the coronavirus virion, including the components determined by the conserved structural proteins S, E, M and N.
This figure was adapted from “Human Coronavirus Structure”, by BioRender.com (2020), retrieved from https://app.biorender.com/biorender-templates.
](images/genome-structure.png){#fig:genome-structure secno=1}

#### Pathogenic Mechanisms of Coronaviruses

While it is possible that SARS-CoV-1 and SARS-CoV-2, like most viruses, enter cells through endocytosis, a process conserved among coronaviruses enables them to target cells for entry through fusion with the plasma membrane [@doi:10.1038/cr.2008.15; @doi:10.1146/annurev-biochem-060208-104626].
Cell entry proceeds in three steps: binding, cleavage, and fusion.
First, the viral spike protein binds to a host cell via a recognized receptor or entry point.
Coronaviruses can bind to a range of host receptors [@doi:10.3390/v4061011; @doi:10.1016/j.jmb.2020.04.009], with binding conserved only at the genus level [@doi:10.1146/annurev-virology-110615-042301].
Viruses in the beta coronavirus genus, to which SARS-CoV-2 belongs, are known to bind to the CEACAM1 protein, 5-N-acetyl-9-O-acetyl neuraminic acid, and to angiotensin-converting enzyme 2 (ACE2) [@doi:10.3390/v4061011].
This recognition is driven by domains in the S1 subunit [@doi:10.1016/j.cell.2020.02.058].
SARS-CoV-2 has a high affinity for human ACE2, which is expressed in the vascular epithelium, other epithelial cells, and cardiovascular and renal tissues [@doi:10.1007/s00134-020-05985-9; @doi:10.1007/978-0-387-33012-9_85], as well as many others [@doi:10.15252/msb.20209610].
The binding process is guided by the molecular structure of the spike protein, which is structured in three segments: an ectodomain, a transmembrane anchor, and an intracellular tail [@doi:10.1128/JVI.02615-14].
The ectodomain forms the crown-like structures on the viral membrane and contains two subdomains known as the S1 and S2 subunits [@doi:10.1038/nrmicro2090].
The S1 (N-terminal) domain forms the head of the crown and contains the receptor binding motif, and the S2 (C-terminal) domain forms the stalk that supports the head [@doi:10.1038/nrmicro2090].
The S1 subunit guides the binding of the virus to the host cell, and the S2 subunit guides the fusion process [@doi:10.1128/JVI.02615-14].

After the binding of the S1 subunit to an entry point, the spike protein of coronaviruses is often cleaved at the S1/S2 boundary into the S1 and S2 subunits by a host protease [@doi:10.1016/j.cell.2020.02.058; @doi:10/cf8chz; @doi:10.1016/j.antiviral.2020.104792].
This proteolytic priming is important because it prepares the S protein for fusion [@doi:10/cf8chz; @doi:10.1016/j.antiviral.2020.104792].
The two subunits remain bound by van der Waals forces, with the S1 subunit stabilizing the S2 subunit throughout the membrane fusion process [@doi:10.1016/j.cell.2020.02.058].
Cleavage at a second site within S2 (S2') activates _S_ for fusion by inducing conformational changes [@doi:10.1016/j.cell.2020.02.058].
Similar to SARS-CoV-1, SARS-CoV-2 exhibits redundancy in which host proteases can cleave the S protein [@doi:10.1016/j.cell.2020.02.052].
Both transmembrane protease serine protease-2 (TMPRSS-2) and cathepsins B/L have been shown to mediate SARS-CoV-2 S protein proteolytic priming, and small molecule inhibition of these enzymes fully inhibited viral entry _in vitro_ [@doi:10.1016/j.cell.2020.02.052; @doi:10.1038/s41467-020-15562-9].
Other proteases known to cleave the S1/S2 boundary in coronaviruses include TMPRSS-4, trypsin, furin, cathepsins, and human airway trypsin-like protease (HAT) [@doi:10.1038/s41467-020-15562-9].

Unlike in SARS-CoV-1, a second cleavage site featuring a furin-like binding motif is also present near the S1/S2 boundary in SARS-CoV-2 [@doi:10.1016/j.antiviral.2020.104742].
This site is found in HCoV belonging to the A and C lineages of beta coronavirus, including MERS-CoV, but not in the other known members of the B lineage of beta coronavirus that contains SARS-CoV-1 and SARS-CoV-2 [@doi:10.1016/j.antiviral.2020.104742].
It is associated with increased virulence in other viral species [@doi:10.1016/j.antiviral.2020.104742] and may facilitate membrane fusion of SARS-CoV-2 in the absence of other proteases that prime the S1/S2 site [@doi:10.1038/s41392-020-0184-0].
However, given that proteases such as HAT are likely to be present in targets like the human airway, the extent to which this site has had a real-world effect on the spread of SARS-CoV-2 was initially unclear [@doi:10.1038/s41392-020-0184-0].
Subsequent research has supported this site as an important contributor to pathogenesis: _in vitro_ analyses have reported that it bolsters pathogenicity specifically in cell lines derived from human airway cells (Calu3 cell line) [@doi:10.1101/2020.08.26.268854; @doi:10.1038/s41586-021-03237-4; @doi:10.1038/s41564-021-00908-w] and that furin inhibitors reduced pathogenic effects in VeroE6 cells [@doi:10.1016/j.celrep.2020.108254].

Electron microscopy suggests that in some coronaviruses, including SARS-CoV-1 and MERS-CoV, a six-helix bundle separates the two subunits in the postfusion conformation, and the unusual length of this bundle facilitates membrane fusion through the release of additional energy [@doi:10.1146/annurev-virology-110615-042301].
The viral membrane can then fuse with the endosomal membrane to release the viral genome into the host cytoplasm.
Once the virus enters a host cell, the replicase gene is translated and assembled into the viral replicase complex.
This complex then synthesizes the double-stranded RNA (dsRNA) genome from the genomic ssRNA(+).
The dsRNA genome is transcribed and replicated to create viral mRNAs and new ssRNA(+) genomes [@doi:10.1007/978-1-4939-2438-7_1; @url:https://viralzone.expasy.org/30].
From there, the virus can spread into other cells.
In SARS-CoV-2, the insertion of the furin-like binding site near the S1/S2 boundary is also thought to increase cell-cell adhesion, making it possible for the viral genome to spread directly from cell to cell rather than needing to propagate the virion itself [@doi:10.1016/j.isci.2020.101212].
In this way, the genome of SARS-CoV-2 provides insight into the pathogenic behavior of the virus.

Evidence also suggests that SARS-CoV-2 may take advantage of the specific structure of endothelial cells to enter the circulatory system.
Endothelial cells are specialized epithelial cells [@doi:10.1055/s-0030-1253446] that form a barrier between the bloodstream and surrounding tissues.
The endothelium facilitates nutrient, oxygen, and cellular exchange between the blood and vascularized tissues [@pubmed:362947].
The luminal (interior) surface of the endothelium is lined with glycocalyx, a network of both membrane-bound and soluble proteins and carbohydrates, primarily proteoglycans and glycoproteins [@doi:10.1007/s00424-007-0212-8; @doi:10.1016/j.cell.2020.09.033].
The glycocalyx varies in thickness from 0.5 microns in the capillaries to 4.5 microns in the carotid arteries and forms a meshwork that localizes both endothelial- and plasma-derived signals to the inner vessel wall [@doi:10.1007/s00424-007-0212-8].
Heparan sulfate is the dominant proteoglycan in the glycocalyx, representing 50-90% of glycocalyx proteoglycan content [@doi:10/bp82dx].
The SARS-CoV-2 spike protein can bind directly to heparan sulfate, which serves in part as a scaffolding molecule to facilitate ACE2 binding and entry into endothelial cells [@doi:10.1016/j.cell.2020.09.033].
A heparan sulfate binding site has also been identified near the ACE2 binding site on the viral receptor binding domain (RBD), and modeling has suggested that heparan sulfate binding yields an open conformation that facilitates binding to ACE2 on the cell surface [@doi:10.1016/j.cell.2020.09.033].
Degrading or removing heparan sulfate was associated with decreased binding [@doi:10.1016/j.cell.2020.09.033].
Heparan sulfate may also interact with the S1/S2 proteolytic cleavage site and other binding sites to promote binding affinity [@doi:10.1101/2020.05.10.087288].
Notably, treatment with soluble heparan sulfate or even heparin (a commonly used anti-coagulant and vasodilator that is similar in structure to heparan sulfate [@doi:10.1007/978-3-642-23056-1_8]) potently blocked spike protein binding and viral infection [@doi:10.1016/j.cell.2020.09.033].
This finding is particularly interesting because degradation of heparan sulfate in the glycocalyx has previously been identified as an important contributor to ARDS and sepsis [@doi:10.1016/bs.ctm.2018.08.005], two common and severe outcomes of COVID-19, and suggests that heparan sulfate could be a target for pharmaceutical inhibition of cell entry by SARS-CoV-2 [@doi:10.1038/s41421-020-00222-5; @doi:10.1016/j.ebiom.2020.102969; @doi:10.1016/j.amjcard.2020.08.005; @doi:10.3390/nu13020328; @doi:10.3389/fimmu.2021.607306].
Together, this evidence suggests that heparan sulfate can serve as an important adhesion molecule for SARS-CoV-2 cell entry.
It may represent a therapeutic target but has not been pursued as much as other candidate targets [@individual-pharmaceuticals].

#### Immune Evasion Strategies

Research in other HCoV provides some indication of how SARS-CoV-2 infection can proceed despite human immune defenses.
Infecting the epithelium can help viruses such as SARS-CoV-1 bypass the physical barriers, such as mucus, that comprise the immune system's first line of defense [@doi:10.1038/mi.2015.127].
Once the virus infiltrates host cells, it is adept at evading detection.
CD163+ and CD68+ macrophage cells are especially crucial for the establishment of SARS-CoV-1 in the body [@doi:10.1038/mi.2015.127].
These cells most likely serve as viral reservoirs that help shield SARS-CoV-1 from the innate immune response.
According to a study on the viral dissemination of SARS-CoV-1 in Chinese macaques, viral RNA could be detected in some monocytes throughout the process of differentiation into dendritic cells [@doi:10.1038/mi.2015.127].
This lack of active viral replication allows SARS-CoV-1 to escape the innate immune response because reduced levels of detectable viral RNA allow the virus to avoid both natural killer cells and Toll-like receptors [@doi:10.1038/mi.2015.127].
Even during replication, SARS-CoV-1 is able to mask its dsRNA genome from detection by the immune system.
Although dsRNA is a pathogen-associated molecular pattern that would typically initiate a response from the innate immune system [@doi:10.3389/fimmu.2018.00829], _in vitro_ analysis of nidoviruses including SARS-CoV-1 suggests that these viruses can induce the development of double-membrane vesicles that protect the dsRNA signature from being detected by the host immune system [@doi:10.1128/jvi.02501-05].
This protective envelope can therefore insulate these coronaviruses from the innate immune system's detection mechanism [@doi:10.1016/j.jpha.2020.03.001].

HCoVs are also known to interfere with the host immune response, rather than just evade it.
For example, the virulence of SARS-CoV-2 is increased by nsp1, which can suppress host gene expression by stalling mRNA translation and inducing endonucleolytic cleavage and mRNA degradation [@doi:10.1126/science.abc8665].
SARS-CoV-1 also evades the immune response by interfering with type I IFN induction signaling, which is a mechanism that leads to cellular resistance to viral infections.
SARS-CoV-1 employs methods such as ubiquitination and degradation of RNA sensor adaptor molecules MAVS and TRAF3/6 [@doi:10.12932/AP-200220-0772].
Also, MERS-CoV downregulates antigen presentation via MHC class I and MHC class II, which leads to a reduction in T cell activation [@doi:10.12932/AP-200220-0772].
These evasion mechanisms, in turn, may facilitate systemic infection.
Coronaviruses such as SARS-CoV-1 are also able to evade the humoral immune response through other mechanisms, such as inhibiting certain cytokine pathways or down-regulating antigen presentation by the cells [@doi:10.1128/jvi.02501-05].

#### Host Cell Susceptibility

ACE2 and TMPRSS-2 have been identified as the primary entry portal and as a critical protease, respectively, in facilitating the entry of SARS-CoV-1 and SARS-CoV-2 into a target cell [@doi:10.1038/nature02145; @doi:10.1126/science.abb2507; @doi:10.1128/JVI.01542-10; @doi:10.1016/j.cell.2020.02.052; @doi:10.1128/JVI.02232-10].
This finding has led to a hypothesized role for the expression of these molecules in determining which cells, tissues, and organs are most susceptible to SARS-CoV-2 infection.
ACE2 is expressed in numerous organs, such as the heart, kidney, and intestine, but it is most prominently expressed in alveolar epithelial cells; this pattern of expression is expected to contribute to the virus' association with lung pathology [@doi:10.1002/jmv.26139; @doi:10.1007/s00134-020-05985-9; @doi:10.1016/j.phrs.2020.104833] as well as that of SARS [@doi:10.1002/path.1570].
A retrospective observational study reported indirect evidence that certain antineoplastic therapies, such as the chemotherapy drug gemcitabine, may reduce risk of SARS-CoV-2 infection in patients with cancer, possibly via decreased ACE2 expression [@doi:10.1001/jamaoncol.2021.3585].
Additionally, the addition of the furin site insertion at the S1/S2 boundary means that SARS-CoV-2 does not require TMPRSS-2 when furin, an ubiquitously expressed endoprotease [@doi:10.1038/nrm934], is present, enabling cell-cell fusion independent of TMPRSS-2 availability [@doi:10.1016/j.molcel.2020.04.022].

Clinical investigations of COVID-19 patients have detected SARS-CoV-2 transcripts in bronchoalveolar lavage fluid (BALF) (93% of specimens), sputum (72%), nasal swabs (63%), fibrobronchoscopy brush biopsies (46%), pharyngeal swabs (32%), feces (29%), and blood (1%) [@doi:10.1001/jama.2020.3786].
Two studies reported that SARS-CoV-2 could not be detected in urine specimens [@doi:10.1001/jama.2020.3786; @doi:10.1001/jama.2020.3204]; however, a third study identified four urine samples (out of 58) that were positive for SARS-CoV-2 nucleic acids [@doi:10.1097/CM9.0000000000000774].
Although respiratory failure remains the leading cause of death for COVID-19 patients [@doi:10.1111/his.14134], SARS-CoV-2 infection can damage many other organ systems including the heart [@doi:10.1001/jamacardio.2020.0950], kidneys [@doi:10.1038/s41585-020-0319-7; @doi:10.1186/s13054-020-02872-z], liver [@doi:10/ggpx6s], and gastrointestinal tract [@doi:10.1053/j.gastro.2020.02.055; @doi:10.1111/1751-2980.12851].
As it becomes clear that SARS-CoV-2 infection can damage multiple organs, the scientific community is pursuing multiple avenues of investigation in order to build a consensus about how the virus affects the human body.

### Clinical Presentation of COVID-19

SARS-CoV-2 pathogenesis is closely linked with the clinical presentation of the COVID-19 disease.
Reports have described diverse symptom profiles associated with COVID-19, with a great deal of variability both within and between institutions and regions.
Definitions for non-severe, severe, and critical COVID-19, along with treatment recommendations, are available from the World Health Organization living guidelines [@doi:10.1136/bmj.m3379].
A large study from Wuhan, China conducted early in the pandemic identified fever and cough as the two most common symptoms that patients reported at hospital admission [@doi:10.1056/NEJMoa2002032], while a retrospective study in China described the clinical presentations of patients infected with SARS-CoV-2 as including lower respiratory tract infection with fever, dry cough, and dyspnea (shortness of breath) [@doi:10/ggnxb3].
This study [@doi:10/ggnxb3] noted that upper respiratory tract symptoms were less common, suggesting that the virus preferentially targets cells located in the lower respiratory tract.
However, data from the New York City region [@doi:10.1001/jama.2020.6775; @doi:10.1056/NEJMc2010419] showed variable rates of fever as a presenting symptom, suggesting that symptoms may not be consistent across individuals.
For example, even within New York City, one study [@doi:10.1001/jama.2020.6775] identified low oxygen saturation (<90% without the use of supplemental oxygen or ventilation support) in 20.4% of patients upon presentation, with fever being present in 30.7%, while another study [@doi:10.1056/NEJMc2010419] reported cough (79.4%), fever (77.1%), and dyspnea (56.5%) as the most common presenting symptoms; both of these studies considered only hospitalized patients.
A later study reported radiographic findings such as ground-glass opacity and bilateral patchy shadowing in the lungs of many hospitalized patients, with most COVID-19 patients having lymphocytopenia, or low levels of lymphocytes (a type of white blood cell) [@doi:10.1056/NEJMoa2002032].
Patients may also experience loss of smell, myalgias (muscle aches), fatigue, or headache.
Gastrointestinal symptoms can also present [@doi:10.15585/mmwr.mm6928a2], and the CDC includes nausea and vomiting, as well as congestion and runny nose, on its list of symptoms consistent with COVID-19 [@url:https://www.cdc.gov/coronavirus/2019-ncov/symptoms-testing/symptoms.html].
An analysis of an app-based survey of 500,000 individuals in the U.S. found that among those tested for SARS-CoV-2, a loss of taste or smell, fever, and a cough were significant predictors of a positive test result [@doi:10.1038/s41562-020-00944-2].
It is important to note that in this study, the predictive value of symptoms may be underestimated if they are not specific to COVID-19.
This underestimation could occur because the outcome measured was a positive, as opposed to a negative, COVID-19 test result, meaning an association would be more easily identified for symptoms that were primarily or exclusively found with COVID-19.
At the time the surveys were conducted, due to limits in U.S. testing infrastructure, respondents typically needed to have some symptoms known to be specific to COVID-19 in order to qualify for testing.
Widespread testing of asymptomatic individuals may therefore provide additional insight into the range of symptoms associated with COVID-19.

Consistent with the wide range of symptoms observed and the pathogenic mechanisms described above, COVID-19 can affect a variety of systems within the body in addition to causing respiratory problems [@doi:10.1038/s41591-020-0968-3].
For example, COVID-19 can lead to acute kidney injury, especially in patients with severe respiratory symptoms or certain preexisting conditions [@doi:10.1016/j.kint.2020.05.006].
Some patients are at risk for collapsing glomerulopathy [@doi:10.1038/s41581-020-0332-3].

COVID-19 can also cause neurological complications [@doi:10.1016/j.bbi.2020.03.031; @doi:10/d259; @doi:10.1001/jamapsychiatry.2021.0500], potentially including stroke, seizures or meningitis [@doi:10.1002/jmv.26000; @doi:10.1002/ana.25807].
One study on autopsy samples suggested that SARS-CoV-2 may be able to enter the central nervous system via the neural–mucosal interface [@doi:10.1038/s41593-020-00758-5].
However, a study of 41 autopsied brains [@doi:10.1093/brain/awab148] found no evidence that the virus can actually infect the central nervous system.
Although there was viral RNA in some brain samples, it was only found in very small amounts, and no viral protein was found.
The RNA may have been in the blood vessels or blood components and not in the brain tissue itself.
Instead, the neuropathological effects of COVID-19 are more likely to be caused indirectly by hypoxia, coagulopathy, or inflammatory processes rather than by infection in the brain [@doi:10.1093/brain/awab148].
COVID-19 has been associated with an increased incidence of large vessel stroke, particularly in patients under the age of 40 [@doi:10.1056/NEJMc2009787], and other thrombotic events including pulmonary embolism and deep vein thrombosis [@doi:10.1016/j.thromres.2020.04.013].
The mechanism behind these complications has been suggested to be related to coagulopathy, with reports indicating the presence of antiphospholipid antibodies [@doi:10.1056/NEJMc2007575] and elevated levels of d-dimer and fibrinogen degradation products in deceased patients [@doi:10.1111/jth.14768].
Other viral infections have been associated with coagulation defects and changes to the coagulation cascade; notably, SARS was also found to lead to disseminated intravascular coagulation and was associated with both pulmonary embolism and deep vein thrombosis [@doi:10.1002/jmv.23354].
The mechanism behind these insults has been suggested to be related to inflammation-induced increases in the von Willebrand factor clotting protein, leading to a pro-coagulative state [@doi:10.1002/jmv.23354].
Abnormal clotting (thromboinflammation or coagulopathy) has been increasingly discussed recently as a possible key mechanism in many cases of severe COVID-19, and may be associated with the high d-dimer levels often observed in severe cases [@doi:10/ggvd74; @doi:10.1186/s13054-020-03060-9; @doi:10.1007/s11239-020-02134-3].
This excessive clotting in lung capillaries has been suggested to be related to a dysregulated activation of the complement system, part of the innate immune system [@doi:10.1172/jci.insight.140711; @doi:10.1172/JCI140183].

Finally, concerns have been raised about long-term sequelae of COVID-19.
Some COVID-19 patients have reported that various somatic symptoms (such as shortness of breath, fatigue, chest pain) and psychological (depression, anxiety or mild cognitive impairment) symptoms can last for months after infection [@doi:10.1038/s41591-021-01283-z].
Such long-term affects occur both in adults [@doi:10.1007/s11606-021-07032-9] and children [@doi:10.1111/apa.15870].
Sustained symptoms affecting a variety of biological systems have been reported across many studies (e.g., [@doi:10.1038/s41591-021-01283-z; @doi:10.1016/j.eclinm.2021.101019; @doi:10/ghstsk]).
The phenomenon of "long COVID" is not fully understood although various possible explanations have been proposed, including damage caused by immune response to infection as well as by the infection itself, in addition to negative consequences of the experience of lengthy illness and hospitalization.
However, a lack of consistency among definitions used in different studies makes it difficult to develop precise definitions or identify specific symptoms associated with long-term effects of COVID-19 [@doi:10.1101/2021.03.20.21253896; @doi:10.1101/2021.06.23.21259416].
Patient and family support groups for "long haulers" have been formed online, and patient-driven efforts to collect data about post-acute COVID-19 provide valuable sources of information (e.g., [@doi:10.1016/j.eclinm.2021.101019]).
The specific relationship between viral pathogenesis and these reported sequelae remains to be uncovered, however.

#### Pediatric Presentation

The presentation of COVID-19 infection can vary greatly among pediatric patients and, in some cases, manifests in distinct ways from COVID-19 in adults.
Evidence suggests that children and adolescents tend to have mostly asymptomatic infections and that those who are symptomatic typically exhibit mild illness [@doi:10.1101/2020.06.25.20140178; @doi:10.1056/NEJMc2005073; @doi:10.1111/apa.15270; @doi:10.1126/science.abe5765].
One review examined symptoms reported in 17 studies of children infected with COVID-19 during the early months of the COVID-19 epidemic in China and one study from Singapore [@doi:10.1001/jamapediatrics.2020.1467].
In the more than a thousand cases described, the most common reports were for mild symptoms such as fever, dry cough, fatigue, nasal congestion and/or runny nose, while three children were reported to be asymptomatic.
Severe lower respiratory infection was described in only one of the pediatric cases reviewed.
Gastrointestinal symptoms such as vomiting or diarrhea were occasionally reported.
Radiologic findings were not always reported in the case studies reviewed, but when they were mentioned they included bronchial thickening, ground-glass opacities, and/or inflammatory lesions [@doi:10.1001/jamapediatrics.2020.1467].
Neurological symptoms have also been reported [@doi:10.1001/jamaneurol.2020.2687].

These analyses indicate that most pediatric cases of COVID-19 are not severe.
Indeed, it is estimated that less than 1% of pediatric cases result in critical illness [@doi:10.1056/NEJMc2007617; @doi:10.1111/apa.15270], although reporting suggests that pediatric hospitalizations may be greater with the emergence of the Delta variant of concern (VOC) [@url:https://covid.cdc.gov/covid-data-tracker; @doi:10.1136/bmj.n1513; @url:https://www.nytimes.com/2021/08/09/health/coronavirus-children-delta.html].
Serious complications and, in relatively rare cases, deaths have occurred [@doi:10.1016/j.eclinm.2020.100433].
Of particular interest, children have occasionally experienced a serious inflammatory syndrome, multisystem inflammatory syndrome in children (MIS-C), following COVID-19 infection [@doi:10.1111/apa.16051].
This syndrome is similar in some respects to Kawasaki disease, including Kawasaki disease shock syndrome [@doi:10.1093/jpids/piaa069; @doi:10.1001/jama.2020.10369; @doi:10.1016/j.ajem.2020.05.117], and is thought to be a distinct clinical manifestation of SARS-CoV-2 due to its distinct cytokine profile and the presence of burr cells in peripheral blood smears [@doi:10.1172/JCI140970; @doi:10.1016/j.cell.2020.09.016].
MIS-C has been associated with heart failure in some cases [@doi:10.1161/CIRCULATIONAHA.120.048360].
A small number of case studies have identified presentations similar to MIS-C in adults associated with SARS-CoV-2 [@doi:10/gg4sd6; @doi:10.1136/bcr-2021-243888; @doi:10.1016/j.ajem.2020.06.053; @doi:10.3389/fimmu.2021.680567].
However, not all cases of severe COVID-19 in children are characterizable as MIS-C.
A recent study [@doi:10.1001/jama.2021.2091] described demographic and clinical variables associated with MIS-C in comparison with non-MIS-C severe acute COVID-19 in young people in the United States.
Efforts to characterize long-term sequelae of SARS-CoV-2 infection in children face the same challenges as in adults, but long-term effects remain a concern in pediatric patients [@doi:10.1101/2021.01.23.21250375; @doi:10.1111/apa.15870; @doi:10.1002/ppul.25521], although some early studies have suggested that they may be less of a concern than in adults [@doi:10/gj9p7b; @doi:10.1101/2021.05.16.21257255; @doi:10.1001/jama.2021.11880].
Research is ongoing into the differences between the pediatric and adult immune responses to SARS-CoV-2, and future research may shed light on the factors that lead to MIS-C; it is also unknown whether the relative advantages of children against severe COVID-19 will remain in the face of current and future variants [@doi:10.1038/d41586-021-02423-8].

#### Cytokine Release Syndrome

The inflammatory response was identified early on as a potential driver of COVID-19 outcomes due to existing research in SARS and emerging research in COVID-19.
While too low of an inflammatory response is a concern because it will fail to eliminate the immune threat [@doi:10.1111/imr.12671], excessive pro-inflammatory cytokine activity can cascade [@doi:10.1159/000087104] and cause cell damage, among other problems [@doi:10.18632/oncotarget.23208].
A dysregulated immune response can cause significant damage to the host [@isbn:9780815332183; @isbn:9780071283663; @doi:10.1016/j.chom.2020.05.009] including pathogenesis associated with sepsis.
Sepsis, which can lead to multi-organ failure and death [@doi:10.1128/MMBR.05015-11; @pmid:22142805], is traditionally associated with bacterial infections.
However, sepsis associated with viral infections may be underidentified [@doi:10.1183/16000617.0038-2020], and sepsis has emerged as a major concern associated with SARS-CoV-2 infection [@doi:10/ggsps7].
Hyperactivity of the pro-inflammatory response due to lung infection is commonly associated with acute lung injury and more rarely with the more severe manifestation, ARDS, which can arise from pneumonia, SARS, and COVID-19 [@doi:10.1159/000087104; @doi:10.1128/MMBR.05015-11].
Damage to the capillary endothelium can cause leaks that disrupt the balance between pro-inflammatory cytokines and their regulators [@doi:10.1164/ajrccm.164.10.2104013], and heightened inflammation in the lungs can also serve as a source for systemic inflammation, or sepsis, and potentially multi-organ failure [@doi:10.1128/MMBR.05015-11].
The shift from local to systemic inflammation is a phenomenon often referred to broadly as a cytokine storm [@doi:10.1128/MMBR.05015-11] or, more precisely, as cytokine release syndrome [@doi:10.1186/s40425-018-0343-9].

Cytokine dysregulation is therefore a significant concern in the context of COVID-19.
In addition to the known role of cytokines in ARDS and lung infection more broadly, immunohistological analysis at autopsy of deceased SARS patients revealed that ACE2-expressing cells that were infected by SARS-CoV-1 showed elevated expression of the cytokines IL-6, IL-1&beta;, and TNF-&alpha; [@doi:10.1002/path.2067].
Similarly, the introduction of the S protein from SARS-CoV-1 to mouse macrophages was found to increase production of IL-6 and TNF-&alpha; [@doi:10.1016/j.virusres.2007.02.007].
For SARS-CoV-2 infection leading to COVID-19, early reports described a cytokine storm syndrome-like response in patients with particularly severe infections [@doi:10.1002/jmv.26139; @doi:10/ggnzmc; @doi:10.1016/j.immuni.2020.06.017].
Sepsis has been identified as a major contributor to COVID-19-related death.
Among patients hospitalized with COVID-19 in Wuhan, China, 112 out of 191 (59%) developed sepsis, including all 54 of the non-survivors [@doi:10/ggnxb3].

While IL-6 is sometimes used as a biomarker for cytokine storm activity in sepsis [@doi:10.1128/MMBR.05015-11], the relationship between cytokine profiles and the risks associated with sepsis may be more complex.
One study of patients with and at risk for ARDS, specifically those who were intubated for medical ventilation, found that shortly after the onset of ARDS, anti-inflammatory cytokine concentration in BALF increased relative to the concentration of pro-inflammatory cytokines [@doi:10.1164/ajrccm.164.10.2104013].
The results suggest that an increase in pro-inflammatory cytokines such as IL-6 may signal the onset of ARDS, but recovery depends on an increased anti-inflammatory response [@doi:10.1164/ajrccm.164.10.2104013].
However, patients with severe ARDS were excluded from this study.
Another analysis of over 1,400 pneumonia patients in the United States reported that IL-6, tumor necrosis factor (TNF), and IL-10 were elevated at intake in patients who developed severe sepsis and/or ultimately died [@doi:10.1001/archinte.167.15.1655].
However, unlike the study analyzing pro- and anti-inflammatory cytokines in ARDS patients [@doi:10.1164/ajrccm.164.10.2104013], this study reported that unbalanced pro-/anti-inflammatory cytokine profiles were rare.
This discrepancy could be related to the fact that the sepsis study measured only three cytokines.
Although IL-6 has traditionally been considered pro-inflammatory, its pleiotropic effects via both classical and trans-signaling allow it to play an integral role in both the inflammatory and anti-inflammatory responses [@doi:10.1016/j.bbamcr.2011.01.034], leading it to be associated with both healthy and pathological responses to viral threat [@doi:10.3389/fmicb.2019.01057].
While the cytokine levels observed in COVID-19 patients fall outside of the normal range, they are not as high as typically found in patients with ARDS [@doi:10.1001/jamainternmed.2020.3313].
Regardless of variation in the anti-inflammatory response, prior work has therefore made it clear that pulmonary infection and injury are associated with systemic inflammation and with sepsis.
Inflammation has received significant interest both in regards to the pathology of COVID-19 as well as potential avenues for treatment, as the relationship between the cytokine storm and the pathophysiology of COVID-19 has led to the suggestion that a number of immunomodulatory pharmaceutical interventions could hold therapeutic value for the treatment of COVID-19 [@doi:10.1016/j.jaut.2020.102452; @individual-pharmaceuticals].

### Insights from Systems Biology

Systems biology provides a cross-disciplinary analytical paradigm through which the host response to an infection can be analyzed.
This field integrates the "omics" fields (genomics, transcriptomics, proteomics, metabolomics, etc.) using bioinformatics and other computational approaches.
Over the last decade, systems biology approaches have been used widely to study the pathogenesis of diverse types of life-threatening acute and chronic infectious diseases [@doi:10.1038/s41576-020-0212-5].
Omics-based studies have also provided meaningful information regarding host immune responses and surrogate protein markers in several viral, bacterial and protozoan infections [@doi:10.1002/prca.201300074].
Though the complex pathogenesis and clinical manifestations of SARS-CoV-2 infection are not yet fully understood, omics technologies offer the opportunity for discovery-driven analysis of biological changes associated with SARS-CoV-2 infection.

#### Transcriptomics

Through transcriptomic analysis, the effect of a viral infection on gene expression can be assessed.
Transcriptomic analyses, whether _in vivo_ or _in situ_, can potentially reveal insights into viral pathogenesis by elucidating the host response to the virus.
For example, infection by some viruses, including by the coronaviruses SARS-CoV-2, SARS-CoV-1, and MERS-CoV, is associated with the upregulation of ACE2 in human embryonic kidney cells and human airway epithelial cells [@doi:10.1002/jmv.26139].
This finding suggests that SARS-CoV-2 facilitates the positive regulation of its own transmission between host cells [@doi:10.1002/jmv.26139].
The host immune response also likely plays a key role in mediating infection-associated pathologies.
Therefore, transcriptomics is one critical tool for characterizing the host response in order to gain insight into viral pathogenesis.
For this reason, the application of omics technologies to the process of characterizing the host response is expected to provide novel insights into how hosts respond to SARS-CoV-2 infection and how these changes might influence COVID-19 outcomes.

Several studies have examined the cellular response to SARS-CoV-2 _in vitro_ in comparison to other viruses.
One study [@doi:10.1016/j.cell.2020.04.026] compared the transcriptional responses of three human cell lines to SARS-CoV-2 and to other respiratory viruses, including MERS-CoV, SARS-CoV-1, *Human parainfluenza virus 3*, *Respiratory syncytial virus*, and *Influenza A virus*.
The transcriptional response differed between the SARS-CoV-1 infected cells and the cells infected by other viruses, with changes in differential expression specific to each infection type.
Where SARS-CoV-2 was able to replicate efficiently, differential expression analysis revealed that the transcriptional response was significantly different from the response to all of the other viruses tested.
A unique pro-inflammatory cytokine signature associated with SARS-CoV-2 was present in cells exposed to both high and low doses of the virus, with the cytokines IL-6 and IL1RA uniquely elevated in response to SARS-CoV-2 relative to other viruses.
However, one cell line showed significant IFN-I or IFN-III expression when exposed to high, but not low, doses of SARS-CoV-2, suggesting that IFN induction is dependent on the extent of exposure.
These results suggest that SARS-CoV-2 induces a limited antiviral state with low IFN-I or IFN-III expression and a moderate IFN-stimulated gene response, in contrast to other viruses.
Other respiratory viruses have been found to encode antagonists to the IFN response [@doi:10.1016/j.mib.2010.05.009; @doi:10.1371/journal.pone.0112014], including SARS-CoV-1 [@doi:10.1128/JVI.01782-06] and MERS-CoV [@doi:10.1128/JVI.01845-13].

The analysis of SARS-CoV-2 suggested that this transcriptional state was specific to cells expressing ACE2, as it was not observed in cells lacking expression of this protein except with ACE2 supplementation and at very high (10-fold increase) level of SARS-CoV-2 exposure [@doi:10.1016/j.cell.2020.04.026].
In another study, direct stimulation with inflammatory cytokines such as type I interferons (e.g., IFN&beta;) was also associated with the upregulation of ACE2 in human bronchial epithelial cells, with treated groups showing four-fold higher ACE2 expression than control groups at 18 hours post-treatment [@doi:10.1101/2020.02.24.963348].
This hypothesis was further supported by studies showing that several nsp in SARS-CoV-2 suppress interferon activity [@doi:10.1080/22221751.2020.1780953] and that the SARS-CoV-2 *ORF3b* gene suppresses IFNB1 promoter activity (IFN-I induction) more efficiently than the SARS-CoV-1 *ORF3b* gene [@doi:10.1016/j.celrep.2020.108185].
Taken together, these findings suggest that a unique cytokine profile is associated with the response to the SARS-CoV-2 virus, and that this response differs depending on the magnitude of exposure.

Susceptibility and IFN induction may also vary by cell type.
Using poly(A) bulk RNA-seq to analyzed dynamic transcriptional responses to SARS-CoV-2 and SARS-CoV-1 revealed negligible susceptibility of cells from the H1299 line (< 0.08 viral read percentage of total reads) compared to those from the Caco-2 and Calu-3 lines (>10% of viral reads) [@doi:10.1101/2020.05.05.079194].
This finding suggests that the risk of infection varies among cell types, and that cell type could influence which hosts are more or less susceptible.
Based on visual inspection of microscopy images alongside transcriptional profiling, the authors also showed distinct responses among the host cell lines evaluated [@doi:10.1101/2020.05.05.079194].
In contrast to Caco-2, Calu-3 cells infected with SARS-CoV-2 showed signs of impaired growth and cell death at 24 hours post infection, as well as moderate IFN induction with a strong up-regulation of IFN-stimulated genes.
Interestingly, the results were similar to those reported in Calu-3 cells exposed to much higher levels of SARS-CoV-2 [@doi:10.1016/j.cell.2020.04.026], as described above.
This finding suggests that IFN induction in Calu-3 cells is not dependent on the level of exposure, in contrast to A549-ACE2 cells.
The discrepancy could be explained by the observations that Calu-3 cells are highly susceptible to SARS-CoV-2 and show rapid viral replication [@doi:10.1038/s41467-020-15562-9], whereas A549 cells are incompatible with SARS-CoV-2 infection [@doi:10.1101/2020.03.02.972935].
This discrepancy raises the concern that _in vitro_ models may vary in their similarity to the human response, underscoring the importance of follow-up studies in additional models.

As a result, transcriptional analysis of patient tissue is an important application of omics technology to understanding COVID-19.
Several studies have collected blood samples from COVID-19 patients and analyzed them using RNA-Seq [@doi:10.1186/s13073-020-00823-5; @doi:10.1016/j.immuni.2020.11.017; @doi:10.1080/22221751.2020.1747363; @doi:10.1016/j.cell.2021.02.018; @doi:10.3389/fimmu.2021.694243; @doi:10.1126/science.abc6261].
Analyzing gene expression in the blood is valuable to understanding host-pathogen interactions because of the potential to identify alterations associated with the immune response and to gain insights into inflammation, among other potential insights [@doi:10.1186/s13073-020-00823-5].
One study compared gene expression in 39 COVID-19 inpatients admitted with community-acquired pneumonia to that of control donors using whole blood cell transcriptomes [@doi:10.1186/s13073-020-00823-5].
They also evaluated the effect of mild versus severe disease.
A greater number of differentially expressed genes were found in severe patients compared to controls than in mild patients compared to controls.
They also identified that the transcriptional profiles clustered into five groups and that the groups could not be explained by disease severity.
Most severe cases fell into two clusters associated with increased inflammation and granulocyte and neutrophil activation.
The presence of these clusters suggests the possibility that personalized medicine could be useful in the treatment of COVID-19 [@doi:10.1186/s13073-020-00823-5].
Longitudinal analysis of granulocytes from patients with mild versus severe COVID-19 revealed that granulocyte activation-associated factors differentiated the disease states, with greater numbers of differentially expressed genes early in disease course [@doi:10.1186/s13073-020-00823-5].
This study therefore revealed distinct patterns associated with COVID-19 and identified genes and pathways associated with each cluster.

Many other studies have also identified transcriptomic signatures associated with the immune response and inflammation.
Other studies have profiled the transcriptome of BALF [@doi:10.1080/22221751.2020.1747363] and the nasopharynx [@doi:10.1084/jem.20210583].
One study used single-cell transcriptomics techniques to investigate cell types including brain and choroid plexus cells compared to healthy controls and controls with influenza; among other signals of neuroinflammation, this study reported cortical T cells only in COVID-19 patients [@doi:10.1038/s41586-021-03710-0].
Transcriptomic analysis can thus provide insight into the pathogenesis of SARS-CoV-2 and may also be useful in identifying candidate therapeutics [@doi:10.1186/s13073-020-00823-5].

#### Proteomics

Proteomics analysis offers an opportunity to characterize the response to a pathogen at a level above transcriptomics.
Especially early on, this primarily involved evaluating the effect of the virus on cell lines.
One early proteomics study investigated changes associated with _in vitro_ SARS-CoV-2 infection using Caco-2 cells [@doi:10.1038/s41586-020-2332-7].
This study reported that SARS-CoV-2 induced alterations in multiple vital physiological pathways, including translation, splicing, carbon metabolism and nucleic acid metabolism in the host cells.
Another area of interest is whether SARS-CoV-2 is likely to induce similar changes to other HCoV.
For example, because of the high level of sequence homology between SARS-CoV-2 and SARS-CoV-1, it has been hypothesized that sera from convalescent SARS-CoV-1 patients might show some efficacy in cross-neutralizing SARS-CoV-2-S-driven entry [@doi:10.1016/j.cell.2020.02.052].
However, despite the high level of sequence homology, certain protein structures might be immunologically distinct, which would be likely to prohibit effective cross-neutralization across different SARS species [@doi:10.1101/2020.03.21.990770].
Consequently, proteomic analyses of SARS-CoV-1 might also provide some essential information regarding the new pathogen [@doi:10.1073/pnas.0407992101; @doi:10.1016/j.bbrc.2004.02.074].

Proteomics research has been able to get ahead of the timeline for development of omics-level big data sets specific to SARS-CoV-2 by adopting a comparative bioinformatics approach.
Data hubs such as UniProt [@doi:10.1093/nar/gky1049], NCBI Genome Database [@url:https://www.ncbi.nlm.nih.gov/genome], The Immune Epitope Database and Analysis Resource [@doi:10.1093/nar/gky1006], and The Virus Pathogen Resource [@doi:10.1093/nar/gkr859] contain a wealth of data from studies in other viruses and even HCoV.
Such databases facilitate the systems-level reconstruction of protein-protein interaction networks, providing opportunities to generate hypotheses about the mechanism of action of SARS-CoV-2 and identify potential drug targets.
In an initial study [@doi:10.1038/s41586-020-2286-9], 26 of the 29 SARS-CoV-2 proteins were cloned and expressed in HEK293T kidney cells, allowing for the identification of 332 high-confidence human proteins interacting with them.
Notably, this study suggested that SARS-CoV-2 interacts with innate immunity pathways.
Ranking pathogens by the similarity between their interactomes and that of SARS-CoV-2 suggested *West Nile virus*, *Mycobacterium tuberculosis*, and *human papillomavirus* infections as the top three hits.
The fact that the host-pathogen interactome of the bacterium *Mycobacterium tuberculosis* was found to be similar to that of SARS-CoV-2 suggests that changes related to lung pathology might comprise a significant contributor to these expression profiles.
Additionally, it was suggested that the envelope protein, E, could disrupt host bromodomain-containing proteins, i.e., BRD2 and BRD4, that bind to histones, and the spike protein could likely intervene in viral fusion by modulating the GOLGA7-ZDHHC5 acyl-transferase complex to increase palmitoylation, which is a post-translational modification that affects how proteins interact with membranes [@doi:10.3389/fimmu.2017.02003].

An example of an application of this _in silico_ approach comes from another study [@doi:10.1101/2020.03.31.019216], which used patient-derived peripheral blood mononuclear cells to identify 251 host proteins targeted by SARS-CoV-2.
This study also reported that more than 200 host proteins were disrupted following infection.
In particular, a network analysis showed that nsp9 and nsp10 interacted with NF-Kappa-B-Repressing Factor, which encodes a transcriptional repressor that mediates repression of genes responsive to Nuclear Factor kappa-light-chain-enhancer of activated B-cells.
These genes are important to pro-, and potentially also anti-, inflammatory signaling [@doi:10.1101/cshperspect.a001651].
This finding could explain the exacerbation of the immune response that shapes the pathology and the high cytokine levels characteristic of COVID-19, possibly due to the chemotaxis of neutrophils mediated by IL-8 and IL-6.
Finally, it was suggested [@doi:10.1101/2020.04.09.033522] that the E protein of both SARS-CoV-1 and SARS-CoV-2 has a conserved Bcl-2 Homology 3-like motif, which could inhibit anti-apoptosis proteins, e.g., BCL2, and trigger the apoptosis of T cells.
Several compounds are known to disrupt the host-pathogen protein interactome, largely through the inhibition of host proteins.
Therefore, this research identifies candidate targets for intervention and suggests that drugs modulating protein-level interactions between virus and host could be relevant to treating COVID-19.

As with other approaches, analyzing the patterns found in infected versus healthy human subjects is also important.
COVID-19 infection has been associated with quantitative changes in transcripts, proteins, metabolites, and lipids in patient blood samples [@doi:10.1016/j.cels.2020.10.003].
One longitudinal study [@doi:10.15252/emmm.202114167] compared COVID-19 patients to symptomatic controls who were PCR-negative for SARS-CoV-2.
The longitudinal nature of this study allowed it to account for differences in the scale of inter- versus intraindividual changes.
At the time of first sampling, common functions of proteins upregulated in COVID-19 patients relative to controls were related to immune system mediation, coagulation, lipid homeostasis, and protease inhibition.
They compared these data to the patient-specific timepoints associated with the highest levels of SARS-CoV-2 antibodies and found that the actin-binding protein gelsolin, which is involved in recovery from disease, showed the steepest decline between those two time points.
Immunoglobulins comprised the only proteins that were significantly different between the COVID-19 and control patients at both of these timepoints.
The most significantly downregulated proteins between these time points were related to inflammation, while the most significantly upregulated proteins were immunoglobulins.
Proteins related to coagulation also increased between the two timepoints.
The selection of a symptomatic control cohort rather than healthy comparisons also suggests that the results are more likely to highlight the response to SARS-CoV-2 and COVID-19 specifically, rather than to disease more broadly.
This study also compared the disease course in patients who ultimately survived to those who died and found that ITIH4, a protein associated with the inflammatory response to trauma, may be a biomarker useful to identifying patients at risk of death.
Thus, these results indicate the value of studying patients in a longitudinal manner over the disease course.
By revealing which genes are perturbed during SARS-CoV-2 infection, proteomics-based analyses can thus provide novel insights into host-virus interaction and serve to generate new avenues of investigation for therapeutics.

### Viral Virulence

Like that of SARS-CoV-1, the entry of SARS-CoV-2 into host cells is mediated by interactions between the viral spike glycoprotein, S, and human ACE2 (hACE2) [@doi:10.1126/science.1116480; @doi:10.1016/j.cell.2020.02.058; @doi:10.1126/science.abb2762; @doi:10.1038/s41586-020-2179-y; @doi:10.1101/2020.02.19.956235; @doi:10.1016/j.cell.2020.02.052; @doi:10.1016/j.cell.2020.03.045; @doi:10.1128/jvi.00127-20].
Differences in how the S proteins of the two viruses interact with hACE2 could partially account for the increased transmissibility of SARS-CoV-2.
Studies have reported conflicting binding constants for the S-hACE2 interaction, though they have agreed that the SARS-CoV-2 S protein binds with equal, if not greater, affinity than the SARS-CoV-1 S protein does [@doi:10.1016/j.cell.2020.02.058; @doi:10.1101/2020.02.19.956235; @doi:10.1126/science.abb2507].
The C-terminal domain of the SARS-CoV-2 S protein in particular was identified as the key region of the virus that interacts with hACE2, and the crystal structure of the C-terminal domain of the SARS-CoV-2 S protein in complex with hACE2 reveals stronger interaction and a higher affinity for receptor binding than that of SARS-CoV-1 [@doi:10.1016/j.cell.2020.03.045].
Among the 14 key binding residues identified in the SARS-CoV-1 S protein, eight are conserved in SARS-CoV-2, and the remaining six are semi-conservatively substituted, potentially explaining variation in binding affinity [@doi:10.1016/j.cell.2020.02.058; @doi:10.1101/2020.02.19.956235].
Studies of crystal structure have shown that the RBD of the SARS-CoV-2 S protein, like that of other coronaviruses, undergoes stochastic hinge-like movement that flips it from a “closed” conformation, in which key binding residues are hidden at the interface between protomers, to an “open” one [@doi:10.1016/j.cell.2020.02.058; @doi:10.1126/science.abb2507].
Spike proteins cleaved at the furin-like binding site are substantially more likely to take an open conformation (66%) than those that are uncleaved (17%) [@doi:10.1038/s41594-020-0468-7].
Because the RBD plays such a critical role in viral entry, blocking its interaction with ACE2 could represent a promising therapeutic approach.
Nevertheless, despite the high structural homology between the SARS-CoV-2 RBD and that of SARS-CoV-1, monoclonal antibodies targeting SARS-CoV-1 RBD failed to bind to SARS-CoV-2-RBD [@doi:10.1126/science.abb2507].
However, in early research, sera from convalescent SARS patients were found to inhibit SARS-CoV-2 viral entry _in vitro_, albeit with lower efficiency than it inhibited SARS-CoV-1 [@doi:10.1016/j.cell.2020.02.052].

Comparative genomic analysis reveals that several regions of the coronavirus genome are likely critical to virulence.
The S1 domain of the spike protein, which contains the receptor binding motif, evolves more rapidly than the S2 domain [@doi:10.3390/v4061011; @doi:10.1016/j.jmb.2020.04.009].
However, even within the S1 domain, some regions are more conserved than others, with the receptors in S1's N-terminal domain (S1-NTD) evolving more rapidly than those in its C-terminal domain (S1-CTD) [@doi:10.1016/j.jmb.2020.04.009].
Both S1-NTD and S1-CTD are involved in receptor binding and can function as RBDs to bind proteins and sugars [@doi:10.3390/v4061011], but RBDs in the S1-NTD typically bind to sugars, while those in the S1-CTD recognize protein receptors [@doi:10.1146/annurev-virology-110615-042301].
Viral receptors show higher affinity with protein receptors than sugar receptors [@doi:10.1146/annurev-virology-110615-042301], which suggests that positive selection on or relaxed conservation of the S1-NTD might reduce the risk of a deleterious mutation that would prevent binding.
The SARS-CoV-2 S protein also contains an RRAR furin recognition site at the S1/S2 junction [@doi:10.1016/j.cell.2020.02.058; @doi:10.1126/science.abb2507], setting it apart from both bat coronavirus RaTG13, with which it shares 96% genome sequence identity, and SARS-CoV-1 [@doi:10.1038/s41586-020-2012-7].
Such furin cleavage sites are commonly found in highly virulent influenza viruses [@doi:10/bvgh5b; @doi:10.1006/viro.1999.9716].
The furin recognition site at the S1/S2 junction is likely to increase pathogenicity via destabilization of the spike protein during fusion to ACE2 and the facilitation of cell-cell adhesion [@doi:10.1016/j.cell.2020.02.058; @doi:10.1126/science.abb2507; @doi:10.1038/s41594-020-0468-7; @doi:10/bvgh5b; @doi:10.1006/viro.1999.9716; @doi:10.1016/j.isci.2020.101212].
These factors may influence the virulence of SARS-CoV-2 relative to other beta coronaviruses.
Additionally, a major concern has been the emergence of SARS-CoV-2 variants with increased virulence.
The extent to which evolution within SARS-CoV-2 may affect pathogenesis is reviewed below.

### Molecular Signatures, Transmission, and Variants of Concern

Genetic variation in SARS-CoV-2 has been used to elucidate patterns over time and space.
Many mutations are neutral in their effect and can be used to trace transmission patterns.
Such signatures within SARS-CoV-2 have provided insights during outbreak investigations [@doi:10.1186/s12967-020-02344-6; @doi:10.1093/nsr/nwaa036; @doi:10.1016/j.meegid.2020.104351].
Similar mutations observed in several patients may indicate that the patients belong to the same transmission group.
The tracking of SARS-CoV-2 mutations is recognized as an essential tool for controlling future outbreaks and tracing the path of the spread of SARS-CoV-2.
In the first months of the pandemic in early 2020, early genomic surveillance efforts in Guangdong, China revealed that local transmission rates were low and that most cases arising in the province were imported [@doi:10.1016/j.cell.2020.04.023].
Since then, efforts have varied widely among countries: for example, the U.K. has coordinated a national database of viral genomes [@doi:10/d5mg], but efforts to collect this type of data in the United States have been more limited [@url:https://www.cdc.gov/coronavirus/2019-ncov/variants/spheres.html].
Studies have applied phylogenetic analyses of viral genomes to determine the source of local COVID-19 outbreaks in Connecticut (USA), [@doi:10.1016/j.cell.2020.04.021], the New York City area (USA) [@doi:10.1126/science.abc1917], and Iceland [@doi:10.1056/NEJMoa2006100].
There has been an ongoing effort to collect SARS-CoV-2 genomes throughout the COVID-19 outbreak, and as of summer 2021, millions of genome sequences have been collected from patients.
The sequencing data can be found at GISAID [@https://www.gisaid.org], NCBI [@https://www.ncbi.nlm.nih.gov/sars-cov-2], and COVID-19 data portal [@https://www.covid19dataportal.org].

Ongoing evolution can be observed in genomic data collected through molecular surveillance efforts.
In some cases, mutations can produce functional changes that can impact pathogenesis.
One early example is the spike protein mutation D614G, which appeared in March 2020 and became dominant worldwide by the end of May 2020 [@doi:10.1016/j.cell.2020.06.043; @doi:10.1016/j.cell.2020.09.032].
This variant was associated with increased infectivity and increased viral load, but not with more severe disease outcomes [@doi:10.1016/j.cell.2020.06.043; @doi:10.1038/s41586-020-2895-3].
This increased virulence is likely achieved by altering the conformation of the S1 domain to facilitate binding to ACE2 [@doi:10.1038/s41586-020-2895-3].
Similarly, the N439K mutation within the RBD of the spike protein is likely associated with increased transmissibility and enhanced binding affinity for hACE2, although it is also not thought to affect disease outcomes [@doi:10.1016/j.cell.2021.01.037].
In contrast, a mutation in ORF8 that was identified in Singapore in the early months of 2020 was associated with cases of COVID-19 that were less likely to require treatment with supplemental oxygen [@doi:10/d6x7], and a deletion surrounding the furin site insertion at the S1/S2 boundary has been identified only rarely in clinical settings [@doi:10.1128/JVI.00790-20], suggesting that these mutations may disadvantage viral pathogenesis in human hosts.
Thus, mutations have been associated with both virological and clinical differences in pathogenesis.

Several VOCs have also been identified and designated through molecular surveillance efforts [@doi:10.1038/s41576-021-00408-x].
The Alpha variant (lineage B.1.1.7) was first observed in the U.K. in October 2020 before it quickly spread around the world [@doi:10.3390/v13030392].
Other variants meriting further investigation have also been identified, including the Beta variant (B.1.351 lineage) first identified in South Africa and the Gamma variant (P.1 lineage) initially associated with outbreaks in Brazil.
These lineages share independently acquired mutations that may affect pathogenicity [@doi:10.1101/2020.12.14.422555; @url:https://cov-lineages.org/global_report_B.1.351.html; @doi:10/gsfg; @doi:10.1016/j.csbj.2021.06.037; @doi:10.1101/2020.12.30.20249034].
For example, they are all associated with a greater binding affinity for hACE2 than that of the wildtype variant [@doi:10/gsfg; @doi:10.1016/j.jmb.2021.167058; @doi:10.1016/j.medidd.2021.100086], but they were not found to have more efficient cell entry than the wildtype virus [@doi:10.1016/j.cell.2021.03.036].
A fourth VOC, the Delta variant (B.1.617.2 and AY.1, AY.2, and AY.3 lineages), was identified in India in late 2020 [@url:https://www.who.int/en/activities/tracking-SARS-CoV-2-variants].
Some of the mutations associated with this lineage may alter fusogenicity and enhance furin cleavage, among other effects associated with increased pathogenicity [@doi:10.1101/2021.06.17.448820].
The changes in these VOC demonstrate how ongoing evolution in SARS-CoV-2 can drive changes in how the virus interacts with host cells.

### Quantifying Viral Presence

Assessing whether a virus is present in a sample is a more complex task than it initially seems.
Many diagnostic tests rely on real-time polymerase chain reaction (RT-PCR) to test for the presence versus absence of a virus [@individual-diagnostics].
They may report the cycle threshold (C~t~) indicating the number of doubling cycles required for the target (in this case, SARS-CoV-2) to become detectable.
A lower C~t~ therefore corresponds to a higher viral load.
The C~t~ that corresponds to a positive can vary widely, but is often around 35.
This information is sufficient to answer many questions, since an amplicon must be present in order to be duplicated in RT-PCR.
For example, if a patient is presenting with COVID-19 symptoms, a positive RT-PCR test can confirm the diagnosis.

However, RT-PCR analysis alone cannot provide the information needed to determine whether a virus is present at sufficient levels to be infectious [@doi:10.2807/1560-7917.ES.2020.25.32.2001483].
Some studies have therefore taken the additional step of cultivating samples _in vitro_ in order to observe whether cells become infected with SARS-CoV-2.
One study collected upper respiratory tract samples from COVID-19 patients, analyzed them with RT-PCR to determine the cycle threshold, and then attempted to cultivate the SARS-CoV-2 virus in VeroE6 cells [@doi:10.2807/1560-7917.ES.2020.25.32.2001483].
This study found that out of 246 samples, less than half (103) produced a positive culture.
Moreover, at a C~t~ of 35, only 5 out of 60 samples grew _in vitro_.
Therefore, the RT-PCR-confirmed presence of SARS-CoV-2 in a sample does not necessarily indicate that the virus is present at a high enough concentration to grow and/or spread. 

### Mechanisms of Transmission

When a human host is infected with a virus and is contagious, person-to-person viral transmission can occur through several possible mechanisms.
When a contagious individual sneezes, coughs, or exhales, they produce respiratory droplets that can contain a large number of viral particles [@pubmed:23771256].
Viral particles can enter the body of a new host when they then come in contact with the oral, nasal, eye, or other mucus membranes [@pubmed:23771256].
The primary terms typically used to discuss the transmission of viruses via respiratory droplets are droplet, aerosol, and contact transmission [@doi:10.1097/QCO.0000000000000563].
The distinction between droplet and aerosol transmission is typically anchored on whether a particle containing the virus is larger or smaller than 5 micrometers (&mu;m) [@doi:10.1016/j.jhin.2020.12.022; @{url:https://papers.ssrn.com/sol3/papers.cfm?abstract_id=3829873}].
Droplet transmission typically refers to contact with large droplets that fall quickly to the ground at close range, such as breathing in droplets produced by a sneeze [@pubmed:23771256; @doi:10.1016/j.jhin.2020.12.022].
Aerosol transmission typically refers to much smaller particles (less than 5 &mu;m) produced by sneezing, coughing, or exhaling [@doi:10.1097/QCO.0000000000000563; @pubmed:23771256] that can remain suspended over a longer period of time and potentially to be moved by air currents [@pubmed:23771256].
It is also possible that viral particles deposited on surfaces via large respiratory droplets could later be aerosolized [@pubmed:23771256].
The transmission of viral particles that have settled on a surface is typically referred to as contact or fomite transmission [@url:https://www.who.int/news-room/commentaries/detail/transmission-of-sars-cov-2-implications-for-infection-prevention-precautions; @pubmed:23771256].
Any respiratory droplets that settle on a surface could contribute to fomite transmission [@pubmed:23771256].
Droplet and contact transmission are both well-accepted modes of transmission for many viruses associated with common human illnesses, including influenza and rhinovirus [@pubmed:23771256].

The extent to which aerosol transmission contributes to the spread of respiratory viruses is more widely debated.
In influenza A, for example, viral particles can be detected in aerosols produced by infected individuals, but it is not clear to what extent these particles drive the spread of influenza A infection [@pubmed:23771256; @doi:10.1097/QCO.0000000000000563; @doi:10.3201/eid1301.061202; @doi:10.1038/s41598-019-38825-y; @doi:10.1093/femsre/fuv039].
Regardless of its role in the spread of influenza A, however, aerosol transmission likely played a role in outbreaks such as the 1918 Spanish Influenza (H1N1) and 2009 "swine flu" (pH1N1) [@doi:10.1093/femsre/fuv039].
All three of these mechanisms have been identified as possible contributors to the transmission of HCoVs [@pubmed:23771256], including the highly pathogenic coronaviruses SARS-CoV-1 and MERS-CoV [@doi:10.1016/B978-0-12-385885-6.00009-2; @doi:10.1038/nrmicro.2016.81].
Transmission of SARS-CoV-1 is thought to proceed primarily through droplet transmission, but aerosol transmission is also considered possible [@pubmed:23771256; @doi:10.1111/j.1600-0668.2004.00317.x; @doi:10.1086/429634], and fomite transmission may have also played an important role in some outbreaks [@doi:10.1371/journal.pone.0181558].
Similarly, the primary mechanism of MERS transmission is thought to be droplets because inter-individual transmission appears to be associated with close interpersonal contact (e.g., household or healthcare settings), but aerosolized particles of the MERS virus have been reported to persist much more robustly than influenza A under a range of environmental conditions [@doi:10.2807/1560-7917.es2013.18.38.20590; @doi:10.1186/s12985-015-0439-5].
However, few of these analyses have sought to grow positive samples in culture and thus to confirm their potential to infect new hosts.

Contact, droplet, and aerosol transmission are therefore all worth evaluating when considering possible modes of transmission for a respiratory virus like SARS-CoV-2.
The stability of the SARS-CoV-2 virus both in aerosols and on a variety of surfaces was found to be similar to that of SARS-CoV-1 [@doi:10.1056/NEJMc2004973].
Droplet-based and contact transmission were initially put forward as the greatest concern for the spread of SARS-CoV-2 [@doi:10.1038/s41368-020-0075-9], with droplet transmission considered the dominant mechanism driving the spread of the virus [@doi:10.1001/jama.2020.12458] because the risk of fomite transmission under real-world conditions is likely to be substantially lower than the conditions used for experimental analyses [@doi:10/gg6br7].
The COVID-19 pandemic has, however, exposed significant discrepancies in how terms pertaining to airborne viral particles are interpreted in different contexts [@doi:10.1016/j.jhin.2020.12.022].
The 5-&mu;m distinction between "droplets" and "aerosols" is typical in the biological literature but is likely an artifact of historical science rather than a meaningful boundary in biology or physics [@{url:https://papers.ssrn.com/sol3/papers.cfm?abstract_id=3829873}].
Additionally, various ambient conditions such as air flow can influence how particles of different sizes fall or spread [@doi:10.1016/j.jhin.2020.12.022].
Despite initial skepticism about airborne transmission of SARS-CoV-2 through small particles [@{url:https://papers.ssrn.com/sol3/papers.cfm?abstract_id=3829873}], evidence now suggests that small particles can contribute to SARS-CoV-2 transmission [@doi:10.1126/science.abc6197; @doi:10.1056/NEJMc2004973; @doi:10.1093/cid/ciaa939; @doi:10/gjqmvq].
For example, one early study detected SARS-CoV-2 viral particles in air samples taken from hospitals treating COVID-19 patients, although the infectivity of these samples was not assessed [@doi:10.1038/s41586-020-2271-3].
Subsequently, other studies have been successful in growing SARS-CoV-2 in culture with samples taken from the air [@doi:10.1016/j.ijid.2020.09.025; @doi:10.1101/2020.07.13.20041632] while others have not [@doi:10.1038/s41598-020-69286-3; @doi:10.1093/cid/ciaa905] (see [@doi:10.1002/rmv.2184] for a systematic review of available findings as of July 2020).
The fact that viable SARS-CoV-2 may exist in aerosolized particles calls into question whether some axioms of COVID-19 prevention, such as 2-meter social distancing, are sufficient [@doi:10.1001/jama.2020.4756; @{url:https://papers.ssrn.com/sol3/papers.cfm?abstract_id=3829873}; @doi:10.1016/j.ijid.2020.09.025].

#### Symptoms and Viral Spread

Other aspects of pathogenesis are also important to understanding how the virus spreads, especially the relationship between symptoms, viral shedding, and contagiousness.
Symptoms associated with reported cases of COVID-19 range from mild to severe [@url:https://www.cdc.gov/coronavirus/2019-ncov/symptoms-testing/symptoms.html], but some individuals who contract COVID-19 remain asymptomatic throughout the duration of the illness [@doi:10.1007/s11427-020-1661-4].
The incubation period, or the time period between exposure and the onset of symptoms, has been estimated at five to eight days, with means of 4.91 (95% confidence interval (CI) 4.35-5.69) and 7.54 (95% CI 6.76-8.56) reported in two different Asian cities and a median of 5 (IQR 1 to 6) reported in a small number of patients in a Beijing hospital [@doi:10.7554/eLife.57149; @doi:10.1164/rccm.202003-0524LE].

However, the exact relationship between contagiousness and viral shedding remains unclear.
Estimates suggest that viral shedding can, in some cases, begin as early as 12.3 days (95% CI 5.9-17.0) before the onset of symptoms, although this was found to be very rare, with less than 0.1% of transmission events occurring 7 or more days before symptom onset [@doi:10.1038/s41591-020-0869-5].
Transmissibility appeared to peak around the onset of symptoms (95% CI -0.9 - 0.9 days), and only 44% (95% CI 30–57%) of transmission events were estimated to occur from presymptomatic contacts [@doi:10.1038/s41591-020-0869-5].
A peak in viral load corresponding to the onset of symptoms was also confirmed by another study [@doi:10.2807/1560-7917.ES.2020.25.32.2001483].
As these trends became apparent, concerns arose due to the potential for individuals who did not yet show symptoms to transmit the virus [@url:https://www.cdc.gov/coronavirus/2019-ncov/prevent-getting-sick/how-covid-spreads.html].
Recovered individuals may also be able to transmit the virus after their symptoms cease.
A study of the communicable period based on twenty-four individuals who tested positive for SARS-CoV-2 prior to or without developing symptoms estimated that individuals may be contagious for one to twenty-one days, but they note that this estimate may be low [@doi:10.1007/s11427-020-1661-4].
In an early study, viral nucleic acids were reported to remain at observable levels in the respiratory specimens of recovering hospitalized COVID-19 patients for a median of 20 days and with a maximum observed duration through 37 days, when data collection for the study ceased [@doi:10/ggnxb3].

As more estimates of the duration of viral shedding were released, they converged around approximately three weeks from first positive PCR test and/or onset of symptoms (which, if present, are usually identified within three days of the initial PCR test).
For example, in some studies, viral shedding was reported for up to 28 days following symptom onset [@doi:10.1038/s41586-020-2196-x] and for one to 24 days from first positive PCR test, with a median of 12 days [@doi:10.1001/jama.2020.3204].
On the other hand, almost 70% of patients were reported to still have symptoms at the time that viral shedding ceased, although all symptoms reduced in prevalence between onset and cessation of viral shedding [@doi:10.1016/j.jcv.2020.104577].
The median time that elapsed between the onset of symptoms and cessation of viral RNA shedding was 23 days and between first positive PCR test and cessation of viral shedding was 17 days [@doi:10.1016/j.jcv.2020.104577].
The fact that this study reported symptom onset to predate the first positive PCR test by an average of three days, however, suggests that there may be some methodological differences between it and related studies.
Furthermore, an analysis of residents of a nursing home with a known SARS-CoV-2 case measured similar viral load in residents who were asymptomatic regardless of whether they later developed symptoms, and the load in the asymptomatic residents was comparable to that of residents who displayed either typical or atypical symptoms [@doi:10.1056/NEJMoa2008457].
Taken together, these results suggest that the presence or absence of symptoms are not reliable predictors of viral shedding or of SARS-CoV-2 status (e.g, [@doi:10.1001/jama.2020.6887]).
However, it should be noted that viral shedding is not necessarily a robust indicator of contagiousness.
The risk of spreading the infection was low after ten days from the onset of symptoms, as viral load in sputum was found to be unlikely to pose a significant risk based on efforts to culture samples _in vitro_ [@doi:10.1038/s41586-020-2196-x].
The relationship between symptoms, detectable levels of the virus, and risk of viral spread is therefore complex.

The extent to which asymptomatic or presymptomatic individuals are able to transmit SARS-CoV-2 has been a question of high scientific and community interest.
Early reports (February and March 2020) described transmission from presymptomatic SARS-CoV-2-positive individuals to close family contacts [@doi:10.1001/jama.2020.2565; @doi:10.1016/j.ijid.2020.03.027].
One of these reports [@doi:10.1016/j.ijid.2020.03.027] also included a description of an individual who tested positive for SARS-CoV-2 but never developed symptoms.
Later analyses also sought to estimate the proportion of infections that could be traced back to a presymptomatic or asymptomatic individual (e.g., [@doi:10.2139/ssrn.3678556]).
Estimates of the proportion of individuals with asymptomatic infections have varied widely.
The proportion of asymptomatic individuals on board the Diamond Princess cruise ship, which was the site of an early COVID-19 outbreak, was estimated at 17.9% [@doi:10.2807/1560-7917.ES.2020.25.10.2000180].
In contrast, a model using the prevalence of antibodies among residents of Wuhan, China estimated a much higher rate of asymptomatic cases, at approximately 7 in 8, or 87.5% [@doi:10.1093/pcmedi/pbaa032].
An analysis of the populations of care homes in London found that, among the residents (median age 85), the rate of asymptomatic infection was 43.8%, and among the caretakers (median age 47), the rate was 49.1% [@doi:10.1016/j.eclinm.2020.100533].
The duration of viral shedding may also be longer in individuals with asymptomatic cases of COVID-19 compared to those who do show symptoms [@doi:10.1038/s41591-020-0965-6].
As a result, the potential for individuals who do not know they have COVID-19 to spread the virus raises significant concerns.
In Singapore and Tianjin, two cities studied to estimate incubation period, an estimated 40-50% and 60-80% of cases, respectively, were considered to be caused by contact with asymptomatic individuals [@doi:10.7554/eLife.57149].
An analysis of viral spread in the Italian town of Vo', which was the site of an early COVID-19 outbreak, revealed that 42.5% of cases were asymptomatic and that the rate was similar across age groups [@doi:10.1038/s41586-020-2488-1].
The argument was thus made that the town's lockdown was imperative for controlling the spread of COVID-19 because it isolated asymptomatic individuals.
While more models are likely to emerge to better explore the effect of asymptomatic individuals on SARS-CoV-2 transmission, these results suggest that strategies for identifying and containing asymptomatic but contagious individuals are important for managing community spread.

#### Estimating the Fatality Rate

Estimating the occurrence of asymptomatic and mild COVID-19 cases is important to identifying the mortality rate associated with COVID-19.
The mortality rate of greatest interest would be the total number of fatalities as a fraction of the total number of people infected.
One commonly reported metric is the case fatality rate (CFR), which compares the number of COVID-19 related deaths to the number of confirmed or suspected cases.
However, in locations without universal testing protocols, it is impossible to identify all infected individuals because so many asymptomatic or mild cases go undetected.
Therefore, a more informative metric is the infection fatality rate (IFR), which compares the known deaths to the estimated number of cases.
It thus requires the same numerator as CFR, but divides by an approximation of the total number of cases rather than only the observed/suspected cases.
IFR varies regionally, with some locations observed to have IFRs as low as 0.17% while others are as high as 1.7% [@doi:10.1016/j.ijid.2020.09.1464].
Estimates of CFR at the national and continental level and IFR at the continent level is maintained by the Centre for Evidence-Based Medicine [@url:https://www.cebm.net/covid-19/global-covid-19-case-fatality-rates].
Several meta-analyses have also sought to estimate IFR at the global scale.
These estimates have varied; one peer-reviewed study aggregated data from 24 other studies and estimated IFR at 0.68% (95% CI 0.53%–0.82%), but a preprint that aggregated data from 139 countries calculated a global IFR of 1.04% (95% CI 0.77%-1.38%) when false negatives were considered in the model [@doi:10.1101/2020.05.11.20098780; @doi:10.1016/j.ijid.2020.09.1464].
A similar prevalence estimate was identified through a repeated cross-sectional serosurvey conducted in New York City that estimated the IFR as 0.97% [@doi:10.1038/s41586-020-2912-6].
Examination of serosurvey-based estimates of IFR identified convergence on a global IFR estimate of 0.60% (95% CI 0.42%–0.77%) [@doi:10.1016/j.ijid.2020.09.1464].
All of these studies note that IFR varies widely by location, and it is also expected to vary with demographic and health-related variables such as age, sex, prevalence of comorbidities, and access to healthcare and testing [@url:https://ourworldindata.org/covid-mortality-risk].
Estimates of infection rates are becoming more feasible as more data becomes available for modeling and will be bolstered as serological testing becomes more common and more widely available.
However, this research may be complicated due to the emergence of variants over time, as well as the varying availability and acceptance of vaccines in different communities and locations.

### Dynamics of Transmission

Disease spread dynamics can be estimated using R~0~, the basic reproduction number, and R~t~, the effective reproduction number.
Accurate estimates of both are crucial to understanding the dynamics of infection and to predicting the effects of different interventions.
R~0~ is the average number of new (secondary) infections caused by one infected person, assuming a wholly susceptible population [@doi:10.1111/j.1467-9574.1996.tb01482.x], and is one of the most important epidemiological parameters [@isbn:9780691116174].
A simple mechanistic model used to describe infectious disease dynamics is a susceptible-infected-recovered compartmental model [@doi:10.1098/rspa.1927.0118; @doi:10.1038/280361a0].
In this model, individuals move through three states: susceptible, infected, and recovered; two parameters, $\gamma$ and $\beta$, specify the rate at which the infectious recover, and the infection transmission rate, respectively, and R~0~ is estimated as the ratio of $\beta$ and $\gamma$ [@doi:10.1126/science.abb5659; @isbn:9780691116174].
A pathogen can invade a susceptible population only if R~0~ > 1 [@isbn:9780691116174; @isbn:9780199209996].
The spread of an infectious disease at a particular time t can be quantified by R~t~, the effective reproduction number, which assumes that part of the population has already recovered (and thus gained immunity to reinfection) or that mitigating interventions have been put into place.
For example, if only a fraction S~t~ of the population is still susceptible, R~t~ = S~t~ x R~0~.
When R~t~ is greater than 1, an epidemic grows (i.e., the proportion of the population that is infectious increases); when R~t~ is less than 1, the proportion of the population that is infectious decreases.
R~0~ and R~t~ can be estimated directly from epidemiological data or inferred using susceptible-infected-recovered-type models.
To capture the dynamics of SARS-CoV-2 accurately, the addition of a fourth compartment, i.e. a susceptible-exposed-infectious-recovered model, may be appropriate because such models account for the relative lengths of incubation and infectious periods [@doi:10.1038/s41598-020-76563-8].

Original estimates of R~0~ for COVID-19 lie in the range R~0~=1.4-6.5 [@doi:10/ggjvr7; @doi:10.1093/jtm/taaa021; @doi:10.1126/science.abb3221].
Variation in R~0~ is expected between different populations, and the estimated values of R~0~ discussed below are for specific populations in specific environments.
The different estimates of R~0~ should not necessarily be interpreted as a range of estimates of the same underlying parameter.
In one study of international cases, the predicted value was R~0~=1.7 [@doi:10.1101/2020.03.21.20040329].
In China (both Hubei province and nationwide), the value was predicted to lie in the range R~0~=2.0-3.6 [@doi:10.2139/ssrn.3524675; @doi:10.1101/2020.01.25.919787; @doi:10/ggjvr7].
Another estimate based on a cruise ship where an outbreak occurred predicted R~0~=2.28 [@doi:10.1016/j.ijid.2020.02.033].
Susceptible-exposed-infectious-recovered model-derived estimates of R~0~ range from 2.0 - 6.5 in China [@doi:10.3390/jcm9020462; @doi:10.1101/2020.01.27.20018952; @doi:10.1101/2020.01.23.916726; @doi:10.1101/2020.01.23.20018549] to R~0~=4.8 in France [@doi:10.1101/2020.03.22.20040915].
Using the same model as for the French population, a study estimated R~0~=2.6 in South Korea [@doi:10.1101/2020.03.22.20040915], which is consistent with other studies [@tag:Park2020_distancing].
From a meta-analysis of studies estimating R~0~, [@doi:10.1093/jtm/taaa021] the median R~0~ was estimated to be 2.79 (IQR 1.16) based on twelve studies published between January 1 and February 7, 2020.

Inference of the effective reproduction number can provide insight into how populations respond to an infection and the effectiveness of interventions.
In China, R~t~ was predicted to lie in the range 1.6-2.6 in January 2020, before travel restrictions [@doi:10/ggptcf].
R~t~ decreased from 2.35 one week before travel restrictions were imposed (January 23, 2020), to 1.05 one week after.
Using their model, the authors also estimated the probability of new outbreaks occurring.
Assuming individual-level variation in transmission comparable to that of MERS or SARS, the probability of a single individual exporting the virus and causing a large outbreak is 17-25%, and assuming variation like that of SARS and transmission patterns like those observed for COVID-19 in Wuhan, the probability of a large outbreak occurring after ≥4 infections exist at a new location is greater than 50%.
An independent study came to similar conclusions, finding R~t~=2.38 in the two-week period before January 23 with a decrease to R~t~ = 1.34 (using data from January 24 to February 3) or R~t~=0.98 (using data from January 24 to February 8) [@doi:10.1126/science.abb3221].
In South Korea, R~t~ was inferred for February through March 2020 in two cities, Daegu (the center of the outbreak) and Seoul [@tag:Park2020_distancing].
Metro data was also analyzed to estimate the effects of social distancing measures.
R~t~ decreased in Daegu from around 3 to <1 over the period that social distancing measures were introduced.
In Seoul, R~t~ decreased slightly, but remained close to 1 (and larger than R~t~ in Daegu).
These findings indicate that social distancing measures appeared to be effective in containing the infection in Daegu, but in Seoul, R~t~ remained above 1, meaning secondary outbreaks remained possible.
The study also shows the importance of region-specific analysis: the large decline in case load nationwide was mainly due to the Daegu region and could mask persistence of the epidemic in other regions, such as Seoul and Gyeonggi-do.
In Iran, estimates of R~t~ declined from 4.86 in the first week to 2.1 by the fourth week after the first cases were reported [@doi:10.1101/2020.03.20.20038422].
In Europe, analysis of 11 countries inferred the dynamics of R~t~ over a time range from the beginning of the outbreak until March 28, 2020, by which point most countries had implemented major interventions (such as stay-at-home orders, public gathering bans, and school closures) [@doi:10.25561/77731].
Across all countries, the mean R~t~ before interventions began was estimated as 3.87; R~t~ varied considerably, from below 3 in Norway to above 4.5 in Spain.
After interventions, R~t~ decreased by an average of 64% across all countries, with mean R~t~=1.43.
The lowest predicted value was 0.97 for Norway and the highest was 2.64 for Sweden, which could be related to the fact that Sweden did not implement social distancing measures on the same scale as other countries.
The study concludes that while large changes in R~t~ are observed, it is too early to tell whether the interventions put into place are sufficient to decrease R~t~ below 1.

Evolution within SARS-CoV-2 has also driven changes in the estimated reproduction number for different populations at different times.
As of June 2021, the reproduction number had increased globally relative to 2020, and increased transmissibility over the wildtype variant was observed for the Alpha, Beta, Gamma, and Delta VOC [@doi:10.2807/1560-7917.ES.2021.26.24.2100509].
In the U.S. between December 2020 and January 2021, B.1.1.7 (Alpha) was estimated to have an increased transmission of 35 to 45% relative to common SARS-CoV-2 variants at the time, with B.1.1.7 the dominant SARS-CoV-2 variant in some places at some timepoints [@doi:10.1101/2021.02.06.21251159].
This lineage was estimated to have increased transmissibility of 43 to 90% in the U.K. [@doi:10.1126/science.abg3055].
An estimate of the reproduction number of B.1.1.7 in the U.K. from September to December 2020 yielded 1.59 overall and between 1.56 and 1.95 in different regions of the country [@doi:10.1101/2020.12.30.20249034].
The Delta variant is particularly transmissible, and it has been estimated to be twice as transmissible than the wildtype variant of SARS-CoV-2 [@doi:10.2807/1560-7917.ES.2021.26.24.2100509].
A review of the literature describing the Delta variant identified a mean estimated R~0~ of 5.08 [@doi:10.1093/jtm/taab124].
Such differences can affect fitness and therefore influence the relative contributions of different lineages to a given viral gene pool over time [@doi:10.2807/1560-7917.ES.2021.26.27.2100570].
Therefore, the evolution of the virus can result in shifts in the reproduction rate.

More generally, population-level epidemic dynamics can be both observed and modeled [@doi:10.1126/science.abb5659].
Data and empirically determined biological mechanisms inform models, while models can be used to try to understand data and systems of interest or to make predictions about possible future dynamics, such as the estimation of capacity needs [@doi:10.1073/pnas.2004064117] or the comparison of predicted outcomes among prevention and control strategies [@doi:10/ggp3xq; @doi:10.1073/pnas.2004978117].
Many current efforts to model R~t~ have also led to tools that assist the visualization of estimates in real time or over recent intervals [@url:https://epiforecasts.io/covid; @url:https://rt.live].
These are valuable resources, yet it is also important to note that the estimates arise from models containing many assumptions and are dependent on the quality of the data they use, which varies widely by region.

### Effect of Vaccines on Pathogenesis and Community Spread

The vaccine clinical trial data demonstrate a significant reduction in the likelihood of contracting symptomatic COVID-19, thereby succeeding in the primary goal of vaccination.
The mRNA vaccines in particular were initially so effective in preventing disease that they were also assumed to have an effect on the likelihood of transmission (e.g., venues requiring proof of vaccination).
However, in light of the reduced efficacy in response to VOC, it is especially important to consider whether this assumption is supported by the available evidence.

This question is made up of several components.
The crux is whether vaccinated individuals with a SARS-CoV-2 infection, regardless of symptom status, are as contagious as unvaccinated, infected individuals.
Additionally, as outlined above, an important qualification is that the variants of SARS-CoV-2 circulating at the time of each study must be considered in light of the effect of evolution on vaccine efficacy.

The phase II/III clinical trials evaluating the mRNA vaccines assessed vaccine efficacy based on COVID-19 diagnosis, thereby detecting only patients who received a diagnosis.
In order to identify patients infected with SARS-CoV-2 who did not receive a diagnosis, for example, potentially those who did not develop symptoms, it would be necessary to conduct routine PCR testing even in the absence of symptoms. <!-- Define PCR? -->
Prior to the development of vaccines, the evidence suggested that asymptomatic individuals could spread SARS-CoV-2.
Investigation of viral dynamics of asymptomatic infection in early 2020 indicated that asymptomatic patients continued to shed the virus for a duration similar to that of symptomatic patients [@doi:10.1016/j.ijid.2020.05.030] (although viral shedding should not be conflated with contagiousness without further investigation).
Another study found viral load to be higher in the nasopharyngeal/oropharyngeal samples of asymptomatic patients compared to symptomatic patients hospitalized due to symptoms and/or known exposure [@doi:10.1007/s15010-020-01548-8].
However, the sample size in both of these studies was small, and a larger study found higher viral load in symptomatic than asymptomatic cases [@doi:10.3390/v13020304] along with a systematic review finding a reduced probability of asymptomatic transmission [@doi:10.3138/jammi-2020-0030].
While far from conclusive, these studies suggest that asymptomatic cases still cary a risk of transmitting SARS-CoV-2.

One important consideration is therefore how likely vaccinated individuals are to develop asymptomatic SARS-CoV-2.
Considering asymptomatic cases is necessary to establish a more complete picture of efficacy with respect to spread.<!-- To Do: Possible figure indicating pyramid of risk with and without vaccines?-->
Routine testing of healthcare workers in California who had received an mRNA vaccine revealed slightly higher rates of absolute risk for testing positive than those identified in the phase II/III trials, although the extent to which asymptomatic infection influenced these numbers was not investigated [@doi:10.1056/NEJMc2101927].
Another study analyzed the results of COVID-19 screening tests administered to asymptomatic individuals prior to receiving certain medical services at the Mayo Clinic in several locations across the United States.
This study found patients who had received two doses of an mRNA vaccine to be 73% less likely to have asymptomatic COVID-19 than patients who had received zero doses [@doi:10.1093/cid/ciab229].
Because this study began on December 17, 2020, a date selected to coincide with the first day vaccines were available at the Mayo Clinic, this number may underestimate the efficacy of the vaccines given that many people eligible for early vaccination were at increased risk for exposure (e.g., healthcare workers and residents of long-term care facilities) [@doi:10.1093/cid/ciab229].
In Israel, a longitudinal study of nearly 12,000 healthcare workers found that of the 5,372 fully vaccinated people with Pfizer/BioNTech BNT162b2, 8 developed symptomatic COVID-19 (0.15%) and 19 developed asymptomatic COVID-19 (0.35%) [@doi:10.1001/jama.2021.7152].
While the study itself analyzed the efficacy of the vaccine based on person-days, these findings also suggest that many or even the majority of SARS-CoV-2 infections in vaccinated individuals are likely to be asymptomatic.
Therefore, in addition to the symptomatic cases reported by the vaccine clinical trials, these findings suggest that asymptomatic cases can also occur in vaccinated people.
In the absence of symptoms, individuals are less likely to know to self-isolate, and therefore evaluating the effect of the vaccine on viral load is critical to understanding the role vaccinated individuals can play in spreading SARS-CoV-2.

Another question of interest is therefore whether vaccinated individuals positive for SARS-CoV-2 carry a similar viral load to unvaccinated individuals.
Viral load is often approximated by cycle threshold (C~t~), or the cycle at which viral presence is detected during RT-qPCR, with a lower C~t~ corresponding to a greater viral load.
A prospective cohort study that evaluated front-line workers in six U.S. states from December 2020 to April 2021 reported a 40% reduction in viral load even with just a single dose of an mRNA vaccine [@doi:10.1056/nejmoa2107058].
The vaccine also appeared to influence the time to viral clearance: the risk of having detectable levels of SARS-CoV-2 for more than one week was reduced by 66% in participants who had received at least one dose [@doi:10.1056/nejmoa2107058].
However, this study compared the mean viral load across the two groups, meaning that these findings cannot be extrapolated across all points in the disease course.
Similarly, between December 2020 and February 2021, positive RT-qPCR tests were analyzed for almost 5,000 Israeli patients [@doi:10.1038/s41591-021-01316-7].
C~t~ was analyzed relative to when each patient received the first dose of the Pfizer mRNA vaccine.
A sharp increase in C~t~ (corresponding to reduced viral load) was observed between days 11 and 12, consistent with what is known about the onset of immunity following vaccination.
This pattern therefore suggested a direct effect of vaccination on viral load.

Other studies, however, have not offered support for a reduced viral load in breakthrough cases.
In Singapore, which has strict protocols for screening individuals with potential COVID-19 exposure, a retrospective cohort of patients who tested positive for SARS-CoV-2 between April and June 2021 was analyzed to compare viral kinetics and symptom course between vaccinated and unvaccinated cases.
Vaccinated individuals who tested positive experienced fewer symptoms than unvaccinated, SARS-CoV-2-positive individuals and were more likely to be asymptomatic [@doi:10.1101/2021.07.28.21261295].
Additionally, this study analyzed C~t~ over time and found that, though the median values were similar between the two groups at disease onset, viral load appeared to decrease more rapidly in vaccinated cases [@doi:10.1101/2021.07.28.21261295].
This study is likely to have evaluated a more accurate representation of all COVID-19 outcomes than has been feasible in most studies, but one limitation was that the RT-PCR reactions were conducted in many different facilities.
A third study investigated viral load (as approximated by C~t~) using samples processed in a single laboratory during the summer of 2021 [@doi:10.1101/2021.07.31.21261387].
This study identified no significant differences in C~t~ between fully vaccinated and unvaccinated cases, but this study used samples sent for diagnosis and was not longitudinal.
It offered the additional benefit of culturing samples to assess whether their C~t~ threshold was likely to represent contagiousness and found that SARS-CoV-2 could be cultured from 51 of 55 samples with C~t~ less than 25 (the cut-off used in many studies).
Another study of samples collected at two sites in San Francisco, one of which tested only asymptomatic individuals, reported no difference in C~t~ between asymptomatic and symptomatic cases regardless of whether vaccination status was included in the model [@doi:10.1101/2021.09.28.21264262].
Though each of these three studies offers distinct strengths and weaknesses, taken together, they suggest that viral load is likely to be similar in vaccinated and unvaccinated individuals, but that vaccinated individuals clear the virus more rapidly, meaning that the average viral load is lower over time.

Given the emergence of VOC, especially the Delta and Omicron variants, for which breakthrough infections are more common, the potential for vaccinated individuals to spread SARS-CoV-2 is not static over time.
In fact, studies reporting reduced viral load in vaccinated individuals collected samples, for the most part, prior to the emergence of the Delta variant's dominance.
The emergence of this variant may partially account for why more recent studies tend to find no difference between viral load in vaccinated and unvaccinated cases.

Taken together, these findings can provide some insight into how vaccines influence community spread.
While vaccinated individuals may be more likely to experience asymptomatic infection, current evidence about viral load in asymptomatic versus symptomatic cases is ambiguous.
Similarly, no conclusions can be drawn about whether viral load is different in vaccinated versus unvaccinated cases.
Therefore, at present, the evidence suggests that vaccinated individuals who are infected can still contribute to community spread.
The one potential mitigating factor supported at present is that differences in the viral kinetics may result in vaccinated cases infecting fewer individuals over time due to a more rapid decrease in viral load [@doi:10.1101/2021.07.28.21261295], although this study did not examine patterns in secondary transmission.
Thus, the virological evidence suggests that public health measures such as masking and distancing remain important even in areas with high vaccination rates.

### Conclusions

The novel coronavirus SARS-CoV-2 is the third HCoV to emerge in the 21st century, and research into previous HCoVs has provided a strong foundation for characterizing the pathogenesis and transmission of SARS-CoV-2.
Critical insights into how the virus interacts with human cells have been gained from previous research into HCoVs and other viral infections.
With the emergence of three devastating HCoV over the past twenty years, emergent viruses are likely to represent an ongoing threat.
Contextualizing SARS-CoV-2 alongside other viruses serves not only to provide insights that can be immediately useful for combating this virus itself but may also prove valuable in the face of future viral threats.

Host-pathogen interactions provide a basis not only for understanding COVID-19, but also for developing a response.
As with other HCoVs, the immune response to SARS-CoV-2 is likely driven by detection of its spike protein, which allows it to enter cells through ACE2.
Epithelial cells have also emerged as the major cellular target of the virus, contextualizing the respiratory and gastrointestinal symptoms that are frequently observed in COVID-19.
Many of the mechanisms that facilitate the pathogenesis of SARS-CoV-2 are currently under consideration as possible targets for the treatment or prevention of COVID-19 [@individual-pharmaceuticals; @individual-nutraceuticals].
Research in other viruses also provides a foundation for understanding the transmission of SARS-CoV-2 among people and can therefore inform efforts to control the virus's spread.
Airborne forms of transmission (droplet and aerosol transmission) have emerged as the primary modes by which the virus spreads to new hosts.
Asymptomatic transmission was also a concern in the SARS outbreak of 2002-03 and, as in the current pandemic, presented challenges for estimating rates of infection [@doi:10.1098/rstb.2004.1490].
These insights are important for developing a public health response, such as the CDC's shift in its recommendations surrounding masking [@url:https://www.latimes.com/science/story/2021-07-27/timeline-cdc-mask-guidance-during-covid-19-pandemic].

Even with the background obtained from research in SARS and MERS, COVID-19 has revealed itself to be a complex and difficult-to-characterize disease that has many possible presentations that vary with age.
Variability in presentation, including cases with no respiratory symptoms or with no symptoms altogether, were also reported during the SARS epidemic at the beginning of the 21st century [@doi:10.1098/rstb.2004.1490].
The variability of both which symptoms present and their severity have presented challenges for public health agencies seeking to provide clear recommendations regarding which symptoms indicate SARS-CoV-2 infection and should prompt isolation.
Asymptomatic cases add complexity both to efforts to estimate statistics such as R~0~ and R~t~, which are critical to understanding the transmission of the virus, and IFR, which is an important component of understanding its impact on a given population.
The development of diagnostic technologies over the course of the pandemic has facilitated more accurate identification, including of asymptomatic cases [@individual-diagnostics].
As more cases have been diagnosed, the health conditions and patient characteristics associated with more severe infection have also become more clear, although there are likely to be significant sociocultural elements that also influence these outcomes [@individual-inequality].
While many efforts have focused on adults, and especially older adults because of the susceptibility of this demographic, additional research is needed to understand the presentation of COVID-19 and MIS-C in pediatric patients.
As more information is uncovered about the pathogenesis of HCoV and SARS-CoV-2 specifically, the diverse symptomatology of COVID-19 has and likely will continue to conform with the ever-broadening understanding of how SARS-CoV-2 functions within a human host.

While the SARS-CoV-2 virus is very similar to other HCoV in several ways, including in its genomic structure and the structure of the virus itself, there are also some differences that may account for differences in the COVID-19 pandemic compared to the SARS and MERS epidemics of the past two decades.
The R~0~ of SARS-CoV-2 has been estimated to be similar to SARS-CoV-1 but much higher than that of MERS-CoV [@doi:10.1093/ajcp/aqaa029], although a higher R~0~ has been estimated for some VOC.
While the structures of the viruses are very similar, evolution among these species may account for differences in their transmissibility and virulence.
For example, the acquisition of a furin cleavage site the S1/S2 boundary within the SARS-CoV-2 S protein may be associated with increased virulence.
Additionally, concerns have been raised about the accumulation of mutations within the SARS-CoV-2 species itself, and whether these could influence virulence [@individual-evolution].
These novel variants may be resistant to vaccines and antibody treatments such as Bamlanivimab that were designed based on the wildtype spike protein [@individual-pharmaceuticals; @individual-vaccines-novel].
As a consequence of reliance on targeting the SARS-CoV-2 spike protein for many therapeutic and prophylactic strategies, increased surveillance is required to rapidly identify and prevent the spread of novel SARS-CoV-2 variants with alterations to the spike protein.
The coming of age of genomic technologies has made these types of analyses feasible, and genomics research characterizing changes in SARS-CoV-2 along with temporal and spatial movement is likely to provide additional insights into whether within-species evolution influences the effect of the virus on the human host.
Additionally, the rapid development of sequencing technologies over the past decade has made it possible to rapidly characterize the host response to the virus.
For example, proteomics analysis of patient-derived cells revealed candidate genes whose regulation is altered by SARS-CoV-2 infection, suggesting possible approaches for pharmaceutical invention and providing insight into which systems are likely to be disrupted in COVID-19 [@doi:10.1101/2020.03.31.019216].
As more patient data becomes available, the biotechnological advances of the 2000s are expected to allow for more rapid identification of potential drug targets than was feasible during the SARS, or even MERS, pandemic.

Thus, the COVID-19 crisis continues to evolve, but the insights acquired over the past 20 years of HCoV research have provided a solid foundation for understanding the SARS-CoV-2 virus and the disease it causes.
As the scientific community continues to respond to COVID-19 and to elucidate more of the relationships between pathogenesis, transmission, host regulatory responses, and symptomatology, this understanding will no doubt continue to evolve and to reveal additional connections among virology, pathogenesis, and health.
This review represents a collaboration between scientists from diverse backgrounds to contextualize this virus at the union of many different biological disciplines [@individual-methods].
At present, understanding the SARS-CoV-2 virus and its pathogenesis is critical to a holistic understanding of the COVID-19 pandemic.
In the future, interdisciplinary work on SARS-CoV-2 and COVID-19 may guide a response to a new viral threat.
