## Appendix: Identification and Development of Therapeutics for COVID-19

### Dexamethasone

In order to understand how dexamethasone reduces inflammation, it is necessary to consider the stress response broadly.
In response to stress, corticotropin‐releasing hormone stimulates the release of neurotransmitters known as catecholamines, such as epinephrine, and steroid hormones known as glucocorticoids, such as cortisol [@doi:10.1016/j.cyto.2015.01.008; @doi:10.1111/j.1749-6632.2002.tb04229.x].
While catecholamines are often associated with the fight-or-flight response, the specific role that glucocorticoids play is less clear, although they are thought to be important to restoring homeostasis [@doi:10.1159/000054578].
Immune challenge is a stressor that is known to interact closely with the stress response.
The immune system can therefore interact with the central nervous system; for example, macrophages can both respond to and produce catecholamines [@doi:10.1016/j.cyto.2015.01.008].
Additionally, the production of both catecholamines and glucocorticoids is associated with inhibition of proinflammatory cytokines such as IL-6, IL-12, and tumor necrosis factor-&alpha; (TNF‐&alpha;) and the stimulation of anti-inflammatory cytokines such as IL-10, meaning that the stress response can regulate inflammatory immune activity [@doi:10.1111/j.1749-6632.2002.tb04229.x].
Administration of dexamethasone has been found to correspond to dose-dependent inhibition of IL-12 production, but not to affect IL-10 [@PMID:8902882]; the fact that this relationship could be disrupted by administration of a glucocorticoid-receptor antagonist suggests that it is regulated by the receptor itself [@PMID:8902882].
Thus, the administration of dexamethasone for COVID-19 is likely to simulate the release of glucocorticoids endogenously during stress, resulting in binding of the synthetic steroid to the glucocorticoid receptor and the associated inhibition of the production of proinflammatory cytokines.
In this model, dexamethasone reduces inflammation by stimulating the biological mechanism that reduces inflammation following a threat such as immune challenge.

Initial support for dexamethasone as a treatment for COVID-19 came from the United Kingdom's RECOVERY trial [@doi:10.1101/2020.06.22.20137273], which assigned over 6,000 hospitalized COVID-19 patients to the standard of care (SOC) or treatment (dexamethasone) arms of the trial at a 2:1 ratio.
At the time of randomization, some patients were ventilated (16%), others were on non-invasive oxygen (60%), and others were breathing independently (24%).
Patients in the treatment arm were administered dexamethasone either orally or intravenously at 6 mg per day for up to 10 days.
The primary end-point was the patient's status at 28-days post-randomization (mortality, discharge, or continued hospitalization), and secondary outcomes analyzed included the progression to invasive mechanical ventilation over the same period.
The 28-day mortality rate was found to be lower in the treatment group than in the SOC group (21.6% vs 24.6%, _p_ < 0.001).
However, the effect was driven by improvements in patients receiving mechanical ventilation or supplementary oxygen.
One possible confounder is that patients receiving mechanical ventilation tended to be younger than patients who were not receiving respiratory support (by 10 years on average) and to have had symptoms for a longer period.
However, adjusting for age did not change the conclusions, although the duration of symptoms was found to be significantly associated with the effect of dexamethasone administration.
Thus, this large, randomized, and multi-site, albeit not placebo-controlled, study suggests that administration of dexamethasone to patients who are unable to breathe independently may significantly improve survival outcomes.
Additionally, dexamethasone is a widely available and affordable medication, raising the hope that it could be made available to COVID-19 patients globally.

It is not surprising that administration of an immunosuppressant would be most beneficial in severe cases where the immune system was dysregulated towards inflammation.
However, it is also unsurprising that care must be taken in administering an immunosuppressant to patients fighting a viral infection.
In particular, the concern has been raised that treatment with dexamethasone might increase patient susceptibility to concurrent (e.g., nosocomial) infections [@doi:10.23812/20-EDITORIAL_1-5].
Additionally, the drug could potentially slow viral clearance and inhibit patients' ability to develop antibodies to SARS-CoV-2 [@doi:10.23812/20-EDITORIAL_1-5; @doi:10/ggks86], with the lack of data about viral clearance being put forward as a major limitation of the RECOVERY trial [@doi:10/ftk4].
Furthermore, dexamethasone has been associated with side effects that include psychosis, glucocorticoid-induced diabetes, and avascular necrosis [@doi:10/ggks86], and the RECOVERY trial did not report outcomes with enough detail to be able to determine whether they observed similar complications.
The effects of dexamethasone have also been found to differ among populations, especially in high-income versus middle- or low-income countries [@doi:10/gg42kx].
However, since the RECOVERY trial's results were released, strategies have been proposed for administering dexamethasone alongside more targeted treatments to minimize the likelihood of negative side effects [@doi:10.23812/20-EDITORIAL_1-5].
Given the available evidence, dexamethasone is currently the most promising treatment for severe COVID-19.

### Favipiravir

The effectiveness of favipiravir for treating patients with COVID-19 is currently under investigation.
Evidence for the drug inhibiting viral RNA polymerase are based on time-of-drug addition studies that found that viral loads were reduced with the addition of favipiravir in early times post-infection [@doi:10.1128/AAC.49.3.981-986.2005; @doi:10.1016/j.bbrc.2012.07.034; @doi:10.1128/AAC.01219-10].
An open-label, nonrandomized, before-after controlled study for COVID-19 was recently conducted [@doi:10.1016/j.eng.2020.03.007].
The study included 80 COVID-19 patients (35 treated with favipiravir, 45 control) from the isolation ward of the National Clinical Research Center for Infectious Diseases (The Third People’s Hospital of Shenzhen), Shenzhen, China.
The patients in the control group were treated with other antivirals, such as lopinavir and ritonavir.
It should be noted that although the control patients received antivirals, two subsequent large-scale analyses, the WHO Solidarity trial and the Randomized Evaluation of COVID-19 Therapy (RECOVERY) trial, identified no effect of lopinavir or of a lopinavir-ritonavir combination, respectively, on the metrics of COVID-19-related mortality that each assessed [@doi:10.1056/NEJMoa2023184; @doi:10/fnx2; @doi:10.1056/NEJMe2034294].
Treatment was applied on days 2-14; treatment stopped either when viral clearance was confirmed or at day 14.
The efficacy of the treatment was measured by, first, the time until viral clearance using Kaplan-Meier survival curves, and, second, the improvement rate of chest computed tomography (CT) scans on day 14 after treatment.
The study found that favipiravir increased the speed of recovery, measured as viral clearance from the patient by RT-PCR, with patients receiving favipiravir recovering in four days compared to 11 days for patients receiving antivirals such as lopinavir and ritonavir.
Additionally, the lung CT scans of patients treated with favipiravir showed significantly higher improvement rates (91%) on day 14 compared to control patients (62%, _p_ = 0.004).
However, there were adverse side effects in 4 (11%) favipiravir-treated patients and 25 (56%) control patients.
The adverse side effects included diarrhea, vomiting, nausea, rash, and liver and kidney injury.
Despite the study reporting clinical improvement in favipiravir-treated patients, several study design issues are problematic and lower confidence in the overall conclusions.
For example, the study was neither randomized nor blinded.
Moreover, the selection of patients did not take into consideration important factors such as previous clinical conditions or sex, and there was no age categorization.
Additionally, it should be noted that this study was temporarily retracted and then restored without an explanation [@url:https://retractionwatch.com/retracted-coronavirus-covid-19-papers].

In late 2020 and early 2021, the first randomized controlled trials of favipiravir for the treatment of COVID-19 released results [@doi:10.1016/j.ejps.2020.105631; @doi:10.1007/s00705-021-04956-9; @doi:10.1093/cid/ciaa1176].
One study [@doi:10.1007/s00705-021-04956-9] was retracted in November 2021 due to concerns about the data.
Of the two remaining, the first [@doi:10.1016/j.ejps.2020.105631] used a randomized, controlled, open-label design to compare two drugs, favipiravir and baloxavir marboxil, to SOC alone.
Here, SOC included antivirals such as lopinavir/ritonavir and was administered to all patients.
The primary endpoint analyzed was viral clearance at day 14.
The sample size for this study was very small, with 29 total patients enrolled, and no significant effect of the treatments was found for the primary or any of the secondary outcomes analyzed, which included mortality.
The second trial examined 60 patients and reported a significant effect of favipiravir on viral clearance at four days (a secondary endpoint), but not at 10 days (the primary endpoint) [@doi:10.1093/cid/ciaa1176].
This study, as well as a prior study of favipiravir [@doi:10/ftgm], also reported that the drug was generally well-tolerated.
Thus, in combination, these small studies suggest that the effects of favipiravir as a treatment for COVID-19 cannot be determined based on the available evidence, but additionally, none raise major concerns about the safety profile of the drug.

### Remdesivir

At the outset of the COVID-19 pandemic, remdesivir did not have any have any FDA-approved use.
A clinical trial in the Democratic Republic of Congo found some evidence of effectiveness against ebola virus disease (EVD), but two antibody preparations were found to be more effective, and remdesivir was not pursued [@doi:10.1056/NEJMoa1910993].
Remdesivir also inhibits polymerase and replication of the coronaviruses MERS-CoV and SARS-CoV-1 in cell culture assays with submicromolar IC50s [@doi:10.1126/scitranslmed.aal3653].
It has also been found to inhibit SARS-CoV-2, showing synergy with CQ _in vitro_ [@doi:10.1038/s41422-020-0282-0].

Remdesivir was first used on some COVID-19 patients under compassionate use guidelines [@doi:10.1126/science.abb7243, @doi:10.1056/NEJMoa2001191; @doi:10.1101/2020.03.09.20032896].
All were in late stages of COVID-19 infection, and initial reports were inconclusive about the drug's efficacy.
Gilead Sciences, the maker of remdesivir, led a recent publication that reported outcomes for compassionate use of the drug in 61 patients hospitalized with confirmed COVID-19.
Here, 200 mg of remdesivir was administered intravenously on day 1, followed by a further 100 mg/day for 9 days [@doi:10.1056/NEJMoa2007016].
There were significant issues with the study design, or lack thereof.
There was no randomized control group.
The inclusion criteria were variable: some patients only required low doses of oxygen, while others required ventilation.
The study included many sites, potentially with variable inclusion criteria and treatment protocols.
The patients analyzed had mixed demographics.
There was a short follow-up period of investigation.
Eight patients were excluded from the analysis mainly due to missing post-baseline information; thus, their health was unaccounted for.
Therefore, even though the study reported clinical improvement in 68% of the 53 patients ultimately evaluated, due to the significant issues with study design, it could not be determined whether treatment with remdesivir had an effect or whether these patients would have recovered regardless of treatment.
Another study comparing 5- and 10-day treatment regimens reported similar results but was also limited because of the lack of a placebo control [@doi:10.1056/NEJMoa2015301].
These studies did not alter the understanding of the efficacy of remdesivir in treating COVID-19, but the encouraging results provided motivation for placebo-controlled studies.

The double-blind placebo-controlled ACTT-1 trial [@doi:10.1056/NEJMoa2007764; @clinicaltrials:NCT04280705] recruited 1,062 patients and randomly assigned them to placebo treatment or treatment with remdesivir.
Patients were stratified for randomization based on site and the severity of disease presentation at baseline [@doi:10.1056/NEJMoa2007764].
The treatment was 200 mg on day 1, followed by 100 mg on days 2 through 10.
Data was analyzed from a total of 1,059 patients who completed the 29-day course of the trial, with 517 assigned to remdesivir and 508 to placebo [@doi:10.1056/NEJMoa2007764].
The two groups were well matched demographically and clinically at baseline.
Those who received remdesivir had a median recovery time of 10 days, as compared with 15 days in those who received placebo (rate ratio for recovery, 1.29; 95% confidence interval (CI), 1.12 to 1.49; _p_ < 0.001).
The Kaplan-Meier estimates of mortality by 14 days were 6.7% with remdesivir and 11.9% with placebo, with a hazard ratio (HR) for death of 0.55 and a 95% CI of 0.36 to 0.83, and at day 29, remdesivir corresponded to 11.4% and the placebo to 15.2% (HR: 0.73; 95% CI, 0.52 to 1.03).
Serious adverse events were reported in 131 of the 532 patients who received remdesivir (24.6%) and in 163 of the 516 patients in the placebo group (31.6%).
This study also reported an association between remdesivir administration and both clinical improvement and a lack of progression to more invasive respiratory intervention in patients receiving non-invasive and invasive ventilation at randomization [@doi:10.1056/NEJMoa2007764].
Largely on the results of this trial, the FDA reissued and expanded the EUA for remdesivir for the treatment of hospitalized COVID-19 patients ages twelve and older [@url:https://www.fda.gov/media/137564/download].
Additional clinical trials [@doi:10.1038/s41422-020-0282-0; @clinicaltrials:NCT04292730; @url:https://www.clinicaltrialsregister.eu/ctr-search/trial/2020-000936-23/FR; @clinicaltrials:NCT04252664; @clinicaltrials:NCT04257656] are currently underway to evaluate the use of remdesivir to treat COVID-19 patients at both early and late stages of infection and in combination with other drugs (Figure @fig:ebm-trials).
As of October 22, 2020, remdesivir received FDA approval based on three clinical trials [@url:https://www.fda.gov/news-events/press-announcements/fda-approves-first-treatment-covid-19].

However, results suggesting no effect of remdesivir on survival were reported by the WHO Solidarity trial [@doi:10.1056/NEJMoa2023184].
Patients were randomized in equal proportions into four experimental conditions and a control condition, corresponding to four candidate treatments for COVID-19 and SOC, respectively; no placebo was administered.
The 2,750 patients in the remdesivir group were administered 200 mg intravenously on the first day and 100 mg on each subsequent day until day 10 and assessed for in-hospital death (primary endpoint), duration of hospitalization, and progression to mechanical ventilation.
There were also 2,708 control patients who would have been eligible and able to receive remdesivir were they not assigned to the control group.
A total of 604 patients among these two cohorts died during initial hospitalization, with 301 in the remdesivir group and 303 in the control group.
The rate ratio of death between these two groups was therefore not significant (0.95, _p_ = 0.50), suggesting that the administration of remdesivir did not affect survival.
The two secondary analyses similarly did not find any effect of remdesivir.
Additionally, the authors compared data from their study with data from three other studies of remdesivir (including [@doi:10.1056/NEJMoa2007764]) stratified by supplemental oxygen status.
A meta-analysis of the four studies yielded an overall rate ratio for death of 0.91 (_p_ = 0.20).
These results thus do not support the previous findings that remdesivir reduced median recovery time and mortality risk in COVID-19 patients.

In response to the results of the Solidarity trial, Gilead, which manufactures remdesivir, released a statement pointing to the fact that the Solidarity trial was not placebo-controlled or double-blind and at the time of release, the statement had not been peer reviewed [@url:https://www.gilead.com/news-and-press/company-statements/gilead-sciences-statement-on-the-solidarity-trial]; these sentiments have been echoed elsewhere [@doi:10.1093/eurheartj/ehaa934].
Other critiques of this study have noted that antivirals are not typically targeted at patients with severe illness, and therefore remdesivir could be more beneficial for patients with mild rather than severe cases [@url:https://www.sciencemag.org/news/2020/10/very-very-bad-look-remdesivir-first-fda-approved-covid-19-drug; @doi:10.1056/NEJMe2034294].
However, the publication associated with the trial sponsored by Gilead did purport an effect of remdesivir on patients with severe disease, identifying an 11 versus 18 day recovery period (rate ratio for recovery: 1.31, 95% CI 1.12 to 1.52) [@doi:10.1056/NEJMoa2007764].
Additionally, a smaller analysis of 598 patients, of whom two-thirds were randomized to receive remdesivir for either 5 or 10 days, reported a small effect of treatment with remdesivir for five days relative to standard of care in patients with moderate COVID-19 [@doi:10.1001/jama.2020.16349].
These results suggest that remdesivir could improve outcomes for patients with moderate COVID-19, but that additional information would be needed to understand the effects of different durations of treatment.
Therefore, the Solidarity trial may point to limitations in the generalizability of other research on remdesivir, especially since the broad international nature of the Solidarity clinical trial, which included countries with a wide range of economic profiles and a variety of healthcare systems, provides a much-needed global perspective in a pandemic [@doi:10.1056/NEJMe2034294].
On the other hand, only 62% of patients in the Solidarity trial were randomized on the day of admission or one day afterwards [@doi:10.1056/NEJMoa2023184], and concerns have been raised that differences in disease progression could influence the effectiveness of remdesivir [@doi:10.1056/NEJMe2034294].
Despite the findings of the Solidarity trial, remdesivir remains available for the treatment of COVID-19 in many places.
Remdesivir has also been investigated in combination with other drugs, such as baricitinib, which is an inhibitor of Janus kinase 1 and 2 [@doi:10.1056/NEJMoa2031994]; the FDA has issued an EUA for the combination of remdesivir and baricitinib in adult and pediatric patients [@url:https://www.fda.gov/media/143822/download].
Follow-up studies are needed and, in many cases, are underway to further investigate remdesivir-related outcomes.

Similarly, the extent to which the remdesivir dosing regimen could influence outcomes continues to be under consideration.
A randomized, open-label trial compared the effect of remdesivir on 397 patients with severe COVID-19 over 5 versus 10 days [@doi:10.1056/NEJMoa2015301; @ClinicalTrials:NCT04292899], complementing the study that found that a 5-day course of remdesivir improved outcomes for patients with moderate COVID-19 but a 10-day course did not [@doi:10.1001/jama.2020.16349].
Patients in the two groups were administered 200 mg of remdesivir intravenously on the first day, followed by 100 mg on the subsequent four or nine days, respectively.
The two groups differed significantly in their clinical status, with patients assigned to the 10-day group having more severe illness.
This study also differed from most because it included not only adults, but also pediatric patients as young as 12 years old.
It reported no significant differences across several outcomes for patients receiving a 5-day or 10-day course, when correcting for baseline clinical status.
The data did suggest that the 10-day course might reduce mortality in the most severe patients at day 14, but the representation of this group in the study population was too low to justify any conclusions [@doi:10.1056/NEJMoa2015301].
Thus, additional research is also required to determine whether the dosage and duration of remdesivir administration influences outcomes.

In summary, remdesivir is the first FDA approved anti-viral against SARS-CoV-2 as well as the first FDA approved COVID-19 treatment.
Early investigations of this drug established proof of principle that drugs targeting the virus can benefit COVID-19 patients.
Moreover, one of the most successful strategies for developing therapeutics for viral diseases is to target the viral replication machinery, which are typically virally encoded polymerases.
Small molecule drugs targeting viral polymerases are the backbones of treatments for other viral diseases including human immunodeficiency virus (HIV) and herpes.
Notably, the HIV and herpes polymerases are a reverse transcriptase and a DNA polymerase, respectively, whereas SARS-CoV-2 encodes an RdRP, so most of the commonly used polymerase inhibitors are not likely to be active against SARS-CoV-2.
In clinical use, polymerase inhibitors show short term benefits for HIV patients, but for long term benefits they must be part of combination regimens.
They are typically combined with protease inhibitors, integrase inhibitors, and even other polymerase inhibitors.
Remdesivir provides evidence that a related approach may be beneficial for the treatment of COVID-19.

### Hydroxychloroquine and Chloroquine

CQ and hydroxychloroquine (HCQ) increase cellular pH by accumulating in their protonated form inside lysosomes [@doi:10.1186/1743-422X-8-163; @doi:10.1111/j.1529-8019.2007.00131.x].
This shift in pH inhibits the breakdown of proteins and peptides by the lysosomes during the process of proteolysis [@doi:10.1111/j.1529-8019.2007.00131.x].
Interest in CQ and HCQ for treating COVID-19 was catalyzed by a mechanism observed in _in vitro_ studies of both SARS-CoV-1 and SARS-CoV-2.
In one study, CQ inhibited viral entry of SARS-CoV-1 into Vero E6 cells, a cell line that was derived from Vero cells in 1968, through the elevation of endosomal pH and the terminal glycosylation of ACE2 [@doi:10.1186/1743-422X-2-69].
Increased pH within the cell, as discussed above, inhibits proteolysis, and terminal glycosylation of ACE2 is thought to interfere with virus-receptor binding.
An _in vitro_ study of SARS-CoV-2 infection of Vero cells found both HCQ and CQ to be effective in inhibiting viral replication, with HCQ being more potent [@doi:10.1093/cid/ciaa237].
Additionally, an early case study of three COVID-19 patients reported the presence of antiphospholipid antibodies in all three patients [@doi:10.1056/NEJMc2007575].
Antiphospholipid antibodies are central to the diagnosis of the antiphospholipid syndrome, a disorder that HCQ has often been used to treat [@doi:10.1182/blood.V128.22.5023.5023; @doi:10.1016/j.autrev.2014.01.053; @doi:10.1182/asheducation-2016.1.714].
Because the 90% effective concentration (EC~90~) of CQ in Vero E6 cells (6.90 μM) can be achieved in and tolerated by rheumatoid arthritis (RA) patients, it was hypothesized that it might also be possible to achieve the effective concentration in COVID-19 patients [@doi:10.1093/jac/dkaa114].
Additionally, clinical trials have reported HCQ to be effective in treating HIV [@doi:10/cq2hx9] and chronic Hepatitis C [@doi:10.1002/jmv.24575].
Together, these studies triggered initial enthusiasm about the therapeutic potential for HCQ and CQ against COVID-19.
HCQ/CQ has been proposed both as a treatment for COVID-19 and a prophylaxis against SARS-CoV-2 exposure, and trials often investigated these drugs in combination with azithromycin (AZ) and/or zinc supplementation.
However, as more evidence has emerged, it has become clear that HCQ/CQ offer no benefits against SARS-CoV-2 or COVID-19.

#### Trials Assessing Therapeutic Administration of HCQ/CQ

The initial study evaluating HCQ as a treatment for COVID-19 patients was published on March 20, 2020 by Gautret et al. [@doi:10.1016/j.ijantimicag.2020.105949].
This non-randomized, non-blinded, non-placebo clinical trial compared HCQ to SOC in 42 hospitalized patients in southern France.
It reported that patients who received HCQ showed higher rates of virological clearance by nasopharyngeal swab on days 3-6 when compared to SOC.
This study also treated six patients with both HCQ + AZ and found this combination therapy to be more effective than HCQ alone.
However, the design and analyses used showed weaknesses that severely limit interpretability of results, including the small sample size and the lack of: randomization, blinding, placebo (no "placebo pill" given to SOC group), Intention-To-Treat analysis, correction for sequential multiple comparisons, and trial pre-registration.
Furthermore, the trial arms were entirely confounded by the hospital and there were false negative outcome measurements (see [@doi:10.5014/ajot.2013.006015]).
Two of these weaknesses are due to inappropriate data analysis and can therefore be corrected _post hoc_ by recalculating the p-values (lack of Intention-To-Treat analysis and multiple comparisons).
However, all other weaknesses are fundamental design flaws and cannot be corrected for.
Thus, the conclusions cannot be generalized outside of the study.
The International Society of Antimicrobial Chemotherapy, the scientific organization that publishes the journal where the article appeared, subsequently announced that the article did not meet its expected standard for publications [@url:https://www.isac.world/news-and-publications/official-isac-statement], although it has not been officially retracted.

Because of the preliminary data presented in this study, HCQ treatment was subsequently explored by other researchers.
About one week later, a follow-up case study reported that 11 consecutive patients were treated with HCQ + AZ using the same dosing regimen [@doi:10.1016/j.medmal.2020.03.006].
One patient died, two were transferred to the intensive care unit (ICU), and one developed a prolonged QT interval, leading to discontinuation of HCQ + AZ administration.
As in the Gautret et al. study, the outcome assessed was virological clearance at day 6 post-treatment, as measured from nasopharyngeal swabs.
Of the ten living patients on day 6, eight remained positive for SARS-CoV-2 RNA.
Like in the original study, interpretability was severely limited by the lack of a comparison group and the small sample size.
However, these results stand in contrast to the claims by Gautret et al. that all six patients treated with HCQ + AZ tested negative for SARS-CoV-2 RNA by day 6 post-treatment.
This case study illustrated the need for further investigation using robust study design to evaluate the efficacy of HCQ and/or CQ.

On April 10, 2020, a randomized, non-placebo trial of 62 COVID-19 patients at the Renmin Hospital of Wuhan University was released [@doi:10.1101/2020.03.22.20040758].
This study investigated whether HCQ decreased time to fever break or time to cough relief when compared to SOC [@doi:10.1101/2020.03.22.20040758].
This trial found HCQ decreased both average time to fever break and average time to cough relief, defined as mild or no cough.
While this study improved on some of the methodological flaws in Gautret et al. by randomizing patients, it also had several flaws in trial design and data analysis that prevent generalization of the results.
These weaknesses include the lack of placebo, lack of correction for multiple primary outcomes, inappropriate choice of outcomes, lack of sufficient detail to understand analysis, drastic disparities between pre-registration [@cctr-hcq] and published protocol (including differences in the inclusion and exclusion criteria, the number of experimental groups, the number of patients enrolled, and the outcome analyzed), and small sample size.
The choice of outcomes may be inappropriate as both fevers and cough may break periodically without resolution of illness.
Additionally, for these outcomes, the authors reported that 23 of 62 patients did not have a fever and 25 of 62 patients did not have a cough at the start of the study, but the authors failed to describe how these patients were included in a study assessing time to fever break and time to cough relief.
It is important to note here that the authors claimed "neither the research performers nor the patients were aware of the treatment assignments."
This blinding seems impossible in a non-placebo trial because at the very least, providers would know whether they were administering a medication or not, and this knowledge could lead to systematic differences in the administration of care.
Correction for multiple primary outcomes can be adjusted _post hoc_ by recalculating p-values, but all of the other issues were design and statistical weaknesses that cannot be corrected for.
Additionally, disparities between the pre-registered and published protocols raise concerns about experimental design.
The design limitations mean that the conclusions cannot be generalized outside of the study.

A second randomized trial, conducted by the Shanghai Public Health Clinical Center, analyzed whether HCQ increased rates of virological clearance at day 7 in respiratory pharyngeal swabs compared to SOC [@doi:10/drbx].
This trial was published in Chinese along with an abstract in English, and only the English abstract was read and interpreted for this review.
The trial found comparable outcomes in virological clearance rate, time to virological clearance, and time to body temperature normalization between the treatment and control groups.
The small sample size is one weakness, with only 30 patients enrolled and 15 in each arm.
This problem suggests the study is underpowered to detect potentially useful differences and precludes interpretation of results.
Additionally, because only the abstract could be read, other design and analysis issues could be present.
Thus, though these studies added randomization to their assessment of HCQ, their conclusions should be interpreted very cautiously.
These two studies assessed different outcomes and reached differing conclusions about the efficacy of HCQ for treating COVID-19; the designs of both studies, especially with respect to sample size, meant that no general conclusions can be made about the efficacy of the drug.

Several widely reported studies on HCQ also have issues with data integrity and/or provenance.
A Letter to the Editor published in _BioScience Trends_ on March 16, 2020 claimed that numerous clinical trials have shown that HCQ is superior to control treatment in inhibiting the exacerbation of COVID-19 pneumonia [@doi:10.5582/bst.2020.01047].
This letter has been cited by numerous primary literature, review articles, and media alike [@doi:10.7150/ijbs.45498; @doi:10.7150/ijbs.45053].
However, the letter referred to 15 pre-registration identifiers from the Chinese Clinical Trial Registry.
When these identifiers are followed back to the registry, most trials claim they are not yet recruiting patients or are currently recruiting patients.
For all of these 15 identifiers, no data uploads or links to publications could be located on the pre-registrations.
At the very least, the lack of availability of the primary data means the claim that HCQ is efficacious against COVID-19 pneumonia cannot be verified.
Similarly, a recent multinational registry analysis [@doi:10/ggwzsb] analyzed the efficacy of CQ and HCQ with and without a macrolide, which is a class of antibiotics that includes Azithromycin, for the treatment of COVID-19.
The study observed 96,032 patients split into a control and four treatment conditions (CQ with and without a macrolide; HCQ with and without a macrolide).
They concluded that treatment with CQ or HCQ was associated with increased risk of _de novo_ ventricular arrhythmia during hospitalization.
However, this study has since been retracted by _The Lancet_ due to an inability to validate the data used [@doi:10/ggzqng].
These studies demonstrate that increased skepticism in evaluation of the HCQ/CQ and COVID-19 literature may be warranted, possibly because of the significant attention HCQ and CQ have received as possible treatments for COVID-19 and the politicization of these drugs.

Despite the fact that the study suggesting that CQ/HCQ increased risk of ventricular arrhythmia in COVID-19 patients has now been retracted, previous studies have identified risks associated with HCQ/CQ.
A patient with systemic lupus erythematosus developed a prolonged QT interval that was likely exacerbated by use of HCQ in combination with renal failure [@doi:10.1155/2016/4626279].
A prolonged QT interval is associated with ventricular arrhythmia [@doi:10.1016/j.hrthm.2008.05.008].
Furthermore, a separate study [@doi:10.1101/2020.04.08.20054551] investigated the safety associated with the use of HCQ with and without macrolides between 2000 and 2020.
The study involved 900,000 cases treated with HCQ and 300,000 cases treated with HCQ + AZ.
The results indicated that short-term use of HCQ was not associated with additional risk, but that HCQ + AZ was associated with an enhanced risk of cardiovascular complications (such as a 15% increased risk of chest pain, calibrated HR = 1.15, 95% CI, 1.05 to 1.26) and a two-fold increased 30-day risk of cardiovascular mortality (calibrated HR = 2.19; 95% CI, 1.22 to 3.94).
Therefore, whether studies utilize HCQ alone or HCQ in combination with a macrolide may be an important consideration in assessing risk.
As results from initial investigations of these drug combinations have emerged, concerns about the efficacy and risks of treating COVID-19 with HCQ and CQ have led to the removal of CQ/HCQ from SOC practices in several countries [@doi:10.1101/2020.04.07.20056424; @url:https://www.cnn.com/2020/04/13/health/chloroquine-risks-coronavirus-treatment-trials-study/index.html].
As of May 25, 2020, WHO had suspended administration of HCQ as part of the worldwide Solidarity Trial [@raw:WHO_briefing_2020_5_25], and later the final results of this large-scale trial that compared 947 patients administered HCQ to 906 controls revealed no effect on the primary outcome, mortality during hospitalization (rate ratio: 1.19; _p_ = 0.23)

Additional research has emerged largely identifying HCQ/CQ to be ineffective against COVID-19 while simultaneously revealing a number of significant side effects.
A randomized, open-label, non-placebo trial of 150 COVID-19 patients was conducted in parallel at 16 government-designated COVID-19 centers in China to assess the safety and efficacy of HCQ [@doi:10.1101/2020.04.10.20060558].
The trial compared treatment with HCQ in conjunction with SOC to SOC alone in 150 infected patients who were assigned randomly to the two groups (75 per group).
The primary endpoint of the study was the negative conversion rate of SARS-CoV-2 in 28 days, and the investigators found no difference in this parameter between the groups (estimated difference between SOC plus HCQ and SOC 4.1%; 95% CI, –10.3% to 18.5%).
The secondary endpoints were an amelioration of the symptoms of the disease such as axillary temperature ≤36.6°C, SpO2 >94% on room air, and disappearance of symptoms like shortness of breath, cough, and sore throat.
The median time to symptom alleviation was similar across different conditions (19 days in HCQ + SOC versus 21 days in SOC, _p_ = 0.97).
Additionally, 30% of the patients receiving SOC+HCQ reported adverse outcomes compared to 8.8% of patients receiving only SOC, with the most common adverse outcome in the SOC+HCQ group being diarrhea (10% versus 0% in the SOC group, _p_ = 0.004).
However, there are several factors that limit the interpretability of this study.
Most of the enrolled patients had mild-to-moderate symptoms (98%), and the average age was 46.
SOC in this study included the use of antivirals (Lopinavir-Ritonavir, Arbidol, Oseltamivir, Virazole, Entecavir, Ganciclovir, and Interferon alfa), which the authors note could influence the results.
Thus, they note that an ideal SOC would need to exclude the use of antivirals, but that ceasing antiviral treatment raised ethical concerns at the time that the study was conducted.
In this trial, the samples used to test for the presence of the SARS-CoV-2 virus were collected from the upper respiratory tract, and the authors indicated that the use of upper respiratory samples may have introduced false negatives (e.g., [@doi:10.1001/jama.2020.3786]).
Another limitation of the study that the authors acknowledge was that the HCQ treatment began, on average, at a 16-day delay from the symptom onset.
The fact that this study was open-label and lacked a placebo limits interpretation, and additional analysis is required to determine whether HCQ reduces inflammatory response.
Therefore, despite some potential areas of investigation identified in _post hoc_ analysis, this study cannot be interpreted as providing support for HCQ as a therapeutic against COVID-19.
This study provided no support for HCQ against COVID-19, as there was no difference between the two groups in either negative seroconversion at 28 days or symptom alleviation, and in fact, more severe adverse outcomes were reported in the group receiving HCQ.

Additional evidence comes from a retrospective analysis [@doi:10.1101/2020.04.16.20065920] that examined data from 368 COVID-19 patients across all United States Veteran Health Administration medical centers.
The study retrospectively investigated the effect of the administration of HCQ (n=97), HCQ + AZ (n=113), and no HCQ (n=158) on 368 patients.
The primary outcomes assessed were death and the need for mechanical ventilation.
Standard supportive care was rendered to all patients.
Due to the low representation of women (N=17) in the available data, the analysis included only men, and the median age was 65 years.
The rate of death was 27.8% in the HCQ-only treatment group, 22.1% in the HCQ + AZ treatment group, and 14.1% in the no-HCQ group.
These data indicated a statistically significant elevation in the risk of death for the HCQ-only group compared to the no-HCQ group (adjusted HR: 2.61, _p_ = 0.03), but not for the HCQ + AZ group compared to the no-HCQ group (adjusted HR: 1.14; _p_ = 0.72).
Further, the risk of ventilation was similar across all three groups (adjusted HR: 1.43, _p_ = 0.48 (HCQ) and 0.43, _p_ = 0.09 (HCQ + AZ) compared to no HCQ).
The study thus showed evidence of an association between increased mortality and HCQ in this cohort of COVID-19 patients but no change in rates of mechanical ventilation among the treatment conditions.
The study had a few limitations: it was not randomized, and the baseline vital signs, laboratory tests, and prescription drug use were significantly different among the three groups.
All of these factors could potentially influence treatment outcome.
Furthermore, the authors acknowledge that the effect of the drugs might be different in females and pediatric subjects, since these subjects were not part of the study.
The reported result that HCQ + AZ is safer than HCQ contradicts the findings of the previous large-scale analysis of twenty years of records that found HCQ + AZ to be more frequently associated with cardiac arrhythmia than HCQ alone [@doi:10.1101/2020.04.08.20054551]; whether this discrepancy is caused by the pathology of COVID-19, is influenced by age or sex, or is a statistical artifact is not presently known.

Finally, findings from the RECOVERY trial were released on October 8, 2020.
This study used a randomized, open-label design to study the effects of HCQ compared to SOC in 11,197 patients at 176 hospitals in the United Kingdom [@doi:10.1056/NEJMoa2022926].
Patients were randomized into either the control group or one of the treatment arms, with twice as many patients enrolled in the control group as any treatment group.
Of the patients eligible to receive HCQ, 1,561 were randomized into the HCQ arm, and 3,155 were randomized into the control arm.
The demographics of the HCQ and control groups were similar in terms of average age (65 years), proportion female (approximately 38%), ethnic make-up (73% versus 76% white), and prevalence of pre-existing conditions (56% versus 57% overall).
In the HCQ arm of the study, patients received 800 mg at baseline and again after 6 hours, then 400 mg at 12 hours and every subsequent 12 hours.
The primary outcome analyzed was all-cause mortality, and patient vital statistics were reported by physicians upon discharge or death, or else at 28 days following HCQ administration if they remained hospitalized.
The secondary outcome assessed was the combined risk of progression to invasive mechanical ventilation or death within 28 days.
By the advice of an external data monitoring committee, the HCQ arm of the study was reviewed early, leading to it being closed due a lack of support for HCQ as a treatment for COVID-19.
COVID-19-related mortality was not affected by HCQ in the RECOVERY trial (rate ratio, 1.09; 95% CI, 0.97 to 1.23; _p_ = 0.15), but cardiac events were increased in the HCQ arm (0.4 percentage points), as was the duration of hospitalization (rate ratio for discharge alive within 28 days: 0.90; 95% CI, 0.83 to 0.98) and likelihood of progression to mechanical ventilation or death (risk ratio 1.14; 95% CI, 1.03 to 1.27).
This large-scale study thus builds upon studies in the United States and China to suggest that HCQ is not an effective treatment, and in fact may negatively impact COVID-19 patients due to its side effects.
Therefore, though none of the studies have been blinded, examining them together makes it clear that the available evidence points to significant dangers associated with the administration of HCQ to hospitalized COVID-19 patients, without providing any support for its efficacy.

#### HCQ for the Treatment of Mild Cases

One additional possible therapeutic application of HCQ considered was the treatment of mild COVID-19 cases in otherwise healthy individuals.
This possibility was assessed in a randomized, open-label, multi-center analysis conducted in Catalonia (Spain) [@doi:10.1093/cid/ciaa1009].
This analysis enrolled adults 18 and older who had been experiencing mild symptoms of COVID-19 for fewer than five days.
Participants were randomized into an HCQ arm (N=136) and a control arm (N=157), and those in the treatment arm were administered 800 mg of HCQ on the first day of treatment followed by 400 mg on each of the subsequent six days.
The primary outcome assessed was viral clearance at days 3 and 7 following the onset of treatment, and secondary outcomes were clinical progression and time to complete resolution of symptoms.
No significant differences between the two groups were found: the difference in viral load between the HCQ and control groups was 0.01 (95% CI, -0.28 to 0.29) at day 3 and -0.07 (95% CI -0.44 to 0.29) at day 7, the relative risk of hospitalization was 0.75 (95% CI, 0.32 to 1.77), and the difference in time to complete resolution of symptoms was -2 days (_p_ = 0.38).
This study thus suggests that HCQ does not improve recovery from COVID-19, even in otherwise healthy adult patients with mild symptoms.

#### Prophylactic Administration of HCQ

An initial study of the possible prophylactic application of HCQ utilized a randomized, double-blind, placebo-controlled design to analyze the administration of HCQ prophylactically [@doi:10.1056/NEJMoa2016638].
Asymptomatic adults in the United States and Canada who had been exposed to SARS-CoV-2 within the past four days were enrolled in an online study to evaluate whether administration of HCQ over five days influenced the probability of developing COVID-19 symptoms over a 14-day period.
Of the participants, 414 received HCQ and 407 received a placebo.
No significant difference in the rate of symptomatic illness was observed between the two groups (11.8% HCQ, 14.3% placebo, _p_ = 0.35).
The HCQ condition was associated with side effects, with 40.1% of patients reporting side effects compared to 16.8% in the control group (_p_ < 0.001).
However, likely due to the high enrollment of healthcare workers (66% of participants) and the well-known side effects associated with HCQ, a large number of participants were able to correctly identify whether they were receiving HCQ or a placebo (46.5% and 35.7%, respectively).
Furthermore, due to a lack of availability of diagnostic testing, only 20 of the 107 cases were confirmed with a PCR-based test to be positive for SARS-CoV-2.
The rest were categorized as "probable" or "possible" cases by a panel of four physicians who were blind to the treatment status.
One possible confounder is that a patient presenting one or more symptoms, which included diarrhea, was defined as a "possible" case, but diarrhea is also a common side effect of HCQ.
Additionally, four of the twenty PCR-confirmed cases did not develop symptoms until after the observation period had completed, suggesting that the 14-day trial period may not have been long enough or that some participants also encountered secondary exposure events.
Finally, in addition to the young age of the participants in this study, which ranged from 32 to 51, there were possible impediments to generalization introduced by the selection process, as 2,237 patients who were eligible but had already developed symptoms by day 4 were enrolled in a separate study.
It is therefore likely that asymptomatic cases were over-represented in this sample, which would not have been detected based on the diagnostic criteria used.
Therefore, while this study does represent the first effort to conduct a randomized, double-blind, placebo-controlled investigation of HCQ's effect on COVID-19 prevention after SARS-CoV-2 exposure in a large sample, the lack of PCR tests and several other design flaws significantly impede interpretation of the results.
However, in line with the results from therapeutic studies, once again no evidence was found suggesting an effect of HCQ against COVID-19.

A second study [@doi:10.1001/jamainternmed.2020.6319] examined the effect of administering HCQ to healthcare workers as a pre-exposure prophylactic.
The primary outcome assessed was the conversion from SARS-CoV-2 negative to SARS-CoV-2 positive status over the 8 week study period.
This study was also randomized, double-blind, and placebo-controlled, and it sought to address some of the limitations of the first prophylactic study.
The goal was to enroll 200 healthcare workers, preferentially those working with COVID-19 patients, at two hospitals within the University of Pennsylvania hospital system in Philadelphia, PA.
Participants were randomized 1:1 to receive either 600 mg of HCQ daily or a placebo, and their SARS-CoV-2 infection status and antibody status were assessed using RT-PCR and serological testing, respectively, at baseline, 4 weeks, and 8 weeks following the beginning of the treatment period.
The statistical design of the study accounted for interim analyses at 50 and 100 participants in case efficacy or futility of HCQ for prophylaxis became clear earlier than completion of enrollment.
The 139 individuals enrolled comprised a study population that was fairly young (average age 33) and made of largely of people who were white, women, and without pre-existing conditions.
At the second interim analysis, more individuals in the treatment group than the control group had contracted COVID-19 (4 versus 3), causing the estimated z-score to fall below the pre-established threshold for futility.
As a result, the trial was terminated early, offering additional evidence against the use of HCQ for prophylaxis.

#### Summary of HCQ/CQ Research Findings

Early _in vitro_ evidence indicated that HCQ could be an effective therapeutic against SARS-CoV-2 and COVID-19, leading to significant media attention and public interest in its potential as both a therapeutic and prophylactic.
Initially it was hypothesized that CQ/HCQ might be effective against SARS-CoV-2 in part because CQ and HCQ have both been found to inhibit the expression of CD154 in T-cells and to reduce TLR signaling that leads to the production of pro-inflammatory cytokines [@doi:10.1038/s41584-020-0372-x].
Clinical trials for COVID-19 have more often used HCQ rather than CQ because it offers the advantages of being cheaper and having fewer side effects than CQ.
However, research has not found support for a positive effect of HCQ on COVID-19 patients.
Multiple clinical studies have already been carried out to assess HCQ as a therapeutic agent for COVID-19, and many more are in progress.
To date, none of these studies have used randomized, double-blind, placebo-controlled designs with a large sample size, which would be the gold standard.
Despite the design limitations (which would be more likely to produce false positives than false negatives), initial optimism about HCQ has largely dissipated.
The most methodologically rigorous analysis of HCQ as a prophylactic [@doi:10.1056/NEJMoa2016638] found no significant differences between the treatment and control groups, and the WHO's global Solidarity trial similarly reported no effect of HCQ on mortality [@doi:10.1056/NEJMoa2023184].
Thus, HCQ/CQ are not likely to be effective therapeutic or prophylactic agents against COVID-19.
One case study identified drug-induced phospholipidosis as the cause of death for a COVID-19 patient treated with HCQ [@doi:10.1080/01913123.2020.1850966], suggesting that in some cases, the proposed mechanism of action may ultimately be harmful.
Additionally, one study identified an increased risk of mortality in older men receiving HCQ, and administration of HCQ and HCQ + AZ did not decrease the use of mechanical ventilation in these patients [@doi:10.1101/2020.04.16.20065920].
HCQ use for COVID-19 could also lead to shortages for anti-malarial or anti-rheumatic use, where it has documented efficacy.
Despite significant early attention, these drugs appear to be ineffective against COVID-19.
Several countries have now removed CQ/HCQ from their SOC for COVID-19 due to the lack of evidence of efficacy and the frequency of adverse effects.

### ACE Inhibitors and Angiotensin II Receptor Blockers

Several clinical trials testing the effects of ACEIs or ARBs on COVID-19 outcomes are ongoing [@clinicaltrials:NCT04338009; @clinicaltrials:NCT04353596; @clinicaltrials:NCT04311177; @clinicaltrials:NCT04312009; @clinicaltrials:NCT04330300; @clinicaltrials:NCT04366050; @clinicaltrials:NCT04364893].
Clinical trials are needed because the findings of the various observational studies bearing on this topic cannot be interpreted as indicating a protective effect of the drug [@doi:10.1161/CIRCRESAHA.120.317205; @doi:10.2215/CJN.03530320].
Two analyses [@clinicaltrials:NCT04338009; @clinicaltrials:NCT04364893] have reported no effect of continuing or discontinuing ARBs and ACEIs on patients admitted to the hospital for COVID-19.
The first, known as REPLACE COVID [@doi:10/fvgt], was a randomized, open-label study that enrolled patients who were admitted to the hospital for COVID-19 and were taking an ACEI at the time of admission.
They enrolled 152 patients at 20 hospitals across seven countries and randomized them into two arms, continuation (n=75) and discontinuation (n=77).
The primary outcome evaluated was a global rank score that integrated several dimensions of illness.
The components of this global rank score, such as time to death and length of mechanical ventilation, were evaluated as secondary endpoints.
This analysis reported no differences between the two groups in the primary or any of the secondary outcomes.

Similarly, a second study [@doi:10.1001/jama.2020.25864] used a randomized, open-label design to examine the effects of continuing versus discontinuing ARBs and ACEIs on patients hospitalized for mild to moderate COVID-19 at 29 hospitals in Brazil.
This study enrolled 740 patients but had to exclude one trial site from all analyses due to the discovery of violations of Good Clinical Trial practice and data falsification.
After this exclusion, 659 patients remained, with 334 randomized to discontinuation and 325 to continuation.
In this study, the primary endpoint analyzed was the number of days that patients were alive and not hospitalized within 30 days of enrollment.
The secondary outcomes included death (including in-hospital death separately), number of days hospitalized, and specific clinical outcomes such as heart failure or stroke.
Once again, no significant differences were found between the two groups.
Initial studies of randomized interventions therefore suggest that ACEIs and ARBs are unlikely to affect COVID-19 outcomes.
These results are also consistent with findings from observational studies (summarized in [@doi:10/fvgt]).
Additional information about ACE2, observational studies of ACEIs and ARBs in COVID-19, and clinical trials on this topic have been summarized [@url:http://www.nephjc.com/news/covidace2].
Therefore, despite the promising potential mechanism, initial results have not provided support for ACEIs and ARBs as therapies for COVID-19.

### Tocilizumab

Human IL-6 is a 26-kDa glycoprotein that consists of 184 amino acids and contains two potential N-glycosylation sites and four cysteine residues.
It binds to a type I cytokine receptor (IL-6R&alpha; or glycoprotein 80) that exists in both membrane-bound (IL-6R&alpha;) and soluble (sIL-6R&alpha;) forms [@doi:10.3389/fimmu.2016.00604].
It is not the binding of IL-6 to the receptor that initiates pro- and/or anti-inflammatory signaling, but rather the binding of the complex to another subunit, known as IL-6R&beta; or glycoprotein 130 (gp130) [@doi:10.7150/ijbs.4989; @doi:10.3389/fimmu.2016.00604].
Unlike membrane-bound IL-6R&alpha;, which is only found on hepatocytes and some types of leukocytes, gp130 is found on most cells [@doi:10.1007/s00430-006-0019-9].
When IL-6 binds to sIL-6R&alpha;, the complex can then bind to a gp130 protein on any cell [@doi:10.1007/s00430-006-0019-9].
The binding of IL-6 to IL-6R&alpha; is termed classical signaling, while its binding to sIL-6R&alpha; is termed trans-signaling [@doi:10.1016/j.cytogfr.2012.04.001; @doi:10.1042/bj3000281; @doi:10.1007/s00430-006-0019-9].
These two signaling processes are thought to play different roles in health and illness.
For example, trans-signaling may play a role in the proliferation of mucosal T-helper TH2 cells associated with asthma, while an earlier step in this proliferation process may be regulated by classical signaling [@doi:10.1007/s00430-006-0019-9].
Similarly, IL-6 is known to play a role in Crohn's Disease via trans-, but not classical, signaling [@doi:10.1007/s00430-006-0019-9].
Both classical and trans-signaling can occur through three independent pathways: the Janus-activated kinase-STAT3 pathway, the Ras/Mitogen-Activated Protein Kinases pathway and the Phosphoinositol-3 Kinase/Akt pathway [@doi:10.3389/fimmu.2016.00604].
These signaling pathways are involved in a variety of different functions, including cell type differentiation, immunoglobulin synthesis, and cellular survival signaling pathways, respectively [@doi:10.3389/fimmu.2016.00604].
The ultimate result of the IL-6 cascade is to direct transcriptional activity of various promoters of pro-inflammatory cytokines, such as IL-1, TFN, and even IL-6 itself, through the activity of NF-κB [@doi:10.3389/fimmu.2016.00604].
IL-6 synthesis is tightly regulated both transcriptionally and post-transcriptionally, and it has been shown that viral proteins can enhance transcription of the IL-6 gene by strengthening the DNA-binding activity between several transcription factors and IL-6 gene-cis-regulatory elements [@doi:10.2492/inflammregen.33.054].
Therefore, drugs inhibiting the binding of IL-6 to IL-6R&alpha; or sIL-6R&alpha; are of interest for combating the hyperactive inflammatory response characteristic of cytokine release syndrome (CRS) and cytokine storm syndrome (CSS).
TCZ is a humanized monoclonal antibody that binds both to the insoluble and soluble receptor of IL-6, providing de facto inhibition of the IL-6 immune cascade.
Interest in TCZ as a possible treatment for COVID-19 was piqued by early evidence indicating that COVID-19 deaths may be induced by the hyperactive immune response, often referred to as CRS or CSS [@doi:10/ggnxb3], as IL-6 plays a key role in this response [@doi:10.1128/mmbr.05015-11].
The observation of elevated IL-6 in patients who died relative to those who recovered [@doi:10/ggnxb3] could reflect an over-production of proinflammatory interleukins, suggesting that TCZ could potentially palliate some of the most severe symptoms of COVID-19 associated with increased cytokine production.

This early interest in TCZ as a possible treatment for COVID-19 was bolstered by a very small retrospective study in China that examined 20 patients with severe symptoms in early February 2020 and reported rapid improvement in symptoms following treatment with TCZ [@doi:10.1073/pnas.2005615117].
Subsequently, a number of retrospective studies have been conducted in several countries.
Many studies use a retrospective, observational design, where they compare outcomes for COVID-19 patients who received TCZ to those who did not over a set period of time.
For example, one of the largest retrospective, observational analyses released to date [@doi:10/d2pk], consisting of 1,351 patients admitted to several care centers in Italy, compared the rates at which patients who received TCZ died or progressed to invasive medical ventilation over a 14-day period compared to patients receiving only SOC.
Under this definition, SOC could include other drugs such as HCQ, azithromycin, lopinavir-ritonavir or darunavir-cobicistat, or heparin.
While this study was not randomized, a subset of patients who were eligible to receive TCZ were unable to obtain it due to shortages; however, these groups were not directly compared in the analysis.
After adjusting for variables such as age, sex, and SOFA (sequential organ failure assessment) score, they found that patients treated with TCZ were less likely to progress to invasive medical ventilation and/or death (adjusted HR = 0.61, CI 0.40-0.92, _p_ = 0.020); analysis of death and ventilation separately suggests that this effect may have been driven by differences in the death rate (20% of control versus 7% of TCZ-treated patients).
The study reported particular benefits for patients whose PaO~2~/FiO~2~ ratio, also known as the Horowitz Index for Lung Function, fell below a 150 mm Hg threshold.
They found no differences between groups administered subcutaneous versus intravenous TCZ.

Another retrospective observational analysis of interest examined the charts of patients at a hospital in Connecticut, USA where 64% of all 239 COVID-19 patients in the study period were administered TCZ based on assignment by a standardized algorithm [@doi:10.1016/j.chest.2020.06.006].
They found that TCZ administration was associated with more similar rates of survivorship in patients with severe versus nonsevere COVID-19 at intake, defined based on the amount of supplemental oxygen needed.
They therefore proposed that their algorithm was able to identify patients presenting with or likely to develop CRS as good candidates for TCZ.
This study also reported higher survivorship in Black and Hispanic patients compared to white patients when adjusted for age.
The major limitation with interpretation for these studies is that there may be clinical characteristics that influenced medical practitioners decisions to administer TCZ to some patients and not others.
One interesting example therefore comes from an analysis of patients at a single hospital in Brescia, Italy, where TCZ was not available for a period of time [@doi:10.1016/j.ejim.2020.05.009].
This study compared COVID-19 patients admitted to the hospital before and after March 13, 2020, when the hospital received TCZ.
Therefore, patients who would have been eligible for TCZ prior to this arbitrary date did not receive it as treatment, making this retrospective analysis something of a natural experiment.
Despite this design, demographic factors did not appear to be consistent between the two groups, and the average age of the control group was older than the TCZ group.
The control group also had a higher percentage of males and a higher incidence of comorbidities such as diabetes and heart disease.
All the same, the multivariate HR, which adjusted for these clinical and demographic factors, found a significant difference between survival in the two groups (HR=0.035, CI=0.004-0.347, _p_ = 0.004).
The study reported improvement of survival outcomes after the addition of TCZ to the SOC regime, with 11 of 23 patients (47.8%) admitted prior to March 13th dying compared to 2 of 62 (3.2%) admitted afterwards (HR=0.035; 95% CI, 0.004 to 0.347; _p_ = 0.004).
They also reported a reduced progression to mechanical ventilation in the TCZ group.
However, this study also holds a significant limitation: the time delay between the two groups means that knowledge about how to treat the disease likely improved over this timeframe as well.
All the same, the results of these observational retrospective studies provide support for TCZ as a pharmaceutical of interest for follow-up in clinical trials.

Other retrospective analyses have utilized a case-control design to match pairs of patients with similar baseline characteristics, only one of whom received TCZ for COVID-19.
In one such study, TCZ was significantly associated with a reduced risk of progression to intensive care unit (ICU) admission or death [@doi:10.1016/j.medmal.2020.05.001].
This study examined only 20 patients treated with TCZ (all but one of the patients treated with TCZ in the hospital during the study period) and compared them to 25 patients receiving SOC.
For the combined primary endpoint of death and/or ICU admission, only 25% of patients receiving TCZ progressed to an endpoint compared to 72% in the SOC group (_p_ = 0.002, presumably based on a chi-square test based on the information provided in the text).
When the two endpoints were examined separately, progression to invasive medical ventilation remained significant (32% SOC compared to 0% TCZ, _p_ = 0.006) but not for mortality (48% SOC compared to 25% TCZ, _p_ = 0.066).
In contrast, a study that compared 96 patients treated with TCZ to 97 patients treated with SOC only in New York City found that differences in mortality did not differ between the two groups, but that this difference did become significant when intubated patients were excluded from the analysis [@doi:10.1093/qjmed/hcaa206].
Taken together, these findings suggest that future clinical trials of TCZ may want to include intubation as an endpoint.
However, these studies should be approached with caution, not only because of the small number of patients enrolled and the retrospective design, but also because they performed a large number of statistical tests and did not account for multiple hypothesis testing.
In general, caution must be exercised when interpreting subgroup analyses after a primary combined endpoint analysis.
These last findings highlight the need to search for a balance between impairing a harmful immune response, such as the one generated during CRS/CSS, and preventing the worsening of the clinical picture of the patients by potential new viral infections.
Early meta-analyses and systematic reviews have investigated the available data about TCZ for COVID-19.
One meta-analysis [@doi:10.2139/ssrn.3642653] evaluated 19 studies published or released as preprints prior to July 1, 2020 and found that the overall trends were supportive of the frequent conclusion that TCZ does improve survivorship, with a significant HR of 0.41 (_p_ < 0.001).
This trend improved when they excluded studies that administered a steroid alongside TCZ, with a significant HR of 0.04 (_p_ < 0.001).
They also found some evidence for reduced invasive ventilation or ICU admission, but only when excluding all studies except a small number whose estimates were adjusted for the possible bias introduced by the challenges of stringency during the enrollment process.
A systematic analysis of sixteen case-control studies of TCZ estimated an odds ratio of mortality of 0.453 (95% CI 0.376–0.547, _p_ < 0.001), suggesting possible benefits associated with TCZ treatment [@doi:10.7717/peerj.10322].
Although these estimates are similar, it is important to note that they are drawing from the same literature and are therefore likely to be affected by the same potential biases in publication.
A different systematic review of studies investigating TCZ treatment for COVID-19 analyzed 31 studies that had been published or released as pre-prints and reported that none carried a low risk of bias [@doi:10.1016/j.pulmoe.2020.07.003].
Therefore, the present evidence is not likely to be sufficient for conclusions about the efficacy of TCZ.

On February 11, 2021, a preprint describing the first randomized control trial of TCZ was released as part of the RECOVERY trial [@doi:10.1101/2021.02.11.21249258].
Of the 21,550 patients enrolled in the RECOVERY trial at the time, 4,116 adults hospitalized with COVID-19 across the 131 sites in the United Kingdom were assigned to the arm of the trial evaluating the effect of TCZ.
Among them, 2,022 were randomized to receive TCZ and 2,094 were randomized to SOC, with 79% of patients in each group available for analysis at the time that the initial report was released.
The primary outcome measured was 28-day mortality, and TCZ was found to reduce 28-day mortality from 33% of patients receiving SOC alone to 29% of those receiving TCZ, corresponding to a rate ratio of 0.86 (95% CI 0.77-0.96; _p_ = 0.007).
TCZ was also significantly associated with the probability of hospital discharge within 28 days for living patients, which was 47% in the SOC group and 54% in the TCZ group (rate ratio 1.22, 95% CI 1.12-1.34, _p_ < 0.0001).
A potential statistical interaction between TCZ and corticosteroids was observed, with the combination providing greater mortality benefits than TCZ alone, but the authors note that caution is advisable in light of the number of statistical tests conducted.
Combining the RECOVERY trial data with data from seven smaller randomized control trials indicates that TCZ is associated with a 13% reduction in 28-day mortality (rate ratio 0.87, 95% CI 0.79-0.96, _p_ = 0.005) [@doi:10.1101/2021.02.11.21249258].

There are possible risks associated with the administration of TCZ for COVID-19.
TCZ has been used for over a decade to treat RA [@doi:10.1177/1759720X18798462], and a recent study found the drug to be safe for pregnant and breastfeeding women [@doi:10.1093/rheumatology/kez100].
However, TCZ may increase the risk of developing infections [@doi:10.1177/1759720X18798462], and RA patients with chronic hepatitis B infections had a high risk of hepatitis B virus reactivation when TCZ was administered in combination with other RA drugs [@doi:10.1111/1756-185X.13010].
As a result, TCZ is contraindicated in patients with active infections such as tuberculosis [@doi:10.1186/s12967-020-02339-3].
Previous studies have investigated, with varying results, a possible increased risk of infection in RA patients administered TCZ [@doi:10.1093/rheumatology/keq343; @doi:10.1136/annrheumdis-2018-214367], although another study reported that the incidence rate of infections was higher in clinical practice RA patients treated with TCZ than in the rates reported by clinical trials [@doi:10.1093/rheumatology/ker223].
In the investigation of 544 Italian COVID-19 patients, the group treated with TCZ was found to be more likely to develop secondary infections, with 24% compared to 4% in the control group (_p_ < 0.0001) [@doi:10/d2pk].
Reactivation of hepatitis B and herpes simplex virus 1 was also reported in a small number of patients in this study, all of whom were receiving TCZ.
A July 2020 case report described negative outcomes of two COVID-19 patients after receiving TCZ, including one death; however, both patients were intubated and had entered septic shock prior to receiving TCZ [@doi:10.1016/j.chest.2020.04.024], likely indicating a severe level of cytokine production.
Additionally, D-dimer and sIL2R levels were reported by one study to increase in patients treated with TCZ, which raised concerns because of the potential association between elevated D-dimer levels and thrombosis and between sIL2R and diseases where T-cell regulation is compromised [@doi:10.1016/j.chest.2020.06.006].
An increased risk of bacterial infection was also identified in a systematic review of the literature, based on the unadjusted estimates reported [@doi:10.2139/ssrn.3642653].
In the RECOVERY trial, however, only three out of 2,022 participants in the group receiving TCZ developed adverse reactions determined to be associated with the intervention, and no excess deaths were reported [@doi:10.1101/2021.02.11.21249258].
TCZ administration to COVID-19 patients is not without risks and may introduce additional risk of developing secondary infections; however, while caution may be prudent when treating patients who have latent viral infections, the results of the RECOVERY trial indicate that adverse reactions to TCZ are very rare among COVID-19 patients broadly.

In summary, approximately 33% of hospitalized COVID-19 patients develop ARDS [@doi:10.1186/s13054-020-03240-7], which is caused by an excessive early response of the immune system which can be a component of CRS/CSS [@doi:10.1016/j.chest.2020.06.006; @doi:10.1186/s12967-020-02339-3].
This overwhelming inflammation is triggered by IL-6.
TCZ is an inhibitor of IL-6 and therefore may neutralize the inflammatory pathway that leads to the cytokine storm.
The mechanism suggests TCZ could be beneficial for the treatment of COVID-19 patients experiencing excessive immune activity, and the RECOVERY trial reported a reduction in 28-day mortality.
Interest in TCZ as a treatment for COVID-19 was also supported by two meta-analyses [@doi:10.1101/2020.07.10.20150938; @doi:10.2139/ssrn.3642653], but a third meta-analysis found that all of the available literature at that time carried a risk of bias [@doi:10.1016/j.pulmoe.2020.07.003].
Additionally, different studies used different dosages, number of doses, and methods of administration.
Ongoing research may be needed to optimize administration of TCZ [@doi:10.1016/j.jcv.2020.104443], although similar results were reported by one study for intravenous and subcutaneous administration [@doi:10/d2pk].
Clinical trials that are in progress are likely to provide additional insight into the effectiveness of this drug for the treatment of COVID-19 along with how it should be administered.

### Interferons

IFNs are a family of cytokines critical to activating the innate immune response against viral infections.
Interferons are classified into three categories based on their receptor specificity: types I, II and III [@doi:10.1128/mmbr.05015-11].
Specifically, IFNs I (IFN-𝛼 and 𝛽) and II (IFN-𝛾) induce the expression of antiviral proteins [@doi:10.1016/j.jcv.2003.11.013].
Among these IFNs, IFN-𝛽 has already been found to strongly inhibit the replication of other coronaviruses, such as SARS-CoV-1, in cell culture, while IFN-𝛼 and 𝛾 were shown to be less effective in this context [@doi:10.1016/j.jcv.2003.11.013].
There is evidence that patients with higher susceptibility to ARDS indeed show deficiency in IFN-𝛽.
For instance, infection with other coronaviruses impairs IFN-𝛽 expression and synthesis, allowing the virus to escape the innate immune response [@doi:10.1016/j.virusres.2014.07.024].
On March 18 2020, Synairgen plc received approval to start a phase II trial for SNG001, an IFN-𝛽-1a formulation to be delivered to the lungs via inhalation [@clinicaltrials:NCT04385095].
SNG001, which contains recombinant interferon beta-1a, was previously shown to be effective in reducing viral load in an _in vivo_ model of swine flu and _in vitro_ models of other coronavirus infections [@synairgen-SNG001-March-2020].
In July 2020, a press release from Synairgen stated that SNG001 reduced progression to ventilation in a double-blind, placebo-controlled, multi-center study of 101 patients with an average age in the late 50s [@synairgen-SNG001-July-2020].
These results were subsequently published in November 2020 [@doi:10/ghjzm4].
The study reports that the participants were assigned at a ratio of 1:1 to receive either SNG001 or a placebo that lacked the active compound, by inhalation for up to 14 days.
The primary outcome they assessed was the change in patients' score on the WHO Ordinal Scale for Clinical Improvement (OSCI) at trial day 15 or 16.
SNG001 was associated with an odds ratio of improvement on the OSCI scale of 2.32 (95% CI 1.07 – 5.04, _p_ = 0.033) in the intention-to-treat analysis and 2.80 (95% CI 1.21 – 6.52, _p_ = 0.017) in the per-protocol analysis, corresponding to significant improvement in the SNG001 group on the OSCI at day 15/16.
Some of the secondary endpoints analyzed also showed differences: at day 28, the OR for clinical improvement on the OSCI was 3.15 (95% CI 1.39 – 7.14, _p_ = 0.006), and the odds of recovery at day 15/16 and at day 28 were also significant between the two groups.
Thus, this study suggested that IFN-𝛽1 administered via SNG001 may improve clinical outcomes.

In contrast, the WHO Solidarity trial reported no significant effect of IFN-&beta;-1a on patient survival during hospitalization [@doi:10.1056/NEJMoa2023184].
Here, the primary outcome analyzed was in-hospital mortality, and the rate ratio for the two groups was 1.16 (95% CI, 0.96 to 1.39; _p_ = 0.11) administering IFN-&beta;-1a to 2050 patients and comparing their response to 2,050 controls.
However, there are a few reasons that the different findings of the two trials might not speak to the underlying efficacy of this treatment strategy.
One important consideration is the stage of COVID-19 infection analyzed in each study.
The Synairgen trial enrolled only patients who were not receiving invasive ventilation, corresponding to a less severe stage of disease than many patients enrolled in the SOLIDARITY trial, as well as a lower overall rate of mortality [@doi:10/ftmj].
Additionally, the methods of administration differed between the two trials, with the SOLIDARITY trial administering IFN-&beta;-1a subcutaneously [@doi:10/ftmj].
The differences in findings between the studies suggests that the method of administration might be relevant to outcomes, with nebulized IFN-&beta;-1a more directly targeting receptors in the lungs.
A trial that analyzed the effect of subcutaneously administered IFN-&beta;-1a on patients with ARDS between 2015 and 2017 had also reported no effect on 28-day mortality [@doi:10.1001/jama.2019.22525], while a smaller study analyzing the effect of subcutaneous IFN administration did find a significant improvement in 28-day mortality for COVID-19 [@doi:10.1128/AAC.01061-20].
At present, several ongoing clinical trials are investigating the potential effects of IFN-&beta;-1a, including in combination with therapeutics such as remdesivir [@clinicaltrials:NCT04492475] and administered via inhalation [@clinicaltrials:NCT04385095].
Thus, as additional information becomes available, a more detailed understanding of whether and under which circumstances IFN-&beta;-1a is beneficial to COVID-19 patients should develop.

### Potential Avenues of Interest for Therapeutic Development

Given what is currently known about these therapeutics for COVID-19, a number of related therapies beyond those explored above may also prove to be of interest.
For example, the demonstrated benefit of dexamethasone and the ongoing potential of tocilizumab for treatment of COVID-19 suggests that other anti-inflammatory agents might also hold value for the treatment of COVID-19.
Current evidence supporting the treatment of severe COVID-19 with dexamethasone suggests that the need to curtail the cytokine storm inflammatory response transcends the risks of immunosuppression, and other anti-inflammatory agents may therefore benefit patients in this phase of the disease.
While dexamethasone is considered widely available and generally affordable, the high costs of biologics such as tocilizumab therapy may present obstacles to wide-scale distribution of this drug if it proves of value.
At the doses used for RA patients, the cost for tocilizumab ranges from $179.20 to $896 per dose for the IV form and $355 for the pre-filled syringe [@url:https://www.ncbi.nlm.nih.gov/books/NBK349513/table/T43].
Several other anti-inflammatory agents used for the treatment of autoimmune diseases may also be able to counter the effects of the cytokine storm induced by the virus, and some of these, such as cyclosporine, are likely to be more cost-effective and readily available than biologics [@url:https://escholarship.umassmed.edu/meyers_pp/385].
While tocilizumab targets IL-6, several other inflammatory markers could be potential targets, including TNF-&alpha;.
Inhibition of TNF-&alpha; by a compound such as Etanercept was previously suggested for treatment of SARS-CoV-1 [@doi:10.1185/030079903125002757] and may be relevant for SARS-CoV-2 as well.
Another anti-IL-6 antibody, sarilumab, is also being investigated [@url:http://www.news.sanofi.us/2020-03-16-Sanofi-and-Regeneron-begin-global-Kevzara-R-sarilumab-clinical-trial-program-in-patients-with-severe-COVID-19; @clinicaltrials:NCT04327388].
Baricitinib and other small molecule inhibitors of the Janus-activated kinase pathway also curtail the inflammatory response and have been suggested as potential options for SARS-CoV-2 infections [@doi:10/dph5].
Baricitinib, in particular, may be able to reduce the ability of SARS-CoV-2 to infect lung cells [@doi:10/ggnrsx].
Clinical trials studying baricitinib in COVID-19 have already begun in the US and in Italy [@url:https://investor.lilly.com/news-releases/news-release-details/lilly-begins-clinical-testing-therapies-covid-19; @clinicaltrials:NCT04320277].
Identification and targeting of further inflammatory markers that are relevant in SARS-CoV-2 infection may be of value for curtailing the inflammatory response and lung damage.

In addition to immunosuppressive treatments, which are most beneficial late in disease progression, much research is focused on identifying therapeutics for early-stage patients.
For example, although studies of HCQ have not supported the early theory-driven interest in this antiviral treatment, alternative compounds with related mechanisms may still have potential.
Hydroxyferroquine derivatives of HCQ have been described as a class of bioorganometallic compounds that exert antiviral effects with some selectivity for SARS-CoV-1 _in vitro_ [@doi:10.1021/jm0601856].
Future work could explore whether such compounds exert antiviral effects against SARS-CoV-2 and whether they would be safer for use in COVID-19.

Another potential approach is the development of antivirals, which could be broad-spectrum, specific to coronaviruses, or targeted to SARS-CoV-2.
Development of new antivirals is complicated by the fact that none have yet been approved for human coronaviruses.
Intriguing new options are emerging, however.
Beta-D-N4-hydroxycytidine is an orally bioavailable ribonucleotide analog showing broad-spectrum activity against RNA viruses, which may inhibit SARS-CoV-2 replication _in vitro_ and _in vivo_ in mouse models of HCoVs [@doi:10.1126/scitranslmed.abb5883].
A range of other antivirals are also in development.
Development of antivirals will be further facilitated as research reveals more information about the interaction of SARS-CoV-2 with the host cell and host cell genome, mechanisms of viral replication, mechanisms of viral assembly, and mechanisms of viral release to other cells; this can allow researchers to target specific stages and structures of the viral life cycle.
Finally, antibodies against viruses, also known as antiviral monoclonal antibodies, could be an alternative as well and are described in detail in an above section.
The goal of antiviral antibodies is to neutralize viruses through either cell-killing activity or blocking of viral replication [@doi:10.1016/j.tim.2015.07.005].
They may also engage the host immune response, encouraging the immune system to hone in on the virus.
Given the cytokine storm that results from immune system activation in response to the virus, which has been implicated in worsening of the disease, a neutralizing antibody (nAb) may be preferable.
Upcoming work may explore the specificity of nAbs for their target, mechanisms by which the nAbs impede the virus, and improvements to antibody structure that may enhance the ability of the antibody to block viral activity.

Some research is also investigating potential therapeutics and prophylactics that would interact with components of the innate immune response.
For example, TLRs are pattern recognition receptors that recognize pathogen- and damage-associated molecular patterns and contribute to innate immune recognition and, more generally, promotion of both the innate and adaptive immune responses [@ISBN:9780815332183].
In mouse models, poly(I:C) and CpG, which are agonists of Toll-like receptors TLR3 and TLR9, respectively, showed protective effects when administered prior to SARS-CoV-1 infection [@doi:10.1128/JVI.01410-12].
Therefore, TLR agonists hold some potential for broad-spectrum prophylaxis.

