## Application of Traditional Vaccine Development Strategies to SARS-CoV-2

### Abstract

Over the past 150 years, vaccines have revolutionized the relationship between people and disease.
During the COVID-19 pandemic, technologies such as mRNA vaccines have received attention due to their novelty and successes.
However, more traditional vaccine development platforms have also yielded important tools in the worldwide fight against the SARS-CoV-2 virus.

A variety of approaches have been used to develop COVID-19 vaccines that are now authorized for use in countries around the world.
In this review, we highlight strategies that focus on the viral capsid and outwards, rather than on the nucleic acids inside.
These approaches fall into two broad categories: whole-virus vaccines and subunit vaccines.
Whole-virus vaccines use the virus itself, either in an inactivated or attenuated state.
Subunit vaccines contain instead an isolated, immunogenic component of the virus.
Here, we highlight vaccine candidates that apply these approaches against SARS-CoV-2 in different ways.
In a companion manuscript, we review the more recent and novel development of nucleic-acid based vaccine technologies.

We further consider the role that these COVID-19 vaccine development programs have played in prophylaxis at the global scale.
Well-established vaccine technologies have proved especially important to making vaccines accessible in low- and middle-income countries.
Vaccine development programs that use established platforms have been undertaken in a much wider range of countries than those using nucleic-acid-based technologies, which have been led by wealthy Western countries.
Therefore, these vaccine platforms, though less novel from a biotechnological standpoint, have proven to be extremely important to the management of SARS-CoV-2.

### Importance

As of {{csse_date_pretty}}, there have been over {{csse_cases}} SARS-CoV-2 cases, and the virus has taken the lives of at least {{csse_deaths}} people globally [@doi:10/ggnsjk].
The development, production, and distribution of vaccines is imperative to saving lives, preventing illness, and reducing the economic and social burdens caused by the COVID-19 pandemic.
Vaccines that use cutting-edge biotechnology have played an important role in mitigating the effects of SARS-CoV-2.
However, more traditional methods of vaccine development that were refined throughout the twentieth century have been especially critical to increasing vaccine access worldwide.
Effective deployment is necessary to reducing the susceptibility of the world's population, which is especially important in light of emerging variants.
In this review, we discuss the safety, immunogenicity, and distribution of vaccines developed using established technologies.
In a separate review, we describe the vaccines developed using nucleic acid-based vaccine platforms.
From the current literature, it is clear that the well-established vaccine technologies are also highly effective against SARS-CoV-2 and are being used to address the challenges of COVID-19 globally, including in low- and middle-income countries.
This worldwide approach is critical for reducing the devastating impact of SARS-CoV-2.

### Introduction

The development of vaccines is widely considered one of the most important medical advances in human history.
Over the past 150 years, several approaches to vaccination have been developed and refined [@doi:10.1073/pnas.1400472111].
The COVID-19 pandemic has produced unusual circumstances compared to past health crises, leading to differences in vaccine development strategies.
One way in which the COVID-19 pandemic differs from prior global health crises is that the SARS-CoV-2 viral genome was sequenced, assembled, and released very early in the course of the pandemic (January 2020).
This genomic information has informed the biomedical response to this novel pathogen across several dimensions [@individual-pathogenesis; @individual-pharmaceuticals].
All the same, vaccines have been developed since long before the concept of a virus or a viral genome was known, and as early as September 2020, there were over 180 vaccine candidates against SARS-CoV-2 in development, many of which employed more traditional vaccine technologies [@doi:10.1038/s41586-020-2798-3].
However, public attention in the United States and elsewhere has largely focused on vaccine development platforms that use new technologies, especially mRNA vaccines.
We review vaccine technologies used for SARS-CoV-2 in two parts: here, the application of established vaccine development platforms to SARS-CoV-2, and separately, novel nucleic acid-based approaches [@individual-vaccines-novel].

Understanding vaccine development programs that are using well-established technologies is important for a global perspective on COVID-19.
As of {{viper_date_pretty}}, {{viper_vaccine_counts}} SARS-CoV-2 vaccines have been approved for use in at least one country [@url:https://covid19.trackvaccines.org].
A resource tracking the distribution of {{owid_vaccine_counts}} vaccines indicates that, as of {{owid_most_recent_date}}, {{owid_worldwide_total_vaccinations}} doses have been administered across {{owid_total_countries}} countries [@doi:10.1038/s41562-021-01122-8].
Many of these vaccines use platforms that do not require information about the viral genome, with {{viper_num_approved_subunit}} developed using subunit and {{viper_num_approved_whole_virus}} using whole-virus approaches [@url:https://covid19.trackvaccines.org].
The types of vaccines available varies widely throughout the world, as the process of developing and deploying a vaccine is complex and often requires coordination between government, industry, academia, and philanthropic entities [@doi:10.1126/science.abc5312].

Another difference between prior global health crises and the COVID-19 pandemic is the way that vaccines are evaluated.
A vaccine's success is often discussed in terms of vaccine efficacy (VE), which describes the protection conferred during clinical trials [@url:https://www.who.int/news-room/feature-stories/detail/vaccine-efficacy-effectiveness-and-protection].
The real-world protection offered by a vaccine is referred to as its effectiveness [@url:https://www.who.int/news-room/feature-stories/detail/vaccine-efficacy-effectiveness-and-protection].
Additionally, protection can mean different things in different contexts.
In general, the goal of a vaccine is to prevent disease, especially severe disease, rather than infection itself.
As a proxy for VE, vaccine developers often test their candidates for serum neutralizing activity, which has been proposed as a biomarker for adaptive immunity in other respiratory illnesses [@doi:10.1056/nejmoa2022483].
The duration and intensity of the COVID-19 pandemic has made it possible to test multiple vaccines in phase III trials, where the effect of the vaccines on a cohort’s likelihood of contracting SARS-CoV-2 can be evaluated, whereas this has not always been feasible for other infectious diseases.
In some cases (e.g., SARS), the pathogen has been controlled before vaccine candidates were available, while in others (e.g., MERS), the scale of the epidemic has been smaller.
Vaccine development is traditionally a slow process, but the urgency of the COVID-19 pandemic created an atypical vaccine development ecosystem where fast development and production was prioritized.
Estimates of VE have been released for many vaccine candidates across a number of technology types based on phase III trial data.

However, efficacy is not a static value, and both trial efficacy and real-world effectiveness can vary across location and over time.
Shifts in effectiveness in particular have been an especially heightened topic of concern since late 2021 given the potential for variants of SARS-CoV-2 to influence VE.
Due to viral evolution, vaccine developers are in an arms race with a pathogen that benefits from mutations that reduce its susceptibility to adaptive immunity.
The evolution of several variants of concern (VOC) presents significant challenges for vaccines developed based on the index strain identified in Wuhan in late 2019.
We discuss these variants in depth elsewhere [@individual-evolution].
To date, the most significant VOC identified are Alpha (2020), Beta (2020), Gamma (2020), Delta (2021), and Omicron (2021), with various subvariants of Omicron being the most recently identified (2022).
The relative timing of studies relative to dominant VOC in the region where participants are recruited is important context for a complete picture of efficacy.
Therefore, the efficacy and/or effectiveness of vaccines in the context of these variants is discussed where information is available.

Beyond the variability introduced by time and geography, efficacy within a trial and effectiveness in the real-world setting can also differ due to cohort differences.
Patients participating in a clinical trial are likely to receive more medical oversight, resulting in better follow-up, adherence, and patient engagement [@pubmed:17112328].
Additionally, the criteria for participant inclusion in a trial often bias trials towards selection of younger, healthier individuals [@doi:10.1093/rheumatology/key109].
The ability of an RCT to accurately assess safety can be biased by the fact that a clinical trial might not reveal rare adverse events (AEs) that might become apparent on a larger scale [@doi:10.1093/rheumatology/key109].
Therefore, while clinical trials are the gold standard for evaluating vaccines for COVID-19, the results of these trials must be considered in a broader context when real-world data is available.

While the relationship between a vaccine and a pathogen is not static, the data clearly demonstrates that a variety of efficacious vaccines have been developed against SARS-CoV-2.
Here we discuss a selection of programs that use well-established vaccine biotechnologies.
These programs have been undertaken worldwide, in complement to the more cutting-edge approaches developed and distributed in the United States (U.S.), the European Union (E.U.), the United Kingdom (U.K.), and Russia [@individual-vaccines-novel].
In this review, we discuss vaccine development using two well-established technologies, whole-virus vaccination and subunit vaccination, and the role these technologies have played in the global response to the COVID-19 pandemic.

### Whole-Virus Vaccines

Whole-virus vaccines have the longest history among vaccine development approaches.
Variolation, which is widely considered the first vaccination strategy in human history, is one example [@doi:10.1016/j.jinf.2005.07.021; @doi:10.1007/978-1-4419-1339-5_2].
Famously, variolation was employed against smallpox when healthy individuals were exposed to pus from an individual infected with what was believed to be either cowpox or horsepox [@doi:10.1016/j.jinf.2005.07.021; @doi:10.1007/978-1-4419-1339-5_2; @doi:10.1377/hlthaff.24.3.611; @doi:10.1016/j.vaccine.2017.11.003].
This approach worked by inducing a mild case of a disease.
Therefore, while whole-virus vaccines confer adaptive immunity, they also raise safety concerns [@doi:10.1016/j.virol.2015.03.032; @doi:10.3389/fimmu.2019.00594; @doi:10.1377/hlthaff.24.3.611].
As of 2005, most vaccines still used whole-virus platforms [@doi:10/dn299p], and these technologies remain valuable tools in vaccine development today [@doi:10.1073/pnas.1400472111].
Whole virus vaccine candidates have been developed for COVID-19 using both live attenuated viruses and inactivated whole viruses.

#### Live-Attenuated Virus Vaccines

Live-attenuated virus vaccines (LAV), also known as replication-competent vaccines, use a weakened, living version of a disease-causing virus or a version of a virus that is modified to induce an immune response [@doi:10.1038/s41586-020-2798-3].
Whether variolation is the first example of a LAV being used to induce immunity is debated [@doi:10.1016/j.virol.2015.03.032; @doi:10.1073/pnas.1400472111].
The first deliberate (albeit pathogen-naïve) attempt to develop an attenuated viral vaccine dates back to Louis Pasteur's efforts in 1885 to inoculate a child against rabies [@url:https://www.nature.com/articles/d42859-020-00008-5].
The next intentional LAVs were developed against the yellow fever virus in 1935 and influenza in 1936 [@doi:10.1128/9781555818951].

Early efforts in LAV development relied on either the identification of a related virus that was less virulent in humans (e.g., cowpox/horsepox or rotavirus vaccines) or the culturing of a virus _in vitro_ [@doi:10.1377/hlthaff.24.3.611; @doi:10.1073/pnas.1400472111].
Today, a virus can be attenuated by passaging it in a foreign host until, due to selection pressure, the virus loses its efficacy in the original host.
Alternatively, selective gene deletion or codon deoptimization can be utilized to attenuate the virus [@doi:10.1038/s41586-020-2798-3], or foreign antigens can be integrated into an attenuated viral vector [@doi:10.1038/s41586-020-3035-9].
LAVs tend to be restricted to viral replication in the tissues around the location of inoculation [@doi:10.1128/9781555818951], and some can be administered intranasally [@doi:10.1038/s41586-020-2798-3].

Today, LAVs are used globally to prevent diseases caused by viruses such as measles, mumps, rubella, polio, influenza, varicella zoster, and the yellow fever virus [@doi:10.1016/B978-0-323-35761-6.00002-X].
There were attempts to develop LAVs against both SARS-CoV-1 and MERS-CoV [@doi:10.3389/fimmu.2020.602256], but no vaccines were approved.
It is generally recognized that LAVs induce an immune response similar to natural infection, and they are favored because they induce long-lasting and robust immunity that can protect from disease.
This strong protective effect is induced in part by the immune response to the range of viral antigens available from LAV, which tend to be more immunogenic than those from non-replicating vaccines [@url:https://www.hhs.gov/immunization/basics/types/index.html; @doi:10.3389/fimmu.2020.602256; @doi:10.1016/j.virol.2015.03.032].

#### LAV Vaccines and COVID-19

To date, LAVs have not been widely deployed against SARS-CoV-2 and COVID-19.
All the same, there are several COVID-19 LAV candidates in the early (preclinical/phase I) stages of investigation.
These candidates utilize different approaches.
Interestingly, several candidates (Meissa Vaccines' MV-014-212 and Codagenix's COVI-VAC, specifically) are administered intranasally, potentially improving accessibility by eliminating the need for sterile needles and reducing manufacturing costs, targeting conferring mucosal immunity, and reducing some issues related to vaccine hesitancy [@doi:10.1016/j.apsb.2022.11.022; @doi:10.1016/j.ebiom.2022.103841].
Additionally, although no phase III trial data is available for LAV vaccine candidates, some manufacturers have proactively sought to respond to the emergence of VOC.
Therefore, the original approach to vaccination may still prove extremely advantageous in the high-tech landscape of COVID-19 vaccine development.

##### YF-S0

One candidate in the preclinical stage is YF-S0, a single-dose LAV developed at Belgium's Katholieke Universiteit Leuven that uses live-attenuated yellow fever 17D (YF17D) as a vector for a noncleavable prefusion conformation of the spike antigen of SARS-CoV-2 [@doi:10.1038/s41586-020-3035-9].
YF-S0 induced a robust immune response in three animal models and prevented SARS-CoV-2 infection in macaques and hamsters [@doi:10.1038/s41586-020-3035-9].
Additionally, the protective effect of YF-S0 against VOC has been investigated in hamsters [@doi:10.1101/2021.11.12.468374].
Even for a small number of hamsters that developed breakthrough infections after exposure to the index strain or the Alpha variant, viral loads were very low [@doi:10.1101/2021.11.12.468374].
However, much higher rates of breakthrough infection and higher viral loads were observed when the hamsters were exposed to the Beta variant [@doi:10.1101/2021.11.12.468374].
Reduced seroconversion and nAb titers were also observed against the Beta and Gamma variants [@doi:10.1101/2021.11.12.468374].
As a result, a modified version of YF-S0, called YF-S0\*, was developed to include a modified spike protein intended to increase immunogenicity by including the full spectrum of amino acids found in the Gamma VOC as well as stabilizing the S protein's conformation [@doi:10.1101/2021.11.12.468374].
The updated vaccine was again tested in Syrian golden hamsters [@doi:10.1101/2021.11.12.468374].
No breakthrough infections were observed following vaccination with YF-S0\* and exposure to the index strain and the Alpha, Beta, Gamma, and Delta variants [@doi:10.1101/2021.11.12.468374].
YF-S0\* also reduced the infectious viral load in the lungs of several VOCs (Alpha, Beta, Gamma, and Delta) relative to a sham comparison [@doi:10.1101/2021.11.12.468374], and the likelihood of the Delta variant spreading to unvaccinated co-housed hamsters was significantly reduced by YF-S0\* [@doi:10.1101/2021.11.12.468374].
The updated vaccine was also associated with the increased production of nAbs against the Omicron variant compared to YF-S0 [@doi:10.1101/2021.11.12.468374].

##### COVI-VAC

Other programs are developing codon deoptimized LAV candidates [@url:https://news.griffith.edu.au/2020/04/23/griffith-university-researchers-on-the-road-to-covid-19-vaccine; @url:https://covid-19tracker.milkeninstitute.org; @doi:10.1073/pnas.2102775118].
This approach follows the synthetic attenuated virus engineering (SAVE) strategy to select codon substitutions that are suboptimal for the virus [@doi:10.1126/science.1155761; @doi:10.1073/pnas.2102775118].
New York-based Codagenix and the Serum Institute of India reported a successful preclinical investigation [@doi:10.1073/pnas.2102775118] of an intranasally administered deoptimized SARS-CoV-2 LAV known as COVI-VAC, and COVI-VAC entered phase I human trials and dosed its first participants in January 2021 [@url:https://covid-19tracker.milkeninstitute.org; @clinicaltrials:NCT04619628].
This vaccine is optimized through the removal of the furin cleavage site (see [@individual-pathogenesis] for a discussion of this site's importance) and deoptimization of 283 codons [@pmc:PMC8644885].
The results of the COVI-VAC phase I human trials are expected soon [@clinicaltrials:NCT04619628].

Other results suggest both potential benefits and risks to the COVI-VAC vaccine candidate.
Preclinical results suggest that the vaccine candidate may confer some protection against VOC even though it was designed based on the index strain: a poster reported that Syrian golden hamsters who received COVI-VAC were significantly less likely to lose weight following viral challenge with the Beta VOC [@pmc:PMC8644885].
On the other hand, some concerns have arisen about the possibility of spillover from LAV vaccines.
A December 2022 study analyzed SARS-CoV-2 samples isolated from COVID-19 patients in India and identified two extremely similar sequences collected on June 30, 2020 that showed a high level of recombination relative to the dominant strains at the time [@doi:10.1186/s12985-022-01945-5].
Comparing these samples to a database of SARS-CoV-2 sequences revealed they were most similar to the sequence used for COVI-VAC [@doi:10.1186/s12985-022-01945-5].
Based on phylogenetic reconstruction, the authors argued that these SARS-CoV-2 isolates were most likely to have spilled over from COVI-VAC trials [@doi:10.1186/s12985-022-01945-5].
If this was a case of spillover, the effect seems to have been limited, as these sequences were just two among over 1,600 analyzed.
However, these concerns may be one consideration in the development of LAV vaccines for COVID-19.

##### Meissa Vaccines MV-014-212

Another company, Meissa Vaccines in Kansas, U.S., which also develops vaccines for respiratory syncytial virus (RSV), has developed an intranasal live-attenuated chimeric vaccine MV-014-212 [@doi:10.1038/s41541-022-00509-6].
Chimeric vaccines integrate genomic content from multiple viruses to create a more stable LAV [@doi:10.3389/fmicb.2019.02881].
To develop a SARS-CoV-2 vaccine candidate, Meissa Vaccines built on their prior work developing RSV vaccines [@doi:10.1038/s41541-022-00509-6].
A live attenuated recombinant strain of RSV previously investigated as a vaccine candidate was modified to replace two surface glycoproteins with a chimeric protein containing components of the SARS-CoV-2 Spike protein as well as the RSV fusion (F) protein [@doi:10.1038/s41541-022-00509-6].
Preclinical results describing the intranasal administration of MV-014-212 to African green monkeys and mice indicated that the vaccine candidate produced neutralizing antibodies (nAb) as well as a cellular immune response to SARS-CoV-2 challenge, including the Alpha, Beta, and Delta VOC [@doi:10.1038/s41541-022-00509-6].
Enrollment for phase I human trials began in March 2021 and recruitment is ongoing [@url:https://covid-19tracker.milkeninstitute.org; @clinicaltrials:NCT04798001].

##### Bacillus Calmette-Guerin Vaccines

Finally, Bacillus Calmette-Guerin (BCG) vaccines that use LAVs are being investigated for the prophylaxis of COVID-19 (see online Appendix [@url:https://greenelab.github.io/covid19-review]).
The purpose of the BCG vaccine is to prevent tuberculosis, but non-specific effects against other respiratory illnesses have suggested a possible benefit against COVID-19 [@doi:10.1038/s41577-020-0337-y].
However, a multicenter trial that randomly assigned participants 60 years and older to vaccination with BCG (n = 1,008) or placebo (n = 1,006) found that BCG vaccination had no effect on the incidence of SARS-CoV-2 or other respiratory infections over the course of 12 months [@doi:10.1093/cid/ciac182].
Despite these findings, BCG vaccination was associated with a stronger cytokine (specifically, IL-6) response following _ex vivo_ stimulation of peripheral blood mononuclear cells in patients with no known history of COVID-19 [@doi:10.1093/cid/ciac182].
Additionally, SARS-CoV-2-positive individuals who had received the BCG vaccine one year prior showed increased immunoglobulin (Ig) responses to the SARS-CoV-2 spike protein and receptor binding domain (RBD) relative to individuals who had received a placebo vaccine [@doi:10.1093/cid/ciac182].
Currently, investigations of BCG vaccines against COVID-19 are being sponsored by institutes in Australia in collaboration with the Bill and Melinda Gates Foundation [@clinicaltrials:NCT04327206] and by Texas A&M University in collaboration with numerous other U.S. institutions [@clinicaltrials:NCT04348370].

##### Summary of LAV Vaccine Development

LAV vaccines for COVID-19 have not advanced as far in development as vaccines developed using other technologies.
As of December 2022, COVI-VAC was the only LAV vaccine candidate in phase III clinical trials [@url:https://covid19.trackvaccines.org/vaccines/59].
As a result, safety data is not yet available for human studies of these vaccines.
In general, though, safety concerns previously associated with LAV have been largely mitigated in the modern manufacturing process.
Manufacturers use safe and reliable methods to produce large quantities of vaccines once they have undergone rigorous preclinical studies and clinical trials to evaluate their safety and efficacy.
However, one remaining safety concern may be contributing to the relatively slow emergence of LAV candidates against COVID-19: they still may present risk to individuals who are immunocompromised [@doi:10.1016/j.copbio.2007.10.010], which is an even greater concern when dealing with a novel virus and disease.
Additional data are needed to ascertain how this technology performs in the case of SARS-CoV-2 and whether rare cases of spillover have indeed occurred.
Additionally, modifications to the design of individual vaccine candidates may make this protection more robust as SARS-CoV-2 evolves, as the limited data about LAV performance against VOC suggests.
Despite the long and trusted history of LAV development, this vaccine strategy has not been favored against COVID-19, as other technologies have shown greater expediency and safety compared to the time-consuming nature of developing LAVs for a novel virus.

### Inactivated Whole-Virus Vaccines

Inactivated whole-virus (IWV) vaccines are another well-established vaccine platform.
This platform uses full virus particles generally produced via cell culture that have been rendered non-infectious by chemical (i.e., formaldehyde or &beta;-propiolactone [@doi:10.1080/14760584.2017.1357471]) or physical (i.e., heat or ultraviolet radiation) means.
In general, these vaccines mimic the key properties of the virus that stimulate a robust immune response, but the risk of adverse reactions is reduced because the virus is inactivated and thus unable to replicate.
Though these viral particles are inactivated, they retain the capacity to prime the immune system.
The size of the viral particle makes it ideal for uptake by antigen-presenting cells, which leads to the stimulation of helper T-cells [@doi:10.1038/nri2868].
Additionally, the array of epitopes on the surface of the virus increases antibody binding efficiency [@doi:10.1038/nri2868].
The native conformation of the surface proteins, which is also important for eliciting an immune response, is preserved using these techniques [@doi:10.1016/j.virusres.2007.03.025].
Membrane proteins, which support B-cell responses to surface proteins, are also induced by this method [@doi:10.1084/jem.164.4.1114].

IWV vaccines have been a valuable tool in efforts to control many viruses.
Some targets of IWV vaccines have included influenza viruses, poliovirus, and hepatitis A virus.
Inactivated vaccines can generally be generated relatively quickly once the pathogenic virus has been isolated and can be passaged in cell culture [@doi:10.3389/fimmu.2020.602256; @doi:10.1111/1751-7915.13818].
During COVID-19, though the World Health Organization (WHO) has been slower to approve IWV vaccine candidates than those developed with nucleic acid-based technologies, IWV vaccine development was also fast.
In China, the first emergency use authorization (EUA) was granted to an IWV vaccine in July 2020, with full approval following that December [@url:https://www.reuters.com/business/healthcare-pharmaceuticals/china-gives-its-first-covid-19-vaccine-approval-sinopharm-2020-12-31; @url:https://www.nytimes.com/2020/07/16/business/china-vaccine-coronavirus.html].
The fact that these vaccines have not received as much public attention (at least in Western media) as nucleic acid vaccines for SARS-CoV-2 may be due at least in part to the novelty of nucleic acid vaccine technologies [@doi:10.1038/d41586-020-03626-1], which are more modular and immunogenic [@individual-vaccines-novel].

Past applications to human coronaviruses (HCoV) have focused predominantly on SARS-CoV-1.
Preclinical studies have demonstrated that IWV SARS-CoV-1 vaccine candidates elicited immune responses _in vivo_.
These vaccines generated nAb titers at concentrations similar to those evoked by recombinant protein vaccines [@doi:10.1002/rmv.492; @doi:10.1016/j.virusres.2007.03.025].
Studies in ferrets and non-human primates demonstrated that IWV vaccines can offer protection against infection due to nAb and SARS-CoV-1-specific T cell responses [@doi:10.1093/intimm/dxh143].
However, several attempts to develop IWV vaccines against both SARS-CoV-1 and MERS-CoV were hindered by incidences of vaccine-associated disease enhancement (VADE) in preclinical studies [@doi:10.1038/s41579-020-00462-y].
In one example of a study in macaques, an inactivated SARS-CoV-1 vaccine induced even more severe lung damage than the virus due to an enhanced immune reaction [@doi:10.1021/acsinfecdis.6b00006].
Independent studies in mice also demonstrated evidence of lung immunopathology due to VADE in response to MERS-CoV IWV vaccination [@doi:10.1080/21645515.2016.1177688; @doi:10.1128/mBio.00554-20].
The exact mechanisms responsible for VADE remain elusive due to the specificity of the virus-host interactions involved, but VADE is the subject of investigation in preclinical SARS-CoV-2 vaccine studies to ensure the safety of any potential vaccines that may reach phase I trials and beyond [@doi:10.1038/s41579-020-00462-y].

#### Application to COVID-19

Table: Inactivated whole-virus vaccines approved in at least one country [@url:https://covid19.trackvaccines.org/types-of-vaccines] as of {{viper_date_pretty}} [@url:https://covid19.trackvaccines.org].
{#tbl:approved-whole-virus}

{{viper_approved_whole_virus}}

Several whole-virus vaccines have been developed against COVID-19 and are available in countries around the world (Table @tbl:approved-whole-virus).
As of {{owid_most_recent_date}}, {{owid_inactivated_count}} vaccines developed with IWV technology are being distributed in {{owid_inactivated_countries}} countries (Figure @fig:iwv-distrib).
Evidence about the value of these vaccines to combat SARS-CoV-2 is available not only from clinical trials, but also from their roll-out following approval.
Here, a major consideration has been that vaccines often lose efficacy as mutations accumulate in the epitopes of the circulating virus; IWV vaccines may be particularly affected in such cases [@doi:10.3389/fimmu.2019.00594].
This loss of specificity over time is likely to be influenced by the evolution of the virus, and specifically by the rate of evolution in the region of the genome that codes for the antigenic spike protein.
Here we review three vaccine development programs and their successes in a real-world setting.

![
**Worldwide availability of vaccines developed using inactivated whole viruses.**
This figure reflects the number of vaccines based on whole inactivated virus technology that were available in each country as of {{owid_most_recent_date}}.
These data are retrieved from Our World in Data [@url:https://ourworldindata.org/coronavirus] and plotted using geopandas [@doi:10.5281/zenodo.5573592].
The color scale is based on the number of vaccines of this type included in the OWID dataset as a whole, not the maximum observed in a single country.
See https://greenelab.github.io/covid19-review/ for the most recent version of this figure, which is updated daily.
]({{owid_inactivated_map}} "Availability of inactivated whole virus vaccines"){#fig:iwv-distrib secno=1}

##### Sinovac's CoronaVac

One IWV vaccine, CoronaVac, was developed by Beijing-based biopharmaceutical company Sinovac.
The developers inactivated a SARS-CoV-2 strain collected in China with &beta;-propiolactone and propagated it using Vero cells [@doi:10.3389/fimmu.2020.602256].
The vaccine is coupled with an aluminum adjuvant to increase immunogenicity [@doi:10.3389/fimmu.2020.602256].
Administration follows a prime-boost regimen using a 0.5 ml dose containing 3 &mu;g of inactivated SARS-CoV-2 virus per dose [@url:https://www.who.int/publications/i/item/WHO-2019-nCoV-vaccines-SAGE_recommendation-Sinovac-CoronaVac-background-2021.1].
In phase I and II clinical trials, CoronaVac elicited a strong immunogenic response in animal models and the development of nAbs in human participants [@doi:10/fx8z; @doi:10.1126/science.abc1932; @doi:10/fpcx].
The phase I/II clinical trials were conducted in adults 18-59 years old [@doi:10/fpcx] and adults over 60 years old [@doi:10/fx8z] in China.
Safety analysis of the CoronaVac vaccine during the phase II trial revealed that most adverse reactions were either mild (grade 1) or moderate (grade 2) in severity [@doi:10/fpcx].
In adults aged 18 to 59 years receiving a variety of dosage schedules, site injection pain was consistently the most common symptom reported [@doi:10/fpcx].
In older adults, the most common local and systemic reactions were pain at the injection site (9%) and fever (3%), respectively [@doi:10/fx8z].

As of December 2022, a total of 17 CoronaVac trials had been registered in a variety of countries including the Philippines and Hong Kong [@url:https://covid19.trackvaccines.org/vaccines/7].
Two of the earliest phase III trials to produce results examined a two-dose regimen of CoronaVac following a 14-day prime boost regimen [@doi:10.1093/cid/ciab823; @doi:10/gk898z].
These trials were conducted in Turkey [@doi:10/gk898z] and Chile [@doi:10.1093/cid/ciab823] and enrolled participants over an identical period from September 2020 and January 2021.
The Chilean trial, which reported interim results regarding safety and immunogenicity, identified specific IgG nAbs against the S1 RBD and a robust IFN-&gamma; secreting T cell response was induced via immunization with CoronaVac [@doi:10.1093/cid/ciab823].
In the Turkish trial, VE was estimated to be 83.5% against symptomatic COVID-19 [@doi:10/gk898z].
In the safety and immunogenicity study, minimal AEs were reported [@doi:10/gk898z], and 18.9% of participants in the vaccine arm of the Turkish trial reported AEs compared to 16.9% of participants in the placebo group [@doi:10/gk898z].
However, 2% (n=7) of Turkish participants aged 18 to 59 reported severe AEs [@doi:10/fx8z], causing the trial to be halted for investigation [@url:https://www.nytimes.com/interactive/2020/health/sinovac-covid-19-vaccine.html].
The investigation determined that these events were unrelated to the vaccine [@doi:10/fx8z; @url:https://www.nytimes.com/interactive/2020/health/sinovac-covid-19-vaccine.html].

An additional phase III trial was conducted in Brazil between July and December 2020 following a randomized, multicenter, endpoint driven, double-blind, placebo-controlled design and enrolling nearly 10,000 healthcare workers [@doi:10.1186/s13063-020-04775-4; @doi:10.2139/ssrn.3822780].
The preprint reporting the results of this study [@doi:10.2139/ssrn.3822780] reports an efficacy of 50.7% against symptomatic COVID-19 and 100% against moderate to severe cases.
A large percentage of participants, 77.1% in the vaccine group and 66.4% in the placebo group, reported AEs, including two deaths, but all of the serious AEs were determined not to be related to the vaccine [@doi:10.2139/ssrn.3822780].
CoronaVac also appears to be suitable for use in immunocompromised patients such as those with autoimmune rheumatic diseases according to phase IV trials [@doi:10.1038/s41591-021-01469-5], and the vaccine was also well tolerated and induced humoral responses in phase I trials in children aged 3 to 17 years, which will now be examined in phase II and III clinical trials [@doi:10/gn93].

Estimates of CoronaVac's VE have varied across trials.
The 50.7% VE reported from the Brazilian trial was contested by Turkish officials, as at the time the efficacy in the Turkish trial appeared to be 91.25% [@url:https://www.reuters.com/article/us-health-coronavirus-sinovac-brazil/brazil-institute-says-coronavac-efficacy-above-50-but-delays-full-results-idUSKBN28X2CR; @url:https://www.nytimes.com/2020/12/25/health/turkey-brazil-sinovac-coronavirus-vaccine.html].
Ultimately, after multiple announcements, the efficacy debate was settled at over 50% [@url:https://www.reuters.com/article/us-health-coronavirus-sinovac-brazil/brazil-institute-says-coronavac-efficacy-above-50-but-delays-full-results-idUSKBN28X2CR; @url:https://www.nytimes.com/2020/12/25/health/turkey-brazil-sinovac-coronavirus-vaccine.html].
Subsequently, the VE for the Turkish trial was finalized at 83.5% [@doi:10/gk898z], and a prospective national cohort study in Chile reported an adjusted estimated effectiveness of 66% for the prevention of COVID-19 with an estimated 90% and 87% prevention of hospitalization and death, respectively [@doi:10.1056/NEJMoa2107715].

Based on these results, CoronaVac was approved in China, and has now been distributed in {{Sinovac_country_count}} countries across {{Sinovac_continents}}, including Brazil, Cambodia, Chile, Colombia, Laos, Malaysia, Mexico, Turkey, Ukraine, and Uruguay [@url:https://www.nytimes.com/interactive/2020/science/coronavirus-vaccine-tracker.html; @doi:10.1038/s41562-021-01122-8].
As of August 2021, Sinovac had reportedly produced over a billion doses of CoronaVac [@url:https://www.nytimes.com/interactive/2020/science/coronavirus-vaccine-tracker.html].
Outside of trials, rare cases of VADE have been reported in association with the CoronaVac vaccine [@doi:10.1155/2021/9673453].
In one case study, two male patients both presented with COVID-19 pneumonia following vaccination with CoronaVac [@doi:10.1155/2021/9673453].
This study identified the timeline of disease presentation, vaccination, and known COVID-19 exposure in the two patients and suggests that the inflammatory response induced by the vaccine could have caused an asymptomatic case of COVID-19 to present with symptoms [@doi:10.1155/2021/9673453].
However, no causal relationship between CoronaVac and COVID-19 symptom onset was evaluated, and the reports are extremely rare.

The effectiveness has also been questioned based on real-world data, such as when concerns were raised about the vaccine's effectiveness following reports that over 350 doctors became ill with COVID-19 in Indonesia despite being immunized with CoronaVac [@url:https://www.nytimes.com/2021/06/22/business/economy/china-vaccines-covid-outbreak.html].
One possible explanation for such outbreaks was the evolution of the virus.
Sera from individuals vaccinated with CoronaVac was found to show reduced neutralizing activity against the Alpha, Beta, and Delta VOC relative to the index strain [@doi:10/gnx76t].
Similarly, a second study of 25 patients in Hong Kong in late 2021 evaluated serum neutralizing activity against the index strain and the Beta VOC, Delta VOC, and two Omicron isolates [@doi:10.1093/cid/ciab1041].
They reported that all individuals were seropositive for nAbs against the index strain, 68% against the Delta variant, and 0% against the Beta VOC and Omicron isolates [@doi:10.1093/cid/ciab1041].
The Beta variant appears to be more resistant to nAbs in sera from individuals immunized with CoronaVac than the Alpha variant or wildtype virus, indicating that emerging variants may be of concern [@doi:10.1056/nejmc2103022].
Finally, a fourth study examined sera from 180 Thai healthcare workers vaccinated with CoronaVac and reported that neutralizing activity was significantly reduced against the Alpha, Delta, and Beta variants relative to the index strain [@doi:10.1016/j.jvacx.2022.100153].
Together, these results suggest that viral evolution is likely to pose a significant challenge to immunity acquired from the CoronaVac vaccine.

Therefore, studies have also evaluated whether booster doses would provide additional protection to individuals vaccinated with CoronaVac.
This strategy is supported by the fact that the antibody response elicited by CoronaVac has been found to wane following the second dose, though it was still detected six months out [@doi:10.3389/fimmu.2022.939311].
A phase I/II clinical trial of CoronaVac in an elderly cohort (adults 60 years and older) in China determined that by 6 to 8 months following the second dose, nAb titers were detected below the seropositive cutoff [@doi:10.1101/2021.08.03.21261544].
Data from two phase II trials indicated that nAb response had declined 6 months after the second dose of the primary series, but a booster dose of CoronaVac administered 8 months after the second dose markedly increased geometric mean titers of SARS-CoV-2 nAbs [@doi:10/gq6nm3].
However, the reduction of nAbs was ameliorated by a booster dose administered 8 months after the second CoronaVac dose [@doi:10/gq6nm3].
Furthermore, Chinese [@url:https://medicalxpress.com/news/2021-08-china-mixed-vaccine-trial-delta.html] and Chilean [@clinicaltrials:NCT04992182] researchers have opted to investigate options to administer different vaccines (e.g., an mRNA vaccine dose) as a booster dose to individuals who have already received two doses of the IWV vaccine CoronaVac.
Another study determined that using a viral-vectored vaccine (CanSino's Convidecia) or an mRNA vaccine (Pfizer/BioNTech's BNT162b2) instead of CoronaVac in a prime-boost vaccination regimen could induce a more robust immune response [@doi:10.1038/s41591-021-01677-z; @doi:10.1038/s41591-022-01705-6].
The WHO now suggests that a booster dose, either homologous or heterologous, can be considered 4 to 6 months after the primary series, especially for high-risk groups [@url:https://www.who.int/news-room/feature-stories/detail/the-sinovac-covid-19-vaccine-what-you-need-to-know].

##### Sinopharm's Covilo

Two additional IWV vaccine candidates were developed following a similar approach by the state-owned China National Pharmaceutical Group Co., Ltd., more commonly known as Sinopharm CNBG.
One, known as BBIBP-CorV or Covilo, was developed in Beijing using the HB02 variant of SARS-CoV-2.
The other was developed at Sinopharm CNBG's Wuhan Institute using the WIV04 variant of SARS-CoV-2 [@doi:10.1038/s41541-021-00292-w].
The viruses were purified, propagated using Vero cells, isolated, and inactivated using &beta;-propiolactone [@doi:10.1016/j.cell.2020.06.008; @doi:10.1038/s41541-021-00292-w].
Both vaccines are adjuvanted with aluminum hydroxide [@doi:10.1016/j.cell.2020.06.008; @doi:10.1038/s41541-021-00292-w].
Here, we focus on Covilo.

Preclinical studies indicated that Covilo induced sufficient nAb titers in mice, and a prime-boost immunization scheme of 2 &mu;g/dose was sufficient to protect rhesus macaques from disease [@doi:10.1016/j.cell.2020.06.008].
In phase II trials, the Covilo vaccine appeared well-tolerated, with 23% of participants in the vaccine condition (482 total participants, 3:1, vaccine:placebo) reporting at least one adverse reaction characterized as mild to moderate [@doi:10/ghjkrf].
No evidence of VADE was detected using this vaccine in phase II data [@doi:10.1001/jama.2020.15543].
In phase III trials conducted between July and December 2020, Covilo achieved an efficacy of 72.8% and was well tolerated [@doi:10.1001/jama.2021.8565].
However, questions were raised about efficacy when Sinopharm affiliates in the UAE in early December 2020 claimed the vaccine had 86% efficacy, which was later at odds with a Sinopharm Beijing affiliate that stated that Covilo had a 79.34% efficacy later that same month [@url:https://www.reuters.com/article/health-coronavirus-china-vaccine-int-idUSKBN2940CA].

Studies have also investigated expected differences in real-world effectiveness of Covilo given the continuing evolution of SARS-CoV-2.
The antibody response elicited by Covilo was found to wane, but still to be detectable, by six months following the second dose [@doi:10.3389/fimmu.2022.939311].
One study showed that the Alpha variant exhibited very little resistance to neutralization by sera of those immunized with Covilo, but the Beta variant was more resistant to neutralization by almost a factor of 3 [@doi:10.1056/NEJMc2103022].
Another study examined sera from 282 participants and used a surrogate neutralizing assay, a test that generally correlates with nAbs, to determine that Covilo appears to induce nAbs against the binding of the RBD of wild type SARS-CoV-2 and the Alpha, Beta, and Delta variants to ACE2 [@doi:10.1101/2021.07.15.21260621].
Notably, a preprint reported that antisera (i.e., the antibody-containing component of the sera) from 12 people immunized with Covilo exhibited nAb capacity against the Beta variant (B.1.351), wild type SARS-CoV-2 (NB02), and one of the original variants of SARS-CoV-2 (D614G) [@doi:10.1101/2021.02.01.429069].
As with many other vaccines, booster doses are being evaluated to mitigate some of the issues arising from viral evolution.
A study of healthcare workers in China has since indicated that a booster shot of Covilo elevates B cell and T cell responses and increases nAb titers [@doi:10.1038/s41421-022-00373-7].
In May 2021, the UAE announced it would consider booster shots for all citizens who had been immunized with Covilo, which was shortly followed by a similar announcement in Bahrain, and by August 29, 2021, the UAE mandated booster shots for all residents who had received Covilo [@url:https://www.nytimes.com/interactive/2020/science/coronavirus-vaccine-tracker.html].

##### Bharat Biotech's Covaxin

Another IWV vaccine candidate was developed by Bharat Biotech International Ltd., which is the biggest producer of vaccines globally, in collaboration with the Indian Council of Medical Research (ICMR) National Institute of Virology (NIV).
This candidate is known as Covaxin or BBV152.
Preclinical studies of Covaxin in hamsters [@doi:10.21203/rs.3.rs-76768/v1] and macaques [@doi:10.1038/s41467-021-21639-w] indicated that the vaccine induced protective responses deemed sufficient to move forward to human trials.
Phase I (July 2020) and phase I/II (September to October 2020) studies indicated that Covaxin adjuvanted with alum and a Toll-like receptor 7/8 (TLR7/8) agonist was safe and immunogenic [@doi:10/gkrthh; @doi:10/gh7597].
These two studies demonstrated that the vaccine induced significant humoral and cell-mediated responses, as assessed by measuring binding [@doi:10/gkrthh] and neutralizing [@doi:10/gkrthh; @doi:10/gh7597] antibodies, cytokines [@doi:10/gkrthh; @doi:10/gh7597], CD3^+^, CD4^+^, and CD8^+^ T-cells [@doi:10/gkrthh], with some formulations also eliciting Th1-skewed memory T-cell responses [@doi:10/gh7597].
Only mild to moderate side-effects were reported upon immunization [@doi:10/gkrthh; @doi:10/gh7597], and in phase II trials, the Covilo vaccine appeared well-tolerated [@doi:10/ghjkrf].

In India, the Covaxin vaccine received emergency authorization on January 3, 2021, but the phase III data was not released until March 3, 2021, and even then it was communicated via press release [@url:https://www.bharatbiotech.com/images/press/covaxin-phase3-efficacy-results.pdf].
This press release reported 80.6% efficacy in 25,800 participants [@url:https://www.bharatbiotech.com/images/press/covaxin-phase3-efficacy-results.pdf; @url:https://www.biogenetech.co.th/wp-content/uploads/2021/03/5-Ocugen.pdf], spurring Zimbabwe to follow suit and authorize the use of Covaxin [@url:http://www.xinhuanet.com/english/2021-03/04/c_139783893.htm].
A detailed preprint describing the double-blind, randomized, controlled phase III trial that enrolled between November 2020 and January 2021 became available in July 2021 [@doi:10.1101/2021.06.30.21259439], and the results collected as of May 17, 2021 were published in December 2021 [@doi:10/gnkdnx].
Based on a final enrollment of 25,798 people (~1:1 vaccine:placebo), overall VE against symptomatic COVID-19 was estimated at 77.8% and against severe disease and asymptomatic infection was reported as 93.4% and 63.6%, respectively [@doi:10/gnkdnx].
The vaccine was also reported to be well tolerated, with fewer severe events occurring in the Covaxin group (0.3%) than in the placebo group (0.5%) [@doi:10/gnkdnx].
One case of a serious AE potentially related to the vaccine, immune thrombocytopenic purpura, was reported, although this patient was seropositive for SARS-CoV-2 at the baseline observation point [@doi:10/gnkdnx].
As of {{owid_commit_date_pretty}}, Covaxin was approved for emergency use in {{Covaxin_country_count}} countries across {{Covaxin_continents}}, including Guyana, India, Iran, Zimbabwe, Nepal, Mauritius, Mexico, Nepal, Paraguay, and the Philippines [@url:https://covid19.trackvaccines.org/vaccines/9].

Like with all vaccines, the continued evolution of SARS-CoV-2 poses a challenge to the effectiveness of Covaxin.
In this case, the phase III clinical trial did evaluate the efficacy of Covaxin in response to variants circulating in mid-to-late 2020 [@doi:10/gnkdnx].
In agreement with previous studies demonstrating sera from individuals vaccinated with Covaxin efficiently neutralized the Alpha variant (B.1.1.7) and the Delta variant (B.1.617.2) [@doi:10.1101/2021.07.30.454511; @doi:10.1093/jtm/taab104; @doi:10.1093/jtm/taab051], the phase III trial reported a 65.2% efficacy against the Delta variant (B.1.617.2) [@doi:10/gnkdnx].
Another study reported that sera from individuals immunized with Covaxin produced effective nAbs against the Delta variant and the so-called Delta plus variant (AY.1) [@doi:10.1093/jtm/taab154].
Indeed, sera obtained from Covaxin boosted individuals (n=13) [@doi:10.1101/2022.01.24.22269189] and those who were vaccinated with Covaxin but recovered from a breakthrough infection (n=31) also neutralized the Omicron variant [@doi:10.1016/j.jinf.2022.03.016].
Therefore, the data suggest that the vaccine does continue to confer protection to VOC.

The authorization of Covaxin has also offered opportunities to monitor how well the clinical trial results translate into a real-world setting.
Additionally, an effort to monitor AEs and COVID-19 cases following vaccine roll-out reported that most side effects were mild and that cases were rare, even though this data would seem to have been collected during the severe wave of COVID-19 brought on by the Delta VOC in India in early 2021; at the same time, the sample sizes were extremely small [@doi:10.53411/jpadr.2021.2.3.5].
Similarly, larger studies of adults (June to September 2021) [@doi:10.1002/jmv.27655] and adolescents (beginning in January 2022) [@doi:10.1007/s40264-022-01226-8] who received the vaccine outside of a trial setting reported that safety was similar across age groups, with no severe AEs reported in adults and with no serious AEs reported in adolescents, although 0.9% (6 individuals) reported severe AEs.
However, a much lower effectiveness (22-29%) was estimated in a real-world setting during an analysis of cases in healthcare workers from April to May 2021 [@doi:10.1080/21645515.2022.2034456].
All the same, monitoring of hospitalized COVID-19 patients between April and June 2021 indicated that the vaccines were highly effective against preventing severe illness [@doi:10.1101/2021.08.26.21262705].

It is not yet clear what level of protection Covaxin offers beyond 6 to 8 months post the second vaccine; consequently, the potential requirement of a booster immunization is being explored [@url:https://www.hindustantimes.com/india-news/covaxin-booster-dose-what-is-it-what-does-govt-say-about-this-101625644184446.html].
Furthermore, Bharat Biotech is considering other vaccine regimens such as providing one initial immunization with Covaxin followed by two immunizations with its intranasal vaccine (BBV154) [@url:https://www.business-standard.com/article/current-affairs/booster-dose-bharat-biotech-s-nasal-vaccine-may-be-used-with-covaxin-121092500034_1.html].
U.S.-based Ocugen Inc., a co-development partner of Bharat Biotech, is leading the application for an Emergency Use Authorization (EUA) for Covaxin intended for the U.S. market.
It has been reported that Bharat Biotech will soon release its phase II and III pediatric trial results [@url:https://timesofindia.indiatimes.com/india/bharat-biotech-to-submit-covaxin-kids-trials-data-to-dcgi-in-weeks-time/articleshow/86392325.cms].

However, the WHO approval of the Covaxin has been delayed [@url:https://www.indiatoday.in/coronavirus-outbreak/video/who-emergency-approval-for-covaxin-delayed-till-october-5-1856178-2021-09-23], and in April 2022, the WHO suspended procurement of Covaxin due to concerns about deviation from good manufacturing practice in their production facilities [@url:https://extranet.who.int/pqweb/vaccines/suspension-supply-covid-19-vaccine-covaxin; @doi:10.1136/bmj.o902].
All the same, no safety issues had been reported in association with this vaccine, and the suspension was unlikely to affect distribution given that Bharat Biotech had not been supplying doses through this mechanism [@url:https://www.businesstoday.in/coronavirus/story/fda-lifts-hold-on-bharat-biotechs-covaxin-clinical-trials-in-us-334915-2022-05-24].
Clinical trials had recommenced in the United States as of May 2022 [@url:https://www.businesstoday.in/coronavirus/story/fda-lifts-hold-on-bharat-biotechs-covaxin-clinical-trials-in-us-334915-2022-05-24].

#### Summary of IWV Vaccine Development

In the past, problems that arose during the manufacturing of IWV vaccines could present safety issues, but oversight of the manufacturing process has helped to improve IWV vaccine safety [@doi:10.1163/25895893-bja10009].
Nevertheless, the departure from norms necessitated by the COVID-19 crisis raised concerns about whether oversight would occur at pre-pandemic standards [@doi:10.1163/25895893-bja10009].
In general, the IWV COVID-19 vaccines have reported very few issues with safety.
Additionally, safety audits have proactively identified concerns, as demonstrated with the WHO's suspension of Covaxin.

More concern has arisen around the issue of effectiveness due to the reduced neutralizing activity of IWV vaccines against VOC relative to the index strain.
In several cases, estimates of VE have varied widely across different trials of a single vaccine.
Such issues are likely to be exacerbated by spatiotemporal differences in viral evolution, though in the case of the very high estimate generated by the Turkish trial of CoronaVac [@doi:10/gk898z], the design of the study may have inflated the VE estimate [@doi:10/jrrf].
Regardless, the authors of the original trial argued that all of the trials suggest a very high efficacy against severe disease [@doi:10/jrrg], as is the case for all of the IWV vaccines discussed here.
In addition to issues related to the evolution of SARS-CoV-2, it is important to consider the duration of immunity over time.
With IWV vaccines, heterologous vaccine boosters are being considered in many cases.
Today, the WHO has developed recommendations for booster immunization for several whole-virus vaccines.
In some cases (Valneva-VLA2001 [@1BhKEx9uG], Covaxin [@url:https://www.who.int/news-room/feature-stories/detail/the-bharat-biotech-bbv152-covaxin-vaccine-against-covid-19-what-you-need-to-know], Covilo [@url:https://www.covid19infovaccines.com/en-posts/is-the-sinopharm-bibp-covilo-covid-19-vaccine-safe-and-effective], Sinopharm-WIBP Inactivated (Vero Cell) [@sinopharm-vaccine-explainer]), boosters are recommended only for high-risk and/or high-priority groups (e.g., the immunocompromised and medical professionals, respectively), while for Sinovac's CoronaVac [@url:https://www.who.int/news-room/feature-stories/detail/the-sinovac-covid-19-vaccine-what-you-need-to-know], they are recommended more broadly.
Studies are also investigating the effects of booster doses in other vaccines [@doi:10.3390/v14092016; @clinicaltrials:NCT05172193; @clinicaltrials:NCT04510207], though some are being investigated or deployed primarily as heterologous boosters in populations vaccinated with a different primary series [@doi:10.1080/21645515.2022.2122503; @doi:10.3390/vaccines10111800 @clinicaltrials:NCT05172193].

As new vaccines are approved by the WHO, more time elapses since many received the primary series, and new variants emerge, booster recommendations are likely to increase.
Therefore, IWV vaccines have played an important role in vaccine access during the initial phase of vaccination against COVID-19, but many IWV vaccinees may receive booster doses developed with emergent vaccine technologies like DNA and mRNA.
In head-to-head comparisons, these types of vaccines were typically found to outperform IWV vaccines (e.g., [@doi:10.1093/cid/ciab1041; @doi:10.1002/jmv.27396; @doi:10.1016/j.jvacx.2022.100153].
At the same time, IWV vaccines are among the easiest to store and transport due to requiring refrigeration only at 2 to 8&#176;C and remaining stable for years at a time [@doi:10.1001/jama.2021.8565].
Therefore, these vaccines are likely to continue to play an important role in vaccine equity and accessibility.

### Subunit Vaccines

Efforts to overcome the limitations of live-virus vaccines led to the development of approaches first to inactivate viruses (circa 1900), leading to IWV vaccines, and then to purifying proteins from viruses cultured in eggs (circa 1920) [@doi:10.1073/pnas.1400472111; @doi:10.1073/pnas.1402981111].
The purification of proteins then set the stage for the development of subunit vaccines based on the principle that the immune system can be stimulated by introducing one or more proteins or peptides isolated from the virus.
Today, such approaches often use antigens isolated from the surface of the viral particle that are key targets of the immune system (protein subunit vaccines).
Advances in biological engineering have also facilitated the development of approaches like viral-like particle (VLP) vaccines using nanotechnology [@doi:10.1007/978-1-4939-1417-3_9].
VLPs share the conformation of a virus's capsid, thereby acting as an antigen, but lack the replication machinery [@doi:10/dg35hw].

Unlike whole-virus vaccines, which introduce the whole virus, subunit vaccines stimulate the immune system by introducing one or more proteins or peptides of the virus that have been isolated.
The main advantage of this platform is that subunit vaccines are considered very safe, as the antigen alone cannot cause an infection [@doi:10.1016/j.addr.2021.01.001].
Both protein subunit and VLP vaccines thus mimic the principle of whole virus vaccines but lack the genetic material required for replication, removing the risk of infection [@doi:10.1186/s12951-021-00806-7].
Protein subunit vaccines can stimulate antibodies and CD4^+^ T-cell responses [@doi:10.1007/978-1-4615-1823-5; @doi:10/dg35hw].

The subunit approach is also favored for its consistency in production.
The components can be designed for a highly targeted immune response to a specific pathogen using synthetic immunogenic particles, allowing the vaccine to be engineered to avoid allergen and reactogenic sequences [@doi:10.3390/vaccines2030515].
One limitation is that, in the case of protein subunit vaccines, adjuvants are usually required to boost the immune response [@doi:10.1517/14712598.2011.573624] (see online Appendix [@url:https://greenelab.github.io/covid19-review]).
Adjuvants, which are compounds that elicit an immunogenic effect, include alum (aluminum hydroxide), squalene- or saponin-based adjuvants, and Freund’s incomplete/complete adjuvants, although the latter is avoided in human and veterinary medicine due to high toxicity [@doi:10.1016/j.vaccine.2019.04.055; @doi:10.3390/vaccines2030515; @doi:10.1093/ilar.46.3.280].

Protein subunit vaccine development efforts for both SARS-CoV-1 and MERS-CoV explored a variety of immunogens as potential targets.
The search for a potential SARS-CoV-1 vaccine included the development of vaccines based on the full-length or trimeric S protein [@doi:10.1128/JVI.00083-06; @doi:10.1089/vim.2012.0076; @doi:10.1016/j.vaccine.2006.01.059], those focused on the RBD protein only [@doi:10.1016/j.vaccine.2006.10.031; @doi:10.1016/j.bbrc.2009.05.003; @doi:10.1089/vim.2009.0090; @doi:10.1016/j.vaccine.2006.06.084] or non-RBD S protein fragments [@doi:10.1089/vim.2012.0076; @doi:10.1089/dna.2005.24.510], and those targeting the N and M proteins [@doi:10.1128/jcm.43.8.3718-3726.2005; @doi:10.1016/j.vaccine.2009.05.073; @doi:10.1016/j.vaccine.2006.01.058].
These efforts have been thoroughly reviewed elsewhere [@doi:10.3389/fmicb.2020.00298].
There have been examples of successful preclinical research including candidate RBD219N-1, a 218-amino-acid residue of the SARS-CoV-1 RBD that, when adjuvanted to aluminum hydroxide, was capable of eliciting a high antibody response of both nAbs and RBD-specific monoclonal antibodies in both pseudovirus and live virus infections of immunized mice [@doi:10.4161/hv.27464].

Similarly to the SARS-CoV-1 vaccine candidates, the MERS-CoV protein subunit vaccine candidates generally target the RBD [@doi:10.3389/fmicb.2020.00298; @doi:10.1016/j.vaccine.2006.10.031; @doi:10.1016/j.ebiom.2015.08.031; @doi:10.1371/journal.pone.0112602; @doi:10.1016/j.vaccine.2018.02.065; @doi:10.1016/j.virol.2016.10.005], with some targeting the full length S protein [@doi:10.1073/pnas.1707304114], non-RBD protein fragments such as the SP3 peptide [@doi:10.1089/vim.2014.0080], and the recombinant N-terminal domain (rNTD) [@doi:10.1016/j.vaccine.2016.11.064].
Other strategies investigating the potential use of the full length S DNA have also been investigated in mice and rhesus macaques, which elicited immune responses [@doi:10.1038/ncomms8712], but these responses were not as effective as the combination of S DNA and the S1 subunit protein together [@doi:10.1038/ncomms8712; @doi:10.1016/j.antiviral.2016.07.015].
No protein subunit vaccine for MERS-CoV has progressed beyond preclinical research to date.
VLPs have been investigated for development of vaccines against MERS and SARS [@doi:10.1016/j.vaccine.2020.07.003; @doi:10.1016/j.vaccine.2014.04.016] including testing in animal models [@doi:10.18632/oncotarget.8475; @doi:10.1007/s12250-018-0064-8], but once again, only preclinical data against HCoV has been collected [@doi:10.1186/s12929-020-00695-2].
However, protein subunit vaccines do play a role in public health and have contributed to vaccination against hepatitis B [@doi:10/d4g86c] and pertussis [@doi:10.1128/mBio.01339-14; @doi:10.1371/journal.ppat.1003418] since the 1980s and human papillomavirus since 2006 [@doi:10.1188/06.CJON.559-560].
They are likely to continue to contribute to public health for the foreseeable future due to ongoing research in vaccines against influenza, SARS-CoV-2, Epstein-Barr virus, dengue virus, and human papillomavirus among others [@doi:10.1016/j.micinf.2014.12.006; @url:https://covid19.trackvaccines.org/vaccines; @doi:10.1080/21655979.2016.1191707].

#### Application to COVID-19

Table: Subunit vaccines approved for use in at least one country [@url:https://covid19.trackvaccines.org/types-of-vaccines] as of {{viper_date_pretty}} [@url:https://covid19.trackvaccines.org].
{#tbl:approved-subunit}

{{viper_approved_subunit}}

The development of subunit vaccines against SARS-CoV-2 is a remarkable achievement given the short period of time since the emergence of SARS-CoV-2 in late 2019, particularly considering these types of vaccines have not played a major role in previous pandemics compared to LAV and IWV vaccines.
More than 20 protein subunit vaccines from companies such as Sanofi/GlaxoSmithKline, Nanogen, and the Serum Institute of India have entered clinical trials for COVID-19 since the beginning of the pandemic [@url:https://covid19.trackvaccines.org/vaccines], {{viper_num_approved_subunit}} have been approved, and at least {{owid_protein_subunit_count}} are being administered worldwide [@doi:10.1038/s41562-021-01122-8; @url:https://covid19.trackvaccines.org] (Table @tbl:approved-subunit).
As of {{owid_most_recent_date}}, protein subunit vaccines are being distributed in at least {{owid_protein_subunit_countries}} countries (Figure @fig:ps-distrib).

![
**Worldwide availability of vaccines developed using protein subunit.**
This figure reflects the number of vaccines based on protein subunit technology that were available in each country as of {{owid_most_recent_date}}.
These data are retrieved from Our World in Data [@url:https://ourworldindata.org/coronavirus; @doi:10.1038/s41562-021-01122-8] and plotted using geopandas [@doi:10.5281/zenodo.5573592].
The color scale is based on the number of vaccines of this type included in the OWID dataset as a whole, not the maximum observed in a single country.
See https://greenelab.github.io/covid19-review/ for the most recent version of this figure, which is updated daily.
]({{owid_protein_subunit_map}} "Availability of protein subunit vaccines"){#fig:ps-distrib secno=1}

VLP vaccines have not progressed as rapidly.
Programs seeking to develop VLP vaccines have used either the full-length S protein or the RBD of the S protein specifically as an antigen, although some use several different SARS-CoV-2 proteins [@doi:10.1016/j.addr.2021.01.001].
As of {{owid_most_recent_date}}, only one VLP was available in one country (Canada) [@doi:10.1038/s41562-021-01122-8].<!--Canada/Covifenz info is hardcoded-->

![
**Worldwide availability of vaccines developed with VLPs.**
This figure reflects the number of vaccines based on VLP technology that were available in each country as of {{owid_most_recent_date}}.
These data are retrieved from Our World in Data [@url:https://ourworldindata.org/coronavirus] and plotted using geopandas [@doi:10.5281/zenodo.5573592].
The color scale is based on the number of vaccines of this type included in the OWID dataset as a whole, not the maximum observed in a single country.
See https://greenelab.github.io/covid19-review/ for the most recent version of this figure, which is updated daily.
]({{owid_VLP_map}} "Availability of protein subunit vaccines"){#fig:vlp-distrib secno=1}

#### Novavax's Nuvaxovid

NVX-CoV2373, also known as Nuvaxovid or Covovax [@url:https://www.who.int/news-room/feature-stories/detail/the-novavax-vaccine-against-covid-19-what-you-need-to-know], is a protein subunit vaccine for SARS-CoV-2 produced by U.S. company Novavax and partners.
Nuvaxovid is a protein nanoparticle vaccine constructed from a mutated prefusion SARS-CoV-2 spike protein in combination with a specialized saponin-based adjuvant to elicit an immune response against SARS-CoV-2 [@doi:10.1056/NEJMoa2026920].
The spike protein is recombinantly expressed in Sf9 insect cells [@doi:10.1038/s41467-020-20653-8], which have previously been used for several other FDA-approved protein therapeutics [@doi:10.1021/acs.iecr.8b00985], and contains mutations in the furin cleavage site (682-RRAR-685 to 682-QQAQ-685) along with two proline substitutions (K986P and V987P) that stabilize the protein [@doi:10.3389/fimmu.2021.660198], including improving thermostability [@doi:10.1038/s41467-020-20653-8].

In preclinical mouse models, Nuvaxovid elicited high anti-spike IgG titers 21 to 28 days post-vaccination that could neutralize the SARS-CoV-2 virus and protect the animals against viral challenge, with particularly strong effects when administered with the proprietary adjuvant Matrix-M^TM^ [@doi:10.1038/s41467-020-20653-8].
In a phase I/II trial, a two-dose regimen of Nuvaxovid was found to induce anti-spike IgG levels and nAb titers exceeding those observed in convalescent plasma donated by symptomatic patients [@doi:10.1056/NEJMoa2026920].
In line with the preclinical studies, the use of Matrix-M adjuvant further increased anti-spike immunoglobulin levels and induced a Th1 response.

In a phase III randomized, observer-blinded, placebo-controlled clinical trial in the U.K., 14,039 participants received two 5-&mu;g doses of Nuvaxovid or placebo administered 21 days apart in a 1:1 ratio from late September to late November 2020 [@doi:10.1056/nejmoa2107659].
The primary endpoint of the trial was the occurrence or absence of PCR-confirmed, symptomatic mild, moderate or severe COVID-19 from 7 days after the second dose onward [@doi:10.1056/NEJMoa2107659].
The VE was reported to be 89.7%, with a total of 10 patients developing COVID-19 in the vaccine group versus 96 in the placebo group [@doi:10.1056/NEJMoa2107659].
No hospitalizations or deaths were reported in the vaccine group [@doi:10.1056/NEJMoa2107659].
An additional phase III randomized, observer-blinded, placebo-controlled trial was conducted in the U.S. and Mexico, enrolling 29,949 participants and administering at least 1 vaccine in a 2:1 ratio from late December 2020 to late February 2021 [@doi:10.1056/NEJMoa2116185].
This trial [@doi:10.1056/NEJMoa2116185] used the same primary endpoints as the initial phase III trial conducted in the U.K. [@doi:10.1056/nejmoa2107659].
A vaccine efficacy of 90.4% was reported based on 77 cases total, 63 of which occurred in the placebo group [@doi:10.1056/NEJMoa2116185].
All moderate to severe cases of COVID-19 occurred in the placebo group [@doi:10.1056/NEJMoa2116185].
Hospitalization and death were not evaluated as individual secondary endpoints, but were instead included in the definition of severe COVID-19; all-cause mortality was comparable between the placebo and treatment conditions [@doi:10.1056/NEJMoa2116185].

In both trials, the vaccine was found to be well-tolerated [@doi:10.1101/2021.10.05.21264567; @doi:10.1056/NEJMoa2107659].
Analysis of 2,310 participants in the U.K. trial revealed that solicited AEs were much more common in the vaccine group than the placebo group across both doses, but the rate of unsolicited events was, while still higher in the vaccine group, much more similar [@doi:10.1056/NEJMoa2107659].
A small number of severe AEs were reported by vaccine recipients, including one case of myocarditis; however, the myocarditis was determined to be viral myocarditis [@doi:10.1056/NEJMoa2107659].
Common AEs were generally considered mild, with low incidences of headache, muscle pain, and fatigue [@doi:10.1056/NEJMoa2116185].
In the trial conducted in the U.S. and Mexico, once again, the most common symptoms included headache, fatigue, and pain, as well as malaise [@doi:10.1056/NEJMoa2116185].
Here, severe AEs were balanced across the vaccine and placebo groups [@doi:10.1056/NEJMoa2116185].
Thus, both trials suggested that the Nuvaxovid vaccine is safe and effective against COVID-19.

However, Novavax experienced significant challenges in preparing Nuvaxovid for distribution.
Prior to the pandemic's onset, Novavax had sold their manufacturing facilities and reduced their staff dramatically [@url:https://www.asbmb.org/asbmb-today/industry/060422/novavax-missed-its-global-moonshot-but-is-angling].
As a result, once they began producing Nuvaxovid, they struggled to establish a stable relationship with contractors who could produce the vaccine [@doi:10.1136/bmj.n2965], especially given the challenge of producing vaccines at scale [@doi:10.1126/science.abc9588].
Additionally, Novavax was not able to meet the purity standards laid out by the FDA [@url:https://www.politico.com/news/2021/10/19/novavax-vaccine-rush-process-global-campaign-516298].
Eventually, the manufacturing issues were resolved [@url:https://www.cnbc.com/2022/05/13/novavax-confident-covid-vaccine-will-receive-fda-authorization-in-june-after-delays.html], and Nuvaxovid has since been authorized by the WHO [@url:https://www.who.int/news/item/17-12-2021-who-lists-9th-covid-19-vaccine-for-emergency-use-with-aim-to-increase-access-to-vaccination-in-lower-income-countries] and by political entities, including the United Kingdom [@url:https://www.gov.uk/government/news/novavax-covid-19-vaccine-nuvaxovid-approved-by-mhra], the E.U. [@ema-nuvaxovid], and the U.S. [@url:https://www.fda.gov/news-events/press-announcements/coronavirus-covid-19-update-fda-authorizes-emergency-use-novavax-covid-19-vaccine-adjuvanted].
These delays obstructed some of the goals of the vaccine development program, which was undertaken with significant investment from the U.S. government through Operation Warp Speed [@url:https://www.politico.com/news/2021/10/19/novavax-vaccine-rush-process-global-campaign-516298].
Novavax was supposed to provide over a billion doses of Nuvaxovid to countries around the world through the COVID-19 Vaccines Global Access (COVAX) Facility [@url:https://www.politico.com/news/2021/10/19/novavax-vaccine-rush-process-global-campaign-516298].
However, following the delays, Gavi (which oversees COVAX) terminated the agreement, leading to ongoing legal disagreements between the nonprofit and Novavax as of late 2022 [@url:https://www.reuters.com/business/healthcare-pharmaceuticals/gavi-says-it-is-not-breach-novavax-vaccine-deal-2022-11-22; @url:https://www.cnbc.com/2022/05/13/novavax-confident-covid-vaccine-will-receive-fda-authorization-in-june-after-delays.html].

As with other vaccines, the question of how well Nuvaxovid continues to provide protection as SARS-CoV-2 evolves has been raised.
_Post hoc_ analysis in the phase III trial indicated a VE of 86.3% against the Alpha variant (identified based on the presence of the 69–70del polymorphism) and 96.4% against viral specimens lacking the 69-70del polymorphism [@doi:10.1056/NEJMoa2107659].
In the second phase III trial [@doi:10.1101/2021.10.05.21264567], whole-genome sequencing was obtained from 61 of the 77 observed cases, and 79% of infections were identified as a VOC or variant of interest (VOI) known at the time of the study.
Vaccine efficacy against cases caused by VOC, among which the Alpha variant was predominant (88.6%), was reported to be 92.6% [@doi:10.1101/2021.10.05.21264567].
In late 2020, an analysis of efficacy in South African adults revealed an overall efficacy of 60.1% and a slightly lower efficacy of 50.1% against the Beta variant (B.1.351) in particular [@doi:10.1056/NEJMoa2103055].

The company has also initiated the development of new constructs to select candidates that can be used as a booster against new strains and plans to initiate clinical trials for these new constructs in the second quarter of 2021.
An analysis of a booster dose of Nuvaxovid administered six months after the primary series revealed a significant increase in neutralizing activity against VOC including Delta and Omicron [@doi:10.1101/2021.12.23.21267374].
This trial was conducted at 18 sites across the United States and Australia [@clinicaltrials:NCT04368988].
Novavax has also initiated booster trials in the U.K. [@url:https://www.nytimes.com/interactive/2020/science/coronavirus-vaccine-tracker.html].
Boosters may be especially important given that Omicron and related variants, in particular, may be associated with significantly reduced efficacy of Nuvaxovid [@doi:10.1101/2022.07.14.500148].

Given the apparent need for boosters, interest has also emerged in whether booster doses of Nuvaxovid can be safely administered along with annual flu vaccines.
In a subgroup of approximately 400 patients enrolled from the U.K. phase III trial who received either Nuvaxovid or a placebo at a ratio of 1:1, a concomitant dose of adjuvanted seasonal influenza vaccines (either a trivalent vaccine or a quadrivalent vaccine) was administered [@doi:10.1101/2021.06.09.21258556].
This study demonstrated that the vaccines could be safely administered together [@doi:10.1101/2021.06.09.21258556].
While no change to the immune response was noted for the influenza vaccine, a notable reduction of the antibody response elicited by Nuvaxovid was reported, but efficacy was still high at 87.5% [@doi:10.1101/2021.06.09.21258556].
Novavax has since started phase I/II trials to investigate the administration of its own influenza vaccine, NanoFlu, concomitantly with Nuvaxovid [@url:https://ir.novavax.com/2021-09-08-Novavax-Initiates-Phase-1-2-Clinical-Trial-of-Combination-Vaccine-for-COVID-19-and-Seasonal-Influenza].
The combination appeared to be safe and effective in preclinical studies [@doi:10.1101/2021.05.05.442782].

#### The Cuban Center for Genetic Engineering and Biotechnology's Abdala Vaccine

Another notable protein subunit vaccine development program came out of Cuba.
Concerned about their ability to access vaccines, especially given the U.S.'s embargo [@doi:10.1038/d41586-021-03470-x], health officials in this developing country made the decision in March 2020 to undertake vaccine development on their own [@doi:10.37757/mr2022.v24.n3-4.13].
Today, three Cuban protein subunit vaccines have been approved for use: Abdala, which was developed at the Cuban Genetic Engineering and Biotechnology Center and SOBERANA 02 and SOBERANA Plus, which were developed at Cuba’s Finlay Vaccine Institute (Instituto Finlay de Vacunas Cuba) [@doi:10.37757/mr2022.v24.n3-4.13].
Here, we focus on the development of the Abdala vaccine, but SOBERANA 01/02/Plus vaccine development program has also achieved great success and reported VEs of over 90% in the three-dose regimen [@doi:10.1016/j.lana.2022.100423; @doi:10.1016/j.medj.2022.08.001].

Abdala, also known as CIGB-66, was developed using yeast as a low-cost alternative to mammalian cell expression systems (e.g., human embryonic kidney cells) to cultivate the recombinant proteins that form the basis of this protein subunit vaccine [@doi:10.1016/j.nbt.2022.08.002].
A sequence corresponding to the RBD of the Spike protein in the index strain of SARS-CoV-2 was codon optimized for expression in yeast, and the RBD proteins were then purified and used to inoculate mice, rats, and African green monkeys [@doi:10.1016/j.nbt.2022.08.002].
In addition to the proteins, the vaccine candidate included an adjuvant, aluminum hydroxide gel [@doi:10.1016/j.nbt.2022.08.002].
Comparing the immunogenicity of the yeast-cultivated proteins to those cultivated in human embryonic kidney cells revealed no significant difference in the immune response [@doi:10.1016/j.nbt.2022.08.002].

Based on promising results in laboratory animal testing, Abdala moved to phase I/II trials in human subjects ages 19 to 80, recruiting participants between December 2020 and February 2021 [@doi:10.1016/j.eclinm.2022.101383].
The three-dose vaccine elicited no serious AEs across either phase I or II, and the vaccine was found to produce a strong immune response [@doi:10.1016/j.eclinm.2022.101383].
In March 2021, phase III trials began [@url:http://www.xinhuanet.com/english/northamerica/2021-03/20/c_139823225.htm], and by June, officials were reporting the VE to be 92.28% [@url:https://www.reuters.com/business/healthcare-pharmaceuticals/cuba-says-abdala-vaccine-9228-effective-against-coronavirus-2021-06-21; @granma].
This high efficacy estimate, along with the short timeline of data collection, initially elicited skepticism, especially given that the data were not made public [@url:https://oncubanews.com/en/cuba/how-was-the-efficacy-of-the-cuban-covid-19-vaccine-candidates-calculated].
However, the trials were designed to enroll a large number of participants and were carried out during a wave of infections due to the arrival of variants carrying the D614G mutation in Cuba, which would be expected to allow an expedited timeline for interim analysis [@url:https://oncubanews.com/en/cuba/how-was-the-efficacy-of-the-cuban-covid-19-vaccine-candidates-calculated].
Based on the reported results, Abdala gained emergency use authorization in Cuba in July 2021 [@cecmed], and by December 2021, cases in Cuba had dropped dramatically [@url:https://www.newscientist.com/article/2303121-cubas-home-grown-vaccines-have-massively-cut-covid-19-cases].
The results of the phase III trial were posted to _medRxiv_ in September 2022, describing the results of a randomized, placebo-controlled, multicenter, double-blind investigation of the Abdala vaccine candidate in 48,000 participants between March 22 and April 3, 2021 [@doi:10.1101/2022.09.08.22279690].
The final results evaluated 42 symptomatic cases of COVID-19 among participants in the placebo condition compared to only 11 cases among participants who received the vaccine, yielding the reported VE of 92.28% [@doi:10.1101/2022.09.08.22279690].
In terms of secondary endpoints, the VE was 91.96% against mild/moderate COVID-19, 94.46% against severe COVID-19, and 100% against critical illness and death [@doi:10.1101/2022.09.08.22279690].
The vaccine was also found to be very safe, with the overall incidence of AEs only 2.5% in vaccine recipients compared to 1.9% in the placebo recipients [@doi:10.1101/2022.09.08.22279690].
Therefore, the phase III trial suggests that this vaccine is highly effective and safe.

Evidence from the deployment of the vaccine also suggests it is highly effective.
A retrospective cohort study conducted between May and August 2021 evaluated public health data from over a million people in the city of Havana and found that the real-world effectiveness of the vaccine met or exceeded estimates of VE during the trial, with 98.2% effectiveness against severe disease and 98.7% effectiveness against death observed in fully vaccinated subjects [@doi:10.1016/j.lana.2022.100366].
Notably, Cuba has vaccinated a high percentage of its population, with 87% of the population vaccinated by January 2022 and 90.3% by the end of December 2022 [@cubanHealth; @doi:10.37757/MR2022.V24.N1.11].
Therefore, one consideration in interpreting retrospective cohort studies is that the vaccination rate in Cuba is so high that the two cohorts might not be directly comparable.
All the same, the fact that the efficacy and effectiveness of the Abdala vaccine have both been estimated to be over 90% against severe illness suggests that this vaccine is highly effective for mitigating the risk of COVID-19.
As of December 2022, the vaccine had been authorized for distribution in five additional countries, including Mexico and Vietnam, although its evaluation for WHO approval was ongoing [@WHOVaccineStatus; @doi:10.1136/bmj.o230].

However, limited data is available about the Abdala's vaccine's robustness to evolutionary changes in SARS-CoV-2.
An _in silico_ analysis identified several potential changes in the epitopes of the Omicron VOC relative to the sequence used in the development of Abdala [@cuban-vaccines-omicron].
Instead, Cuban health officials have prioritized boosters.
A representative of the Cuban state business group reportedly stated that immunity remains high at six months after the primary course but that some people may be prone to infection [@url:https://oncubanews.com/en/coronavirus/cuba-to-apply-booster-doses-of-its-covid-19-vaccines], suggesting waning immunity.
The Cuban government authorized boosters in January 2022 in an effort to mitigate the effects of the Omicron variant [@url:https://www.cnbc.com/2022/01/13/why-cubas-extraordinary-covid-vaccine-success-could-provide-the-best-hope-for-the-global-south.html; @url:https://oncubanews.com/en/coronavirus/cuba-to-apply-booster-doses-of-its-covid-19-vaccines; @url:https://www.reuters.com/world/americas/cuba-fast-track-boosters-omicron-looms-2021-12-29].
Additional support for the efficacy of Abdala and other Cuban vaccines comes from the fact that Cuba's COVID-19 death rate has virtually flatlined since fall 2021, with less than 250 deaths reported during the entire year of 2022 in a population of 11.3 million [@url:https://www.worldometers.info/coronavirus/country/cuba].
Therefore, in addition to developing a vaccine with an estimated VE paralleling that of vaccines developed using cutting-edge nucleic acid technologies [@individual-vaccines-novel], Cuba's vaccine roll out has also been much more successful than in nearly all similarly sized countries.
This remarkable vaccine program underscores the continued importance of established, cost-effective vaccine development strategies [@url:https://www.cnbc.com/2022/01/13/why-cubas-extraordinary-covid-vaccine-success-could-provide-the-best-hope-for-the-global-south.html] that make it possible for countries that have not traditionally been a leader in biotechnological innovation but have developed a solid vaccine production sector [@doi:10.1136/bmj.n1912] to develop and produce vaccines that will serve their own population's needs.
Additionally, Cuba's vaccines are uniquely accessible to many countries around the world [@url:https://www.cnbc.com/2022/01/13/why-cubas-extraordinary-covid-vaccine-success-could-provide-the-best-hope-for-the-global-south.html].

#### Medicago's Covifenz

The leading example of a VLP approach applied to COVID-19 comes from Covifenz, developed by Canadian company Medicago [@doi:10.1503/cmaj.1095992].
This vaccine was developed using plant-based VLP technology [@url:https://medicago.com/en/our-products/our-vaccines/covifenz-covid-19-vlp-vaccine] that the company had been investigating in order to develop a high-throughput quadrivalent VLP platform to provide protection against influenza [@doi:10/gjn28x].
The approach utilizes _Nicotiana benthamiana_, an Australian relative of the tobacco plant, as an upstream bioreactor [@doi:10/gjn28x; @doi:10.1038/s41591-021-01370-1].
Specifically, the _S_ gene from SARS-CoV-2 in its prefusion conformation is inserted into a bacterial vector (_Agrobacterium tumefaciens_) that then infects the plant cells [@doi:10/gjn28x; @doi:10.1038/s41591-021-01370-1].
Expression of the S glycoprotein causes the production of VLPs composed of S trimers anchored in a lipid envelope that accumulate between the plasma membrane and the cell wall of the plant cell [@doi:10.1038/s41591-021-01370-1].
Because these VLPs do not contain the SARS-CoV-2 genome, they offer similar advantages to whole-virus vaccines while mitigating the risks [@doi:10/gjn28x; @doi:10.1038/s41591-021-01370-1].

In the phase I study, 180 Canadian adults ages 18 to 55 years old were administered Covifenz as two doses, 21 days apart, with three different dosages evaluated [@doi:10.1038/s41591-021-01370-1].
This study reported that when the VLPs were administered with AS03, an oil-in-water emulsion containing &alpha;-tocopherol and squalene [@doi:10.1586/erv.11.192], as an adjuvant, the vaccine elicited an nAb response that was significantly (approximately 10 times) higher than that in convalescent sera [@doi:10.1038/s41591-021-01370-1].
The phase III trial examined 24,141 adults assigned to the treatment and control conditions at a 1:1 ratio between March and September of 2021 [@doi:10.1056/NEJMoa2201300].

Covifenz was reported to be 71% effective in preventing COVID-19 in the per-protocol analysis [@doi:10.1056/NEJMoa2201300].
Efficacy was only slightly lower in the intention-to-treat group at 69%, with the VE for the prevention of moderate-to-severe disease in this group estimated at 78.8% [@doi:10.1056/NEJMoa2201300].
Over 24,000 participants were included in the safety analysis, which reported that 92.3% of vaccine recipients reported local AEs compared to 45.5% of placebo recipients, with rates for systemic AEs at 87.3% and 65.0%, respectively [@doi:10.1056/NEJMoa2201300].
The adverse effects reported were generally mild to moderate, with the most common adverse effects being injection site pain, headache, myalgia, fatigue, and general discomfort [@doi:10.1056/NEJMoa2201300].
Only three patients (two in the vaccine group) reported grade 4 events, all after the second dose [@doi:10.1056/NEJMoa2201300].
The vaccine was approved for use in adults ages 18 to 65 by Health Canada in February 2022 [@url:https://www.gsk.com/en-gb/media/press-releases/medicago-and-gsk-announce-the-approval-by-health-canada-of-covifenz].

Plant-based expression systems such as the one used in Covifenz are relatively new [@doi:10.1038/s41591-021-01370-1] but are likely to offer unparalleled feasibility at scale given the speed and low-cost associated with the platform [@doi:10.1111/j.1467-7652.2008.00384.x].
Additionally, the Covifenz vaccine offers the advantage of being stored at 2 to 8&#176;C.
However, the worldwide footprint of Covifenz, and of VLP-based technologies against SARS-CoV-2 broadly, remains small, with only {{owid_VLP_count}} VLP vaccine approved for distribution in {{owid_VLP_countries}} countries (Figure @fig:vlp-distrib).
Approval and administration of Covifenz in countries outside of Canada has been limited by concerns at the WHO about ties between Medicago and the tobacco industry [@doi:10.1503/cmaj.1095992; @doi:10.1136/bmj.o811].
While other species of plants have been explored as the upstream bioreactors for plant-derived VLPs, the specific species of tobacco used increased yield dramatically [@doi:10.4161/hv.22218].
In December 2022, tobacco industry investors in Medicago divested, opening new possibilities for the distribution of the vaccine [@url:https://www.cbc.ca/news/health/philips-morris-divestment-medicago-1.6700103].

As a result of this limited roll-out and given that the phase III results were published only in May 2022, little is known about the real-world performance of Covifenz.
However, it should be noted that the Covifenz trials were conducted in 2021, at a time during which the B.1.617.2 (Delta) and P.1 (Gamma) variants were predominant [@doi:10.1056/NEJMoa2201300].
Genomic analysis of 122 out of 176 cases (165 in the per-protocol population) revealed that none of the COVID-19 cases reported were caused by the original Wuhan strain [@doi:10.1056/NEJMoa2201300].
Instead, 45.9% of cases were identified as the Delta variant, 43.4% as Gamma, 4.9% as Alpha, and 5.8% as VOIs [@doi:10.1056/NEJMoa2201300].
Therefore, Covifenz and Nuvaxovid, despite both being designed based on the index strain, were tested under circumstances where different VOC were dominant, and differences in the Spike proteins of different VOC relative to the index strain could affect vaccine efficacy.
As of late 2022, Covifenz has not been authorized as a booster in Canada [@canadaGuide], and no studies on booster doses had been released by Medicago [@url:https://medicago.com/en/news-releases].

#### Subunit Vaccine Summary

Subunit vaccine technology is one of the best-represented platforms among COVID-19 vaccine candidates.
Development programs are underway in many countries around the world, including low- and middle-income countries [@url:https://covid19.trackvaccines.org/vaccines].
To date, data about the effect of viral evolution on the effectiveness of subunit vaccines has been limited.
Because these vaccines were developed using the Spike protein from the index strain [@doi:10.1038/s41467-020-20653-8; @doi:10.1056/NEJMoa2201300], a potential concern has been that these vaccines could lose effectiveness against SARS-CoV-2 containing mutations in the Spike protein.
Comparison of studies across vaccines suggests that some VOC, such as Alpha, may have minimal impact on vaccine efficacy/effectiveness [@doi:10.1016/j.bjid.2021.101606].
Additionally, to the extent that data is available such as from the vaccine rollout in Cuba, it suggests that real-world effectiveness remains strong against severe illness and death.

Subunit platforms offer some unique advantages.
Cuba's successful vaccine development programs highlights the fact that protein subunit vaccines can be developed using low-cost technologies.
Additionally, they are more feasible to store and transport [@doi:10.1038/s41541-022-00507-8].
Hoping to build on Cuba's success and the continued lack of vaccine access in many countries, several Latin American nations have begun developing protein subunit vaccines [@doi:10.1038/d41586-020-01756-0].

The efficacy and effectiveness of these vaccines is also very high, especially for Nuvaxovid, Abdala, and SOBERANA 01/02/Plus, where estimates exceeded 90%.
Unfortunately, there seem to be limited studies directly comparing the immunogenicity of subunit vaccines to nucleic acid vaccines, and comparing efficacies across trials is subject to bias [@doi:10.1093/cid/ciab213].
All the same, the evidence suggests that some protein subunit vaccines are able to provide extremely strong protection.
Coupled with the reduced barriers to development and transportation relative to most nucleic acid vaccines, it is clear that subunit technologies are important to vaccine access.

### Global Vaccine Status and Distribution

The unprecedented deployment of COVID-19 vaccines in under a year from the identification of SARS-CoV-2 led to a new challenge: the formation of rapid global vaccine production and distribution plans.
The development of vaccines is costly and complicated, but vaccine distribution can be just as challenging.
Logistical considerations such as transport, storage, equipment (e.g., syringes), the workforce to administer the vaccines, and a continual supply from the manufacturers to meet global demands all must be accounted for and vary globally due to economic, geographic, and sociopolitical reasons [@doi:10.1016/j.eclinm.2020.100674; @doi:10.1126/science.abe2803; @doi:10.1126/sciadv.abf1374].
As of {{owid_worldwide_date}}, at least {{owid_worldwide_total_vaccinations}} vaccine doses had been administered in at least {{owid_total_countries}} countries worldwide using {{owid_vaccine_counts}} different vaccines [@url:https://ourworldindata.org/coronavirus].>
The daily global vaccination rate at this time was {{owid_worldwide_daily_rate}}.

However, the distribution of these doses is not uniform around the globe.
Latin America leads world vaccination rates with at least 82% of individuals in this region receiving one vaccine dose followed by the U.S. and Canada (81%), Asia-Pacific (81%), Europe (70%), the Middle East (58%), and Africa with only 33% as of November 2022 [@url:https://www.nytimes.com/interactive/2021/world/covid-vaccinations-tracker.html].
It is estimated that only ~25% of individuals in low- and middle-income countries have received one vaccine dose [@url:https://ourworldindata.org/covid-vaccinations; @doi:10.1038/s41562-021-01122-8].
Vaccine production and distribution varies from region to region and seems to depend on the availability of the vaccines and potentially a country's resources and wealth [@url:https://www.nytimes.com/2020/12/25/business/coronavirus-vaccines-global-economy.html].

One effort to reduce these disparities is COVAX, a multilateral initiative as part of the Access to COVID-19 Tools (ACT) Accelerator coordinated by the WHO, Gavi, the Vaccine Alliance, and the Coalition for Epidemic Preparedness Innovations (CEPI), the latter two of which are supported by the Bill and Melinda Gates Foundation.
Their intention is to accelerate the development of COVID-19 vaccines, diagnostics, and therapeutics and to ensure the equitable distribution of vaccines to low- and middle-income countries [@doi:10.1111/1468-0009.12503; @url:https://www.who.int/publications/m/item/fair-allocation-mechanism-for-covid-19-vaccines-through-the-covax-facility].
COVAX invested in several vaccine programs to ensure they would have access to successful vaccine candidates [@doi:10.1126/science.369.6503.489].
However, the initiative has been less successful than was initially hoped due to less participation from high-income countries than was required for COVAX to meet its goals [@doi:10/h7kz].

Additionally, the vaccine technologies available differ widely around the globe.
As we review elsewhere [@individual-vaccines-novel], wealthier nations have invested heavily in mRNA and DNA vaccines.
In contrast, as we describe above, many countries outside of Europe and North America have developed highly effective vaccines using more traditional approaches.
There is a clear relationship between a country's gross domestic product (GDP) and its access to these cutting-edge types of vaccines (Figure @fig:gdpscatter).
Whole-virus and subunit vaccine development programs are responsible for a much higher percentage of the vaccinated populous in lower-income countries.
Therefore, vaccine development programs that utilized established vaccine technologies have played a critical role in providing protection against SARS-CoV at the global level.

![
**Vaccine Distribution across Platform Types as a Function of GDP.**
The total number of doses of the original formulation of each vaccine that were distributed within each country as of {{owid_most_recent_date}}, by platform type, is shown as a function of GDP.
These data are retrieved from Our World in Data [@url:https://ourworldindata.org/coronavirus; @doi:10.1038/s41562-021-01122-8] and plotted using the Python package plotnine [@url:https://github.com/has2k1/plotnine].
Lines show a general trend in the data and are drawn using geom_smooth [@url:https://ggplot2.tidyverse.org/reference/geom_smooth.html].
The list of countries included in the dataset is available from OWID [@url:https://github.com/owid/covid-19-data/blob/master/public/data/vaccinations/locations.csv].
See https://greenelab.github.io/covid19-review/ for the most recent version of this figure, which is updated daily.
Axes are not scaled per capita because both variables are modulated by population size.
]({{owid_doses_scatterplot}} "Distribution of vaccines according to GDP"){#fig:gdpscatter secno=1}

<!-- Figure is not rendering -->

When vaccines first became available, the wealthy nations of North America and Europe secured most of the limited COVID-19 vaccine stocks [@url:https://www.nytimes.com/2020/12/15/us/coronavirus-vaccine-doses-reserved.html].
Throughout 2021, low- and middle-income countries faced steep competition with high-income countries for vaccines, and the rates of vaccination reflected this unequal distribution [@doi:10.1002/hpm.3341].
While the wealthiest countries in these regions could compete with each other for vaccines independent of programs such as COVAX [@doi:10.1002/hpm.3341], other countries in these regions have faced challenges in acquiring vaccines developed by the world's wealthiest nations.
Fortunately, while mRNA and DNA vaccine development programs are not widespread, vaccine development using whole-virus and subunit technologies has been undertaken worldwide.
China and India, in particular, have developed several vaccines that are now widely available in these densely populated countries (see online Appendix [@url:https://greenelab.github.io/covid19-review]).

Still, many nations, especially in Africa, are reliant on the COVAX Facility, who have promised 600 million doses to the continent [@url:https://www.bbc.com/news/56100076].
The COVAX plan seeks to ensure that all participating countries would be allocated vaccines in proportion to their population sizes.
Once each country has received vaccine doses to account for 20% of their population, the country’s risk profile will determine its place in subsequent phases of vaccine distribution.
However, several limitations of this framework exist, including that the COVAX scheme seems to go against the WHO’s own ethical principles of human well-being, equal respect, and global equity and that other frameworks might have been more suitable [@doi:10.1136/bmj.m4853].
Furthermore, COVAX is supposed to allow poorer countries access to affordable vaccines, but the vaccines are driven by publicly traded companies that are required to make a profit [@url:https://www.nytimes.com/2020/12/25/business/coronavirus-vaccines-global-economy.html].

In any case, COVAX provides access to COVID-19 vaccines that may otherwise have been difficult for some countries to obtain.
COVAX aimed to distribute 2 billion vaccine doses globally by the end of 2021 [@url:https://www.who.int/initiatives/act-accelerator/covax].
According to Gavi, as of January 2022, COVAX had distributed over 1 billion vaccines to 144 participants of the program [@url:https://www.gavi.org/covax-vaccine-roll-out], short of its target but still a major global achievement.
It is envisaged that COVAX may also receive additional donations of doses from Western nations who purchased surplus vaccines in the race to vaccinate their populations, which will be a welcome boost to the vaccination programs of low- and middle-income countries [@doi:10.1126/science.abh4476].

In general, deciding on the prioritization and allocation of the COVID-19 vaccines is also a challenging task due to ethical and operational considerations.
Various frameworks, models, and methods have been proposed to tackle these issues with many countries, regions, or U.S. states devising their own distribution and administration plans [@doi:10.1126/science.abe6959; @doi:10.1038/s41598-020-78447-3; @doi:10.1016/j.vaccine.2020.12.059; @doi:10.1136/medethics-2020-107036; @doi:10.1101/2021.01.12.21249694].
The majority of the distribution plans prioritized offering vaccines to key workers such as health care workers and those who are clinically vulnerable, such as the elderly, the immunocompromised, and individuals with comorbidities, before targeting the rest of the population, who are less likely to experience severe outcomes from COVID-19 [@url:https://ourworldindata.org/covid-vaccination-policy].
The availability of vaccines developed in a variety of countries using a variety of platforms is likely to work in favor of worldwide vaccine access.
The initiative by Texas Children’s Hospital and Baylor College of Medicine to develop Corbevax, a patent-free COVID-19 protein subunit vaccine, is an important step towards vaccine equity because the manufacturing specifications can be shared globally.
Corbevax can be produced at low cost using existing technology and is now licensed to Biological E. Limited (BioE), an Indian company specializing in low-cost vaccine production [@url:https://theconversation.com/corbevax-a-new-patent-free-covid-19-vaccine-could-be-a-pandemic-game-changer-globally-174672].
The vaccine has been approved for distribution in India and Botswana [@url:https://covid19.trackvaccines.org/vaccines/54].

Logistical challenges and geographical barriers also dictate the availability of certain vaccines.
Many countries have had poor availability of ultra-low temperature freezers, leading to challenges of distribution for vaccines such as mRNA vaccines that require storage at very low temperatures [@doi:10.1093/inthealth/ihab010; @doi:10.1208/s12249-021-01974-3; @url:https://www.bloomberg.com/news/articles/2021-01-03/pfizer-to-supply-african-health-care-workers-with-vaccines].
Furthermore, ancillary supplies such as vaccine containers, diluents for frozen or lyophilized vaccines, disinfecting wipes, bandages, needles, syringes, sharps and biological waste disposal containers are also required, which may not be readily available in geographically isolated locations and can be bulky and expensive to ship [@doi:10.1093/inthealth/ihab010].
While some of these challenges in vaccine rollout in low- and middle-income countries are being addressed through COVAX [@url:https://www.unicef.org/supply/covax-ensuring-global-equitable-access-covid-19-vaccines], many issues persist worldwide [@doi:10/jqp4; @doi:10.1093/cid/ciac361; @doi:10.1080/20477724.2022.2091862].
COVAX also failed to distribute its promised two billion vaccine doses on time due to multiple complications [@url:https://www.washingtonpost.com/world/2021/12/10/covax-doses-delivered].

Another major challenge to global vaccine distribution is vaccine hesitancy, which the WHO has designated as a leading global health threat [@url:https://www.who.int/news-room/spotlight/ten-threats-to-global-health-in-2019].
Polling in the U.S. in January 2021 suggested that 20% of individuals were reluctant to receive a vaccine at that time, with a further 31% expressing some hesitancy to a lesser extent [@url:https://www.kff.org/coronavirus-covid-19/report/kff-covid-19-vaccine-monitor-january-2021; @doi:10.1056/NEJMms2101220].
A survey of 8,243 long-term healthcare workers in November 2020 (Indiana, USA) reported that only 69% of respondents would ever consider receiving an FDA-approved vaccine due to their perceived risk of side effects (70%), health concerns (34%), efficacy (20%), and religious beliefs (12%) [@doi:10.1111/jgs.17022].
Notably, almost a third of parents surveyed in the United States in March 2021 expressed concerns about vaccinating their children against COVID-19 [@doi:10.1177/00333549221114346].
Indeed, vaccine hesitancy has been reported as a significant barrier to vaccine distribution in countries in North and South America, Europe, Asia, and Africa [@doi:10.1002/jmv.28156; @doi:10.1126/sciadv.abm9825; @doi:10.1186/s41256-022-00255-1; @doi:10.1080/20477724.2021.2011580; @doi:10.1136/bmjopen-2021-052432].
Various factors have been associated with increased vaccine hesitancy including access to compelling misinformation via social media [@doi:10.1093/pnasnexus/pgac207; @doi:10.1038/s41591-022-01728-z], religious and conservative political beliefs [@doi:10.1371/journal.pone.0268926; @doi:10.1093/pubmed/fdab122; @doi:10.1177/1075547020960463; @doi:10.1377/hlthaff.2020.02254], and safety and efficacy concerns [@doi:10.1177/00333549221114346], to highlight a few.
Many of the concerns regarding safety and efficacy have focused on the novel mRNA technologies due to the perceived speed of their development and expedited clinical trial process [@doi:10.1186/s13037-021-00291-9]; however, general vaccine hesitancy relating to traditional vaccine platforms existed long before the pandemic and the distribution of the novel mRNA vaccines [@doi:10.1016/j.vaccine.2015.09.035; @doi:10.1016/j.mayocp.2015.09.006].
While in the United States, it was hoped that Novavax's Nuvaxovid would appeal to the vaccine hesitant [@url:https://www.ama-assn.org/delivering-care/public-health/what-sets-apart-novavax-option-other-covid-19-vaccines; @url:https://www.galvnews.com/health/free/article_8ddebef4-1db0-579a-b0d2-852f2031d881.html], but this protein subunit vaccine has not led to the uptake hoped [@doi:10.1001/jama.2022.13661; @url:https://www.cnbc.com/2022/07/15/why-new-novavax-covid-vaccine-wont-win-over-unvaccinated-americans.html].

Overall, the vaccine landscape remains heterogeneous even as the pandemic nears its third year, with certain vaccines much more accessible in high-income countries than in low- and middle-income countries.
The vaccines described in this manuscript, which were developed using well-established technologies, have played a crucial role in improving the feasibility and accessibility of vaccination programs worldwide.
While the novel technologies have received the bulk of public attention in countries like the U.S., these more traditional vaccine platforms also provide safe and highly effective protection against SARS-CoV-2.
Although companies developing cutting-edge technologies, namely Moderna and Pfizer/BioNTech, reported very high efficacies greater than 90% in their clinical trials [@individual-vaccines-novel], the efficacies identified in whole-virus and subunit trials have also been very high.
While the clinical trial efficacy estimates for IWV and subunit have been lower, some of these trials have also reported efficacies over 80% (e.g., Novavax's Nuvaxovid with 89.7% [@doi:10.1056/NEJMoa2107659] or Sinovac's CoronaVac with 83.5% [@doi:10/gk898z]).
Variation among studies investigating the efficacy of these vaccines, especially CoronaVac, clearly indicate that clinical trials of the same vaccine might not identify the same efficacy, depending on conditions such as the specific variants circulating in a clinical trial population during the trial period.
Additionally, there are many cohort- and population-level characteristics that can introduce bias within and between clinical trials [@doi:10.1016/j.vaccine.2021.05.099; @doi:10.1093/cid/ciab213], and the extent to which these different factors are present may influence trial outcomes.
While head-to-head comparisons of VE across different studies may therefore not be appropriate, the results make it clear that effective vaccines have been developed with a wide variety of technologies.
The vaccines discussed here, which took advantage of well-established approaches, have proven to be especially valuable in pursuing vaccine equity.

### Conclusions

Much attention has focused on the most novel vaccine technologies that have been deployed against SARS-CoV-2, but the established vaccine platforms discussed here have all made a significant impact on human health during the twentieth century and in some cases even earlier.
The COVID-19 pandemic has demonstrated new potential in these established technologies.
In the early 2000s, these technologies were explored for managing SARS-CoV-1 [@doi:10.3201/eid1107.050219; @doi:10.1038/nrmicro3143], but the epidemic was controlled before those efforts came to fruition [@doi:10.1056/nejmp2005630].
Similarly, these technologies were explored for MERS-CoV, but outbreaks were sporadic and difficult to predict, making vaccine testing and the development of a vaccination strategy difficult [@doi:10.1080/21645515.2017.1358325].
However, in the COVID-19 pandemic, most of these technologies have been used to accelerate vaccine development programs worldwide.
Therefore, they are also offering the opportunity to respond quickly to an emergent pathogen.

While these tried-and-true technologies do not always produce vaccines with the highly desirable VE reported in mRNA clinical trials (which exceeded 90%), the efficacies are still very high, and these vaccines are extremely effective at preventing severe illness and death.
Furthermore, some vaccine development programs using established technologies, especially protein subunit vaccines, have seen remarkably high VE and vaccine effectiveness.
Some protein subunit vaccine phase III trials generated VE estimates of over 90%, comparable to those in the mRNA vaccine trials.
Additionally, in some cases, such as Cuba's highly successful vaccine development program, these vaccines have been developed by and for low- and middle-income nations.
As a result, the greater accessibility and stability of these vaccines makes them extremely valuable for the global effort to mitigate the loss of life from SARS-CoV-2.
The outcomes of the response to COVID-19 suggests that these established vaccine technologies may continue to play an important role in tackling future viral threats.

