## Appendix: Additional Information about Established Vaccine Platforms for COVID-19

### Sinovac's CoronaVac

The CoronaVac vaccine was developed by Sinovac, a Beijing-based biopharmaceutical company.
The vaccine uses an inactivate whole virus with the addition of an aluminum adjuvant [@doi:10.3389/fimmu.2020.585354].
Pre-clinical trials were performed using BALB/c mice and rhesus macaques [@doi:10.1126/science.abc1932].
The SARS-CoV-2 strains used in this trial isolated from 11 hospitalized patients (5 from China, 3 from Italy, 1 from the United Kingdom (U.K.), 1 from Spain, 1 from Switzerland).
A phylogenetic analysis demonstrated that the strains were representative of the variants circulating at the time.
One of the strains from China, CN2, was used as the inactivated and purified virus while the other 10 strains were used to challenge.
CN2 was grown in Vero cells.
The immunogenicity of the vaccine candidate was evaluated with an ELISA assay.
Ten mice were injected with the vaccine on day 0 and day 7 with varying doses (0, 1.5, 3, or 6 &mu;g), and 10 mice were treated with physiological saline as the control.
IgG developed in the serum of all vaccinated mice.

Using the same setup, immunogenicity was also assessed in macaques.
Four macaques were assigned to each of four groups: treatment with 3 &mu;g at day 0, 7, and 14, treatment with a high dose of 6 &mu;g at day 0, 7, and 14, administration of a placebo vaccine, and administration of only the adjuvant.
All vaccinated macaques induced IgGs and neutralizing antibodies.
After challenge with SARS-CoV-2 strain CN1, vaccinated macaques were protected compared to control macaques (placebo or adjuvant only) based on histology and viral loads collected from different regions of the lung.

A single center, randomized, double-blind, placebo-controlled phase I/II trial was conducted in April 2020i in adults 18-59 years old.
Patients in this study were recruited from the community in Suining County of Jiangsu province, China.
For the phase I trial, 144 (of 185 screened) participants were enrolled, with 72 enrolled in the 14-day interval cohort (i.e., treated on day 0 and day 14) and 72 in the 28-day interval cohort.
This group of 72 participants was split into 2 blocks for a low-dose (3 &mu;g) and high-dose (6 &mu;g) vaccine.
Within each block, participants were randomly assigned vaccination with CoronaVac or placebo (aluminum diluent without the virus) at a 2:1 ratio.
Both the vaccine and placebo were prepared in a Good Manufacturing Practice-accredited facility of Sinovac Life Sciences (Beijing, China).

The phase II trial followed the same organization of participants, this time using 300 enrolled participants in the 14-day and another 300 enrolled in the 28-day groups.
One change of note was that the vaccine was produced using a highly automated bioreactor (ReadyToProcess WAVE 25, GE, Ume&aring;, Sweden) to increase vaccine production capacity.
This change resulted in a higher intact spike protein content.
The authors of this study were not aware of this antigen-level difference between the vaccine batches for the phase I/II when the ethical approval for the trials occurred.

To assess adverse responses, participants were asked to record any events up to 7 days post-treatment.
The reported adverse events were graded according to the China National Medical Products Administration guidelines.
In the phase I trial, the overall incidence of adverse reactions was 29-38% of patients in the 0 to 14 day group and 13-17% in the 0 to 28 day vaccination group.
The most common symptom was pain at the injection site, which was reported by 17-21% of patients in the 0 to 14 day cohort and 13% in the 0 to 28 day cohort.
Most adverse reactions were mild (grade 1), with patients recovering within 48 hours.
A single case of acute hypersensitivity with manifestation of urticaria 48 hours following the first dose of study drug was reported in the 6 &mu;g group
Both the 14-day and 28-day cohorts had a strong neutralizing antibody (Ab) response.
The neutralizing Ab response was measured using a micro cytopathogenic effect assay, which assesses the minimum dilution of neutralizing Ab to be 50% protective against structural changes in host cells in response to viral infection [@doi:10.1016/j.vaccine.2012.03.010].
Additionally IgG antibody titers against the receptor binding domain were also measured using ELISA.

Another phase I/II study was performed with older patients (over 60 years of age) [@doi:10/fx8z].
The study conducted a single-center, randomized, double-blind, placebo-controlled trial.
The phase I trial looked at dose escalation using 3 dosages: 1.5, 3, and 6 &mu;g.
The mean age of participants was 65.8 years (standard deviation = 4.8).
Of 95 screened participants, 72 were enrolled.
These 72 participants were split into low (3 &mu;g) and high (6 &mu;g) dose groups.
Within each group, 24 participants received the treatment and 12 the placebo.
A neutralizing antibody response against live SARS-CoV-2 was detected compared to baseline using the same micro cytopathogenic effect assay.
This response was similar across the two dose concentrations.
Additionally, they did not observe a difference in response between age groups (60–64 years, 65–69 years, and ≥70 years).

In phase II the mean age was 66.6 years (standard deviation = 4.7).
499 participants were screened and 350 were enrolled.
300 were evenly split into 1.5, 3, and 6 &mu;g dose groups, and the remaining 50 were assigned to the placebo group.
Again, they found a neutralizing antibody response in phase II.
There wasn't a significant different between the response to 3 &mu;g versus 6 &mu;g, but the response in both these conditions was higher than in the 1.5 &mu;g condition.

Participants were required to record adverse reaction events within the first 7 days after each dose.
The safety results were combined across phase I and II.
All adverse reactions were either mild (grade 1) or moderate (grade 2) in severity.
The most common symptom was pain at the injection site (9%) and fever (3%).
2% (7 participants) reported severe adverse events (4 from the 1.5 &mu;g group, 1 from the 3 &mu;g group, 2 from the 6 &mu;g group), though these were found to be unrelated to the vaccine.

Overall, the results from the pre-clinical and phase I/II clinical trials were promising, especially the fact that the immune response was consistent in older adults (> 60 years).

### Sinopharm's Clinical Trials of Two Vaccine Candidates

Sinopharm Wuhan Institute developed their SARS-CoV-2 inactivated vaccine using the WIV04 strain isolated from a patient at the Jinyintan Hospital in Wuhan, China [@doi:10.1038/s41541-021-00292-w].
This vaccine is administered intramuscularly using 5 &mu;g of virus per dose.
Preclinical data providing supporting evidence for the use of this vaccine is not available publicly.
Despite the lack of publicly available preclinical results, Sinopharm Wuhan Institute initiated phase I/II trials, which reported on varying dosing and prime-boost regimens.

A combined phase I/II RCT of Sinopharm's BBIBP-CorV, also known as Covilo, followed [@doi:10/ghjkrf].
In phase I, 192 participants were randomized with varying doses of 2 &mu;g, 4 &mu;g, or 8 &mu;g/dose or a placebo, and they received the same as a second dose 28 days later.
Approximately 29% of participants reported at least 1 adverse event, most commonly fever, and neutralizing antibody titers were reported for all doses.
In the phase II trial, 482 participants were enrolled (3:1, vaccine:placebo).
Participants in the vaccine condition received either a single 8 &mu;g dose or a double immunization of a 4 &mu;g/dose that was administered 14, 21, or 28 days post the prime dose.
Participants in the placebo condition received the placebo on one of the same four schedules.
The vaccine appeared well-tolerated, with 23% reporting at least one adverse reaction characterized as mild to moderate.
It was reported that all participants had a humoral immune response to the vaccines by day 42 but that the double immunization dosing regimen of 4 &mu;g/dose achieved higher neutralizing antibody titers than a single dose of 8 &mu;g and that the highest response was seen in the double-immunization regimen when at least 21 days separated the two doses [@doi:10/ghjkrf].
Similar findings were reported in another phase I/II trial published by the same authors [@doi:10.1001/jama.2021.8565].
For the other vaccine, nAbs were detected in all groups 14 days after the final dose in the phase I part of the trial [@doi:10.1001/jama.2020.15543], with similar findings reported in interim phase II data [@doi:10.1001/jama.2020.15543].

### Novavax's Nuvaxovid (NVX-CoV2373)

Novavax's Nuvaxovid is a particularly appealing candidate because the improved stability caused by the proline substitutions is particularly critical to facilitating global distribution, particularly to regions where local refrigerator/freezer capacities are limited.
Importantly, these amino acid substitutions did not affect the ability of the spike protein to bind the hACE2 receptor (the target receptor of SARS-CoV-2 spike protein).
The Novavax-CoV2373 vaccine candidate uses a proprietary, saponin-based Matrix-M^TM^ adjuvant that contains two different 40nm-sized particles formed by formulating purified saponin with cholesterol and phospholipids [@doi:10.1007/s12026-018-8991-x].
In preclinical models, the use of the Matrix-M adjuvant potentiated the cellular and humoral immune responses to influenza vaccines [@doi:10.1016/j.vaccine.2013.01.039; @doi:10.1016/j.vaccine.2009.09.044; @doi:10.1111/j.1750-2659.2011.00256.x; @doi:10.1007/s12026-018-8991-x].
Importantly, Matrix-M adjuvant-containing vaccines have shown acceptable safety profiles in human clinical trials [@doi:10.1016/j.vaccine.2011.08.042].

Novavax-CoV2373 induced a multifunctional CD4/CD8 T-cell responses and generate high frequencies of follicular helper T-cells and B-cell germinal centers after vaccination.
These findings were subsequently evaluated in a baboon primate model, in which Novavax-CoV2373 also elicited high antibody titers against the SARS-CoV-2 spike protein, as well as an antigen specific T-cell response.
Based on this data Novavax initiated a phase I/II clinical trial to evaluate the safety and immunogenicity of Novavax-CoV2373 with Matrix-M [@clinicaltrials:NCT04368988; @doi:10.1056/NEJMoa2026920].

The phase I/II trial was a randomized, placebo-controlled study with 131 healthy adult participants in 5 treatment arms [@doi:10.1056/NEJMoa2026920].
Participants that received the recombinant SARS-CoV-2 vaccine with or without the Matrix-M adjuvant got two injections, 21 days apart.
Primary outcomes that were assessed include reactogenicity, lab-values (serum chemistry and hematology), and anti-spike IgG levels.
Secondary outcomes measured included virus neutralization, T-cell responses, and unsolicited adverse events.
The authors reported that no serious treatment-related adverse events occurred in any of the treatment arms.
Reactogenicity was mostly absent and of short duration.
The two-dose vaccine regimen induced anti-spike IgG levels and neutralizing antibody-titers exceeding those in the convalescent plasma of symptomatic patients.
The outcomes of this trial suggest that Novavax-CoV2373 has an acceptable safety profile and is able to induce a strong immune response with high neutralizing antibody titers.

The phase II component of the trial was designed to identify the dose regimen for the next clinical trial stage [@doi:10.1371/journal.pmed.1003769].
Both younger (18-59 years) and older patients (60-84 years) were randomly assigned to receive either 5 &mu;g or 25 &mu;g Novavax-CoV2373 or a sodium-chloride placebo in two doses, 21 days apart.
In line with the phase I data, reactogenicity remained mild to moderate, with no more than 1% of participants in any group reporting grade 3 AEs, and of short duration.
Both dose levels were able to induce high anti-spike IgG titers as well as neutralizing antibody responses after the second dose.
Based on both safety and efficacy data, the 5 &mu;g dosing regimen was selected as the optimal dose regimen for the phase III trial.

Novavax announced an efficacy of 89.3% based on their phase III trial in the U.K. and South Africa [@doi:10.1056/NEJMoa2107659; @url:https://ir.novavax.com/2021-01-28-Novavax-COVID-19-Vaccine-Demonstrates-89-3-Efficacy-in-UK-Phase-3-Trial; @url:https://ir.novavax.com/2021-06-14-Novavax-COVID-19-Vaccine-Demonstrates-90-Overall-Efficacy-and-100-Protection-Against-Moderate-and-Severe-Disease-in-PREVENT-19-Phase-3-Trial].
This trial included over 15,000 participants in the U.K. and 4,000 participants in South Africa.
The primary endpoint of the trial was the occurrence or absence of PCR-confirmed, symptomatic mild, moderate or severe COVID-19 from 7 days after the second dose onward.
In the first interim analysis (U.K.), 56 cases of COVID-19 were observed in the placebo group compared to 6 cases in the treatment group.
Importantly, the vaccine candidate also shows significant clinical efficacy against the prevalent U.K. and South African variants.

### Protein Subunit Vaccine Development Programs Prior to SARS-CoV-2

Earlier studies examined the immunogenicity of a SARS-CoV-1 RBD fused with IgG1 Fc.
This recombinant fusion protein could induce a robust long-lasting neutralizing antibody and cellular immune response that protected mice from SARS-CoV-1 [@doi:10.3389/fimmu.2020.602256; @doi:10.1016/j.vaccine.2006.10.031; @doi:10.1016/j.vaccine.2006.06.084].
While there have been other potential protein subunit vaccines for SARS-CoV-1 investigated _in vivo_ [@10.3389/fimmu.2020.602256; @doi:10.3389/fmicb.2020.00298], none of these candidates have successfully completed clinical trials, more than likely due to the fact that the SARS-CoV-1 epidemic mostly ended by May 2004, and there was thus less of a demand or funding for SARS-CoV-1 vaccine research.

Similar vaccine candidates have emerged that target the RBD found in the S1 subunit of the trimeric MERS-CoV S protein, which binds to dipeptidyl-peptidase 4 (DPP4 also known as hCD26), the entry point through which MERS-CoV infects cells [@doi:10.1038/nature12005; @doi:10.1038/nature12328; @doi:10.1128/JVI.01277-13].
After initially determining that an RBD subunit candidate (S377-588-Fc) could elicit neutralizing antibodies [@doi:10.1371/journal.pone.0081587], a study in mice determined that the administration of three sequential doses of RBD-Fc vaccine coupled with MF59, a squalene immunogenic adjuvant, induced humoral and systemic immunity in mice [@doi:10.1038/cmi.2015.03].
Mice that had been transduced with Ad5-hCD26 and subsequently challenged with MERS-CoV five days later did not show evidence of viral infection in the lungs versus control mice at ten days post vaccination [@doi:10.1038/cmi.2015.03].
Other variations of this vaccine approach include a stable S trimer vaccine whereby proline-substituted variants of S2 can maintain a stable prefusion conformation of the S2 domain [@10.3389/fimmu.2020.602256].
This approach leads to broad and potent neutralizing antibodies [@10.3389/fimmu.2020.602256]

### Complementary Approaches to Vaccine Development

A complementary approach to other vaccine development programs that is being investigated explores the potential for vaccines that are not made from the SARS-CoV-2 virus to confer what has been termed trained immunity.
In a recent review [@doi:10.1038/s41577-020-0285-6], trained immunity was defined as forms of memory that are temporary (e.g., months or years) and reversible.
It is induced by exposure to whole-microorganism vaccines or other microbial stimuli that generates heterologous protective effects.
Trained immunity can be displayed by innate immune cells or innate immune features of other cells, and it is characterized by alterations to immune responsiveness to future immune challenges due to epigenetic and metabolic mechanisms.
These alterations can take the form of either an increased or decreased response to immune challenge by a pathogen.
Trained immunity elicited by non-SARS-CoV-2 whole-microorganism vaccines could potentially improve SARS-CoV-2 susceptibility or severity [@doi:10.1016/j.cell.2020.04.042].

One type of stimulus which research indicates can induce trained immunity is bacillus Calmette-Guerin (BCG) vaccination.
BCG is an attenuated form of bacteria _Mycobacterium bovis_.
The vaccine is most commonly administered for the prevention of tuberculosis in humans.
Clinical trials in non-SARS-CoV-2-infected adults have been designed to assess whether BCG vaccination could have prophylactic effects against SARS-CoV-2 by reducing susceptibility, preventing infection, or reducing disease severity.
A number of trials are now evaluating the effects of the BCG vaccine or the related vaccine VPM1002 [@doi:10.1016/j.cell.2020.04.042; @clinicaltrials:NCT04327206; @clinicaltrials:NCT04328441; @clinicaltrials:NCT04348370; @clinicaltrials:NCT04350931; @clinicaltrials:NCT04362124; @clinicaltrials:NCT04369794; @clinicaltrials:NCT04373291; @clinicaltrials:NCT04379336; @clinicaltrials:NCT04384549; @clinicaltrials:NCT04387409; @clinicaltrials:NCT04414267; @clinicaltrials:NCT04417335; @clinicaltrials:NCT04435379; @clinicaltrials:NCT04439045].

The ongoing trials are using a number of different approaches.
Some trials enroll healthcare workers, other trials hospitalized elderly adults without immunosuppression who get vaccinated with placebo or BCG at hospital discharge, and yet another set of trials older adults (>50 years) under chronic care for conditions like hypertension and diabetes.
One set of trials, for example, uses time until first infection as the primary study endpoint; more generally, outcomes measured in some of these trials are related to incidence of disease and disease severity or symptoms.
Some analyses have suggested a possible correlation at the country level between the frequency of BCG vaccination (or BCG vaccination policies) and the severity of COVID-19 [@doi:10.1016/j.cell.2020.04.042].
Currently it is unclear whether this correlation has any connection to trained immunity.
Many possible confounding factors are also likely to vary among countries, such as age distribution, detection efficiency, stochastic epidemic dynamic effects, differences in healthcare capacity over time in relation to epidemic dynamics, and these have not been adequately accounted for in current analyses. <!-- TO DO: add in study that debunks this-->
It is unclear whether there is an effect of the timing of BCG vaccination, both during an individual's life cycle and relative to the COVID-19 pandemic.
Additionally, given that severe SARS-CoV-2 may be associated with a dysregulated immune response, it is unclear what alterations to the immune response would be most likely to be protective versus pathogenic (e.g., [@doi:10.1016/j.chom.2020.04.009; @doi:10.1016/j.chom.2020.05.009; @doi:10.1016/j.cell.2020.04.042; @doi:10.1016/j.chom.2020.05.008]).
The article [@doi:10.1016/j.cell.2020.04.042] proposes that trained immunity might lead to an earlier and stronger response, which could in turn reduce viremia and the risk of later, detrimental immunopathology.
While trained immunity is an interesting possible avenue to complement vaccine development efforts through the use of an existing vaccine, additional research is required to assess whether the BCG vaccine is likely to confer trained immunity in the case of SARS-CoV-2.

### India and China's Roles in Vaccine Innovation and Development

The nations of China and India have played a major role as COVID-19 vaccination developers and providers.
Considering India produced approximately 60% of the world's vaccines prior to the pandemic, it is no surprise that the nation has developed and is developing several COVID-19 vaccine candidates.
In addition to Covaxin, the Bio E subunit vaccine CORBEVAX is being produced by Biological E in collaboration with U.S.-based Dynavax and the Baylor College of Medicine [@url:https://www.bbc.com/news/world-asia-india-55748124].
These two home-grown vaccines are now approved for adults and children as young as five (CORBEVAX) and six (Covaxin) [@url:https://www.tribuneindia.com/news/nation/covaxin-cleared-for-6-12-age-group-by-drugs-regulator-389581].

Other vaccines licensed by India were developed elsewhere but produced in India.
For example, Novavax (developed in the United States) has signed an agreement with the Serum Institute of India allowing them to produce up to 2 billion doses a year [@url:https://www.reuters.com/article/health-coronavirus-novavax-idUSKBN2661PI].
Similarly, many people within India have been vaccinated with the AstraZeneca-University of Oxford vaccine, known as Covishield in India, which is also produced by the Serum Institute of India [@url:https://www.bbc.com/news/world-asia-india-55748124].
India is also developing vaccines using cutting-edge nucleic-acid-based platforms..
These include ZyCov-D, a DNA vaccine produced by Zydus Cadila, HGCO19 and India’s first mRNA vaccine, produced by Genova and HDT Biotech Corporation (of the U.S.) [@url:https://www.bbc.com/news/world-asia-india-55748124].
Additionally, in February 2021, Bharat Biotech received approval from Indian officials to commence a phase I study of an intranasal chimpanzee-adenovirus (ChAd) vectored SARS-CoV-2-S vaccine called BBV154 [@url:https://www.bharatbiotech.com/intranasal-vaccine.html].

In China, the Sinopharm-Beijing Institute vaccine, the Sinopharm-Wuhan Institute of Biological Products vaccine, the Sinovac Biotech (CoronaVac) vaccine, and CanSino Biologics vaccine are the main vaccines being distributed.
Sinovac and Sinopharm aimed to produce 2 billion doses by the end of 2021, and they have distributed vaccines as aid to the Philippines and Pakistan [@url:https://www.nytimes.com/2021/01/25/business/china-covid-19-vaccine-backlash.html].
In contrast, the Sinopharm-Wuhan vaccine, which has been approved for use in China since February 25, 2021, has been distributed almost exclusively within China, with limited supplies distributed to the United Arab Emirates [@url:https://www.nytimes.com/interactive/2020/science/coronavirus-vaccine-tracker.html].
On the same date, the CanSino vaccine was approved for use in China and has been granted emergency use in several other countries [@url:https://www.nytimes.com/interactive/2020/science/coronavirus-vaccine-tracker.html].

However, the vaccine approval and distribution processes in China have come under increased scrutiny from other nations.
China was criticized for administering vaccines to thousands of government officials and state-owned businesses in September 2020, prior to the completion of phase III clinical trials [@doi:10.1001/jama.2021.1961].
The behavior of Chinese officials has also come into question due to misinformation campaigns questioning the safety of Western vaccine candidates such as Moderna and Pfizer-BioNTech in a way that is intended to highlight the benefits of their own vaccine candidates [@url:https://www.nytimes.com/2021/01/25/business/china-covid-19-vaccine-backlash.html].
China in particular took aim at mRNA technologies, but Chinese companies have since developed their own mRNA vaccines targeting the omicron variant, one of which is due to begin trials soon in the UAE [@url:https://www.reuters.com/business/healthcare-pharmaceuticals/chinese-omicron-specific-mrna-covid-vaccine-candidate-be-trialed-uae-2022-04-30].
Furthermore, delays in vaccine distribution have also caused issues, particularly in Turkey where 10 million doses of Sinovac were due to arrive by December 2020, but instead only 3 million were delivered in early January [@url:https://www.nytimes.com/2021/01/25/business/china-covid-19-vaccine-backlash.html].
Similar delays and shortages of doses promised were reported by officials in the Philippines, Egypt, Morocco, and the United Arab Emirates [@url:https://apnews.com/article/cabinets-philippines-coronavirus-pandemic-asia-east-asia-e6f826359395951b2c805dbd90f34205; @url:https://www.wsj.com/articles/chinas-covid-19-vaccine-makers-struggle-to-meet-demand-11612958560].
All the same, Sinovac's vaccine has since been approved for use in countries around the world [@url:https://www.nytimes.com/interactive/2020/science/coronavirus-vaccine-tracker.html].

