## Social Factors Influencing COVID-19 Exposure and Outcomes

### Social Factors Influencing COVID-19 Outcomes

In addition to understanding the fundamental biology of the SARS-CoV-2 virus and COVID-19, it is critical to consider how the broader environment can influence both COVID-19 outcomes and efforts to develop and implement treatments for the disease.
The evidence clearly indicates that social environmental factors are critical determinants of individuals' and communities' risks related to COVID-19.
There are distinct components to COVID-19 susceptibility, and an individual's risk can be elevated at one or all stages from exposure to recovery/mortality: an individual may be more likely to be exposed to the virus, more likely to get infected once exposed, more likely to have serious complications once infected, and be less likely to receive adequate care once they are seriously ill.
The fact that differences in survival between Black and white patients were no longer significant after controlling for comorbidities and socioeconomic status (type of insurance, neighborhood deprivation score, and hospital where treatment was received) in addition to sex and age [@doi:10.1001/jamanetworkopen.2020.18039] underscores the relevance of social factors to understanding mortality differences between racial and ethnic groups.
Moreover, the Black patients were younger and more likely to be female than white patients, yet still had a higher mortality rate without correction for the other variables [@doi:10.1001/jamanetworkopen.2020.18039].
Here, we outline a few systemic reasons that may exacerbate the COVID-19 pandemic in communities of color.

### Factors Observed to be Associated with Susceptibility

As COVID-19 has spread into communities around the globe, it has become clear that the risks associated with this disease are not equally shared by all individuals or all communities.
Significant disparities in outcomes have led to interest in the demographic, biomedical, and social factors that influence COVID-19 severity.
Untangling the factors influencing COVID-19 susceptibility is a complex undertaking.
Among patients who are admitted to the hospital, outcomes have generally been poor, with rates of admission to the intensive care unit (ICU) upwards of 15% in both Wuhan, China and Italy [@doi:10.1056/nejmoa2002032; @doi:10.1001/jama.2020.2648; @doi:10.1001/jama.2020.4031].
However, hospitalization rates vary by location [@doi:10.15585/mmwr.mm6915e3].
This variation may be influenced by demographic (e.g., average age in the area), medical (e.g., the prevalence of comorbid conditions such as diabetes), and social (e.g., income or healthcare availability) factors that vary geographically.
Additionally, some of the same factors may influence an individual's probability of exposure to SARS-CoV-2, their risk of developing a more serious case of COVID-19 that would require hospitalization, and their access to medical support.
As a result, quantifying or comparing susceptibility among individuals, communities, or other groups requires consideration of a number of complex phenomena that intersect across many disciplines of research.
In this section, the term "risk factor" is used to refer to variables that are statistically associated with more severe COVID-19 outcomes.
Some are intrinsic characteristics that have been observed to carry an association with variation in outcomes, whereas others may be more functionally linked to the pathophysiology of COVID-19.

#### Patient Traits Associated with Increased Risk

Two traits that have been consistently associated with more severe COVID-19 outcomes are male sex and advanced age (typically defined as 60 or older, with the greatest risk among those 85 and older [@url:https://www.cdc.gov/coronavirus/2019-ncov/need-extra-precautions/older-adults.html]).
In the United States, males and older individuals diagnosed with COVID-19 were found to be more likely to require hospitalization [@doi:10.1377/hlthaff.2020.00598; @doi:10.15585/mmwr.mm6925e1].
A retrospective study of hospitalized Chinese patients [@doi:10/ggnxb3] found that a higher probability of mortality was associated with older age, and world-wide, population age structure has been found to be an important variable for explaining differences in outbreak severity [@doi:10.1073/pnas.2004911117].
The CFR for adults over 80 has been estimated upwards of 14% or even 20% [@doi:10.1111/jgs.16472].
Male sex has also been identified as a risk factor for severe COVID-19 outcomes, including death [@doi:10.1136/bmj.m1985; @doi:10.1186/s13293-020-00304-9; @url:https://globalhealth5050.org/the-sex-gender-and-covid-19-project/].
Early reports from China and Europe indicated that even though the case rates were similar across males and females, males were at elevated risk for hospital admission, ICU admission, and death [@doi:10.1186/s13293-020-00304-9], although data from some US states indicates more cases among females, potentially due to gender representation in care-taking professions [@doi:10.1371/journal.ppat.1008570].
In older age groups (e.g., age 60 and older), comparable absolute numbers of male and female cases actually suggests a higher rate of occurrence in males, due to increased skew in the sex ratio [@doi:10.1186/s13293-020-00304-9].
Current estimates based on worldwide data suggest that, compared to females, males may be 30% more likely to be hospitalized, 80% more likely to be admitted to the ICU, and 40% more likely to die as a result of COVID-19 [@url:https://globalhealth5050.org/the-sex-gender-and-covid-19-project/].
There also may be a compounding effect of advanced age and male sex, with differences time to recovery worst for males over 60 years old relative to female members of their age cohort [@doi:10.1371/journal.ppat.1008520].

Both of these risk factors can be approached through the lens of biology.
The biological basis for greater susceptibility with age is likely linked to the prevalence of extenuating health conditions such as heart failure or diabetes [@doi:10.1111/jgs.16472].
Several hypotheses have been proposed to account for differences in severity between males and females.
For example, some evidence suggests that female sex hormones may be protective [@doi:10.1186/s13293-020-00304-9; @doi:10.1371/journal.ppat.1008570].
ACE2 expression in the kidneys of male mice was observed to be twice as high as that of females, and a regulatory effect of estradiol on ACE2 expression was demonstrated by removing the gonads and then supplementing with estradiol [@doi:10.1186/2042-6410-1-6; @doi:10.1371/journal.ppat.1008570].
Other work in mice has shown an inverse association between mortality due to SARS-CoV-1 and estradiol, suggesting a protective role for the sex hormone [@doi:10.1371/journal.ppat.1008570].
Similarly, evidence suggests that similar patterns might be found in other tissues.
A preliminary analysis identified higher levels of ACE2 expression in the myocardium of male patients with aortic valve stenosis showed  than female patients, although this pattern was not found in controls [@doi:10.1186/s13293-020-00304-9].
Additionally, research has indicated that females respond to lower doses than males of heart medications that act on the Renin angiotensin aldosterone system (RAAS) pathway, which is shared with ACE2 [@doi:10.1186/s13293-020-00304-9].
Additionally, several components of the immune response, including the inflammatory response, may differ in intensity and timing between males and females [@doi:10.1371/journal.ppat.1008570; @doi:10.1186/2042-6410-1-6].
This hypothesis is supported by some preliminary evidence showing that female patients who recovered from severe COVID-19 had higher antibody titers than males [@doi:10.1371/journal.ppat.1008570].
Sex steroids can also bind to immune cell receptors to influence cytokine production [@doi:10.1186/s13293-020-00304-9].
Additionally, social factors may influence risks related to both age and sex: for example, older adults are more likely to live in care facilities, which have been a source for a large number of outbreaks [@doi:10.1093/qjmed/hcaa136], and gender roles may also influence exposure and/or susceptibility due to differences in care-taking and/or risky behaviors (e.g., caring for elder relatives and smoking, respectively) [@doi:10.1186/s13293-020-00304-9] among men and women (however, it should be noted that both transgender men and women are suspected to be at heightened risk [@url:https://escholarship.org/uc/item/55t297mc].)

#### Comorbid Health Conditions

A number of pre-existing or comorbid conditions have repeatedly been identified as risk factors for more severe COVID-19 outcomes.
Several underlying health conditions were identified at high prevalence among hospitalized patients, including obesity, diabetes, hypertension, lung disease, and cardiovascular disease [@doi:10.15585/mmwr.mm6915e3].
Higher Sequential Organ Failure Assessment (SOFA) scores have been associated with a higher probability of mortality [@doi:10/ggnxb3], and comorbid conditions such as cardiovascular and lung disease as well as obesity were also associated with an increased risk of hospitalization and death, even when correcting for age and sex [@doi:10.1136/bmj.m1985].
Diabetes may increase the risk of lengthy hospitalization [@doi:10.1016/j.cmet.2020.04.021] or of death [@doi:10.1016/j.cmet.2020.04.021;@doi:10.1007/s00592-020-01546-0].
[@doi:10.1111/dom.14057] and [@doi:10.1152/ajpendo.00124.2020] discuss possible ways in which COVID-19 and diabetes may interact.
Obesity also appears to be associated with higher risk of severe outcomes from SARS-CoV-2 [@doi:10.1016/j.metabol.2020.154262; @doi:10.1101/2020.04.23.20076042].
Obesity is considered an underlying risk factor for other health problems, and the mechanism for its contributions to COVID-19 hospitalization or mortality is not yet clear [@doi:10.1016/j.medj.2020.06.005].
Dementia and cancer were also associated with the risk of death in an analysis of a large number (more than 20,000) COVID-19 patients in the United Kingdom [@doi:10.1136/bmj.m1985].
It should be noted that comorbid conditions are inextricably tied to age, as conditions tend to be accumulated over time, but that the prevalence of individual comorbidities or of population health overall can vary regionally [@doi:10.1073/pnas.2008760117].
Several comorbidities that are highly prevalent in older adults, such as COPD, hypertension, cardiovascular disease, and diabetes, have been associated with CFRs upwards of 8% compared to an estimate of 1.4% in people without comorbidities [@doi:10.1111/jgs.16472; @url:https://www.who.int/publications/i/item/report-of-the-who-china-joint-mission-on-coronavirus-disease-2019-(covid-19)]. <!-- will this url work for Manubot?-->
Therefore, both age and health are important considerations when predicting the impact of COVID-19 on a population [@doi:10.1073/pnas.2008760117].
However, other associations may exist, such as patients with sepsis having higher SOFA scores -- in fact, SOFA was developed for the assessment of organ failure in the context of sepsis, and the acronym originally stood for Sepsis-Related Organ Failure Assessment [@doi:10.1007/BF01709751; @doi:10.1001/jama.2016.0287].
Additionally, certain conditions are likely to be more prevalent under or exacerbated by social conditions, especially poverty, as is discussed further below.

#### Ancestry

A number of studies have suggested associations between individuals' racial and ethnic backgrounds and their COVID-19 risk.
In particular, Black Americans are consistently identified as carrying a higher burden of COVID-19 than white Americans [@doi:10.1377/hlthaff.2020.00598; @doi:10.15585/mmwr.mm6925e1], with differences in the rates of kidney complications from COVID-19 particularly pronounced [@doi:10.1016/j.kint.2020.05.006].
Statistics from a number of cities indicate significant discrepancies between the proportion of COVID-19 cases and deaths in Black Americans relative to their representation in the general population [@doi:10/ggv494].
In addition to Black Americans, disproportionate harm and mortality from COVID-19 has also been noted in Latino/Hispanic Americans and in Native American and Alaskan Native communities, including the Navajo nation [@doi:10.1001/jama.2020.8598; @doi:10.1136/bmj.m1483; @doi:10.1111/jrh.12451; https://www.nytimes.com/2020/04/09/us/coronavirus-navajo-nation.html?searchResultPosition=10; @url:https://www.nytimes.com/interactive/2020/07/05/us/coronavirus-latinos-african-americans-cdc-data.html; @doi:10.1093/tbm/ibaa055; @url:https://journalhosting.ucalgary.ca/index.php/jisd/article/view/70753/54416].
In Brazil, indigenous communities likewise carry an increased burden of COVID-19 [@doi:10.1126/science.abc0073].
In the United Kingdom, nonwhite ethnicity (principally Black or South Asian) was one of several factors found to be associated with a higher risk of death from COVID-19 [@doi:10.1038/s41586-020-2521-4].

From a genetic standpoint, it is highly unlikely that ancestry itself predisposes individuals to contracting COVID-19 or to experiencing severe COVID-19 outcomes.
Examining human genetic diversity indicates variation over a geographic continuum, and that most human genetic variation is associated with the African continent [@doi:10.1038/ng1438].
African-Americans are also a more genetically diverse group relative to European-Americans, with a large number of rare alleles and a much smaller fraction of common alleles identified in African-Americans [@doi:10.1146/annurev.genom.9.081307.164258].
Therefore, the idea that African ancestry (at the continent level) might convey some sort of genetic risk for severe COVID-19 contrasts with what is known about worldwide human genetic diversity [@doi:10.1126/science.abd4842].
The possibility for genetic variants that confer some risk or some protection remains possible, but has not been widely explored, especially at a global level.
Research in Beijing of a small number (n=80) hospitalized COVID-19 patients revealed an association between severe COVID-19 outcomes and homozygosity for an allele in the interferon-induced transmembrane protein 3 (IFITM3) gene, which was selected as a candidate because it was previously found to be associated with influenza outcomes in Chinese patients [@doi:10.1093/infdis/jiaa224].
Genetic factors may also play a role in the risk of respiratory failure for COVID-19 [@doi:10.1056/NEJMoa2020283; @doi:10.1093/gerona/glaa131; @doi:10.1101/2020.06.16.155101].
However, genetic variants associated with outcomes within ancestral groups are far less surprising than genetic variants explaining outcomes between groups.
Alleles in _ACE2_ and _TMPRSS2_ have been identified that vary in frequency among ancestral groups [@doi:10.1186/s12916-020-01673-z], but whether these variants are associated with COVID-19 susceptibility has not been explored.

Instead, examining patterns of COVID-19 susceptibility on a global scale that suggest that social factors are of primary importance in predicting mortality.
Reports from several sub-Saharan African countries have indicated that the effects of the COVID-19 pandemic have been less severe than expected based on the outbreaks in China and Italy.
In Kenya, for example, estimates of national prevalence based on testing blood donors for SARS-CoV-2 antibodies were consistent with 5% of Kenyan adults having recovered from COVID-19 [@doi:10.1101/2020.07.27.20162693].
This high seroprevalence of antibodies lies in sharp contrast to the low number of COVID-19 fatalities in Kenya, which at the time was 71 out of 2093 known cases [@doi:10.1101/2020.07.27.20162693].
Likewise, a serosurvey of health care workers in Blantyre City, Malawi reported an adjusted antibody prevalence of 12.3%, suggesting that the virus had been circulating more widely than thought and that the death rate was up eight times lower than models had predicted [@doi:10.1101/2020.07.30.20164970].
While several possible hypotheses for the apparent reduced impact of COVID-19 on the African continent are being explored, such as young demographics in many places [@doi:10.1126/science.369.6505.756], these reports present a stark contrast to the severity of COVID-19 in Americans and Europeans of African descent.
Additionally, ethnic minorities in the United Kingdom also tend to be younger than white British living in the same areas, yet the burden of COVID-19 is still more serious for minorities, especially people of Black Caribbean ancestry, both in absolute numbers and when controlling for age and location [@url:https://www.ifs.org.uk/inequality/chapter/are-some-ethnic-groups-more-vulnerable-to-covid-19-than-others/].
Furthermore, the groups in the United States and United Kingdom that have been identified as carrying elevated COVID-19 burden, namely Black American, indigenous American, and Black and South Asian British, are quite distinct in their position on the human ancestral tree.
What is shared across these groups is instead a history of disenfranchisement under colonialism and ongoing systematic racism.
A large analysis of over 11,000 COVID-19 patients hospitalized in 92 hospitals across U.S. states revealed that Black patients were younger, more often female, more likely to be on Medicaid, more likely to have comorbidities, and came from neighborhoods identified as more economically deprived than white patients [@doi:10.1001/jamanetworkopen.2020.18039].
This study reported that when these factors were accounted for, the differences in mortality between Black and white patients were no longer significant.
Thus, the current evidence suggests that the apparent correlations between ancestry and health outcomes must be examined in the appropriate social context.

### Environmental Influences on Susceptibility

#### Exposure to COVID-19

Social distancing has emerged as one of the main social policies used to manage the COVID-19 epidemic in many countries.
Many governments issued stay-at-home orders, especially in the initial months of the crisis.
However, data clearly indicates that these orders impacted different socioeconomic groups differently.
In U.S. counties with and without stay-at-home orders, smartphone tracking indicated a significant decrease in the general population's mobility in April relative to February through March of 2020 (-52.3% and -60.8%, respectively) [@doi:10.1101/2020.05.03.20084624].
A linear relationship was observed between counties' reduction in mobility and their wealth and health, as measured by access to health care, food security, income, space, and other factors [@doi:10.1101/2020.05.03.20084624].
Counties with greater reductions in mobility were also found to have much lower child poverty and household crowding and to be more racially segregated, and to have fewer youth and more elderly residents [@doi:10.1101/2020.05.03.20084624].
Similar associations between wealth and decreased mobility were observed in cellphone GPS data from Colombia, Indonesia, and Mexico collected between January and May 2020 [@arXiv:2006.15195], as well as in a very large data set from several US cities [@doi:10.1038/s41586-020-2923-3].
These disparities in mobility are likely to be related to the role that essential workers have played during the pandemic.
Essential workers are disproportionately likely to be female, people of color, immigrants, and to have an income below 200% of the poverty line [@url:https://mronline.org/wp-content/uploads/2020/06/2020-04-Frontline-Workers.pdf].
Black Americans in particular are over-represented among front-line workers and in professions where social distancing is infeasible [@doi:10.1002/ajim.23145].
Health care work in particular presents an increased risk of exposure to SARS-CoV-2 [@doi:10.1002/ajim.23145; @doi:10.1371/journal.pone.0232452; @url:https://www.ons.gov.uk/peoplepopulationandcommunity/healthandsocialcare/causesofdeath/bulletins/coronaviruscovid19relateddeathsbyoccupationenglandandwales/deathsregistereduptoandincluding20april2020; @url:https://www.ons.gov.uk/employmentandlabourmarket/peopleinwork/employmentandemployeetypes/articles/whichoccupationshavethehighestpotentialexposuretothecoronaviruscovid19/2020-05-11; @url:https://assets.publishing.service.gov.uk/government/uploads/system/uploads/attachment_data/file/892085/disparities_review.pdf].
In the United Kingdom, (South) Asians are more likely than their white counterparts to be medical professionals [@url:https://www.ifs.org.uk/inequality/chapter/are-some-ethnic-groups-more-vulnerable-to-covid-19-than-others/], although BAME medical professionals are still disproportionately represented in the proportion of National Health Service staff deaths [@url:https://www.hsj.co.uk/exclusive-deaths-of-nhs-staff-from-covid-19-analysed/7027471.article].
Similar trends have been reported for nurses, especially nurses of color, in the United States [@url:https://act.nationalnursesunited.org/page/-/files/graphics/0920_Covid19_SinsOfOmission_Data_Report.pdf].
Furthermore, beyond the risks associated with work itself, use of public transportation may also impact COVID-19 risk [@url:http://www.nber.org/papers/w27407].
The socioeconomic and racial/ethnic gaps in who is working on the front lines of the pandemic make it clear that socioeconomic privilege is likely to decrease the probability of exposure to SARS-CoV-2.

Increased risk of exposure can also arise outside the workplace.
Nursing homes and skilled nursing facilities received attention early on as high-risk locations for COVID-19 outbreaks [@doi:10.1001/jama.2020.11642].
Prisons and detention centers also confer a high risk of exposure or infection [@doi:10.1001/jamainternmed.2020.1856; @doi:10.1001/jama.2020.12528].
Populations in care facilities are largely older adults, and in the United States, incarcerated people are more likely to be male and persons of color, especially Black [@url:https://www.issuelab.org/resources/695/695.pdf].
Additionally, multi-generational households are less common among non-Hispanic white Americans than people of other racial and ethnic backgrounds [@doi:10.1111/j.1751-9020.2010.00306.x], increasing the risk of exposure for more susceptible family members.
Analysis suggests that household crowding may also be associated with increased risk of COVID-19 exposure [@doi:10.1101/2020.05.03.20084624], and household crowding is associated with poverty [@doi:10.1037/12057-014].
Forms of economic insecurity like housing insecurity, which is associated with poverty and more pronounced in communities subjected to racism [@doi:10.7916/D8WH2W9T; @doi:10.1093/socpro/spv025], would be likely to increase household crowding and other possible sources of exposure.
As a result, facets of systemic inequality such as mass incarceration of Black Americans and poverty are likely to increase the risk of exposure outside of the workplace.

#### Severity of COVID-19 Following Exposure

Following exposure to SARS-CoV-2, the likelihood that an individual develops COVID-19 and the severity of the disease presentation can be influenced by a number of social factors.
As discussed above, a number of patient characteristics are associated with the likelihood of severe COVID-19 symptoms.
In some cases, these trends run counter to those expected given rates of exposure: for example, although women are more likely to be exposed, men are more likely to be diagnosed with, hospitalized from, or die from COVID-19 [@doi:10.1371/journal.ppat.1008570].
In the case of comorbid conditions and racial/ethnic demographics, however, social factors are highly likely to modulate or at least influence the apparent association between these traits and the increased risk from COVID-19.
In particular, the comorbidities and racial/ethnic correlates of severe COVID-19 outcomes suggest that poverty confers additional risk for COVID-19.

In order to explore the relationship between poverty and COVID-19 outcomes, it is necessary to consider how poverty impacts biology.
In particular, we focus on the United States and the United Kingdom.
Comorbidities that increase risk for COVID-19, including obesity, type II diabetes, hypertension, and cardiovascular disease, are known to be intercorrelated [@doi:10/bpp37d].
Metabolic conditions related to heightened inflammation, like obesity, type II diabetes, and hypertension, are more strongly associated with negative COVID-19 outcomes than other comorbid conditions, such as chronic heart disease [@doi:10.2337/dbi19-0023].
As discussed above, dysregulated inflammation characteristic of cytokine release syndrome is one of the greatest concerns for COVID-19-related death.
Therefore, it is possible that chronic inflammation characteristic of these metabolic conditions predisposes patients to COVID-19-related death [@doi:10.2337/dbi19-0023].
The association between these diseases and severe COVID-19 outcomes is a concern from a health equity perspective because poverty exposes people to "obesogenic" conditions [@doi:10/gddg84] and is therefore unsurprisingly associated with higher incidence of obesity and associated disorders [@doi:10.5604/12321966.1120608].
Furthermore, cell phone GPS data suggests that lower socioeconomic status may also be associated with decreased access to healthy food choices during the COVID-19 pandemic [@doi:10.1002/oby.22940; @doi:10.1002/oby.22993], suggesting that health-related risk factors for COVID-19 may be exacerbated as the pandemic continues [@doi:10.1016/j.pcad.2020.07.002].
Chronic inflammation is a known outcome of chronic stress (e.g., [@doi:10.1067/mai.2000.110163; @doi:10.1037/0278-6133.21.6.531; @doi:10.1037/a0025536; @doi:10.1111/j.1467-8721.2006.00450.x]).
Therefore, the chronic stress of poverty is likely to influence health broadly (as summarized in [@doi:10.1038/scientificamerican1205-92]) and especially during the stress of the ongoing pandemic.

A preprint [@doi:10.1101/2020.04.05.20054502] provided observational evidence that geographical areas in the United States that suffer from worse air pollution by fine particulate matter have also suffered more COVID-19 deaths per capita, after adjusting for demographic covariates.
Although lack of individual-level exposure data and the impossibility of randomization make it difficult to elucidate the exact causal mechanism, this finding would be consistent with similar findings for all-cause mortality (e.g., [@doi:10.1073/pnas.1803222115]).
Exposure to air pollution is associated with both poverty (e.g., [@doi:10.3390/ijerph15061114]) and chronic inflammation [@doi:10.1016/j.neubiorev.2018.06.002].
Other outcomes of environmental racism, such as the proximity of abandoned uranium mines to Navajo land, can also cause respiratory illnesses and other health issues [@url:https://journalhosting.ucalgary.ca/index.php/jisd/article/view/70753/54416].
Similarly, preliminary findings indicate that nutritional status (e.g., vitamin D deficiency [@doi:10.1210/clinem/dgaa733]) may be associated with COVID-19 outcomes, and reduced access to grocery stores and fresh food often co-occurs with environmental racism [@url:https://journalhosting.ucalgary.ca/index.php/jisd/article/view/70753/54416; @doi:10.1056/NEJMp2021264].
Taken together, the evidence suggests that low-income workers who face greater exposure to SARS-CoV-2 due to their home or work conditions are also more likely to face environmental and social stressors associated with increased inflammation, and therefore with increased risk from COVID-19.
In particular, structural racism can play an important role on disease severity after SARS-CoV-2 exposure, due to consequences of racism which include an increased likelihood of poverty and its associated food and housing instability.
COVID-19 can thus be considered a "syndemic", or a synergistic interaction between several epidemics [@doi:10.1002/ajhb.23482].
As a result, it is not surprising that people from minoritized backgrounds and/or with certain pre-existing conditions are more likely to suffer severe effects of COVID-19, but these "risk factors" are likely to be causally linked to poverty [@doi:10.1001/jama.2020.26443].

#### Access to Treatment

Finally, COVID-19 outcomes can be influenced by access to healthcare.
Receiving care for COVID-19 can, but does not always, include receiving a positive test for the SARS-CoV-2 virus.
For example, it is common to see treatment guidelines for suspected cases regardless of whether the presence of SARS-CoV-2 has been confirmed (e.g., [@doi:10.1016/j.ajem.2020.03.036]).
Whether and where a patient is diagnosed can depend on their access to testing, which can vary both between and within countries.
In the United States, it is not always clear whether an individual will have access to free testing [@url:https://www.npr.org/sections/health-shots/2020/06/19/880543755/insurers-may-only-pay-for-coronavirus-tests-when-theyre-medically-necessary; @url:https://www.commonwealthfund.org/blog/2020/private-health-insurance-coverage-covid-19-public-health-emergency].
The concern has been raised that more economic privilege is likely to correspond to increased access to testing, at least within the United States [@doi:10.1016/j.jaad.2020.04.046].
This is supported by the fact that African Americans seem to be more likely to be diagnosed in the hospital, while individuals from other groups were more likely to have been diagnosed in ambulatory settings in the community [@doi:10.1377/hlthaff.2020.00598].
Any delays in treatment are a cause for concern [@doi:10.1016/j.jaad.2020.04.046], which could potentially be increased by an inability to acquire testing because in the United States, insurance coverage for care received can depend on a positive test [@url:https://www.hrsa.gov/coviduninsuredclaim/frequently-asked-questions].

Another important question is whether patients with moderate to severe cases are able to access hospital facilities and treatments, to the extent that they have been identified.
Early findings from China as of February 2020 suggested the COVID-19 mortality rate to be much lower in the most developed regions of the country [@doi:10/ggqscd], although reported mortality is generally an estimate of CFR, which is dependent on rates of testing.
Efforts to make treatment accessible for all confirmed and suspected cases of COVID-19 in China are credited with expanding care to people with fewer economic resources [@doi:10.1038/s41591-020-0823-6].
In the United States, access to healthcare varies widely, with certain sectors of the workforce less likely to have health insurance; many essential workers in transportation, food service, and other frontline fields are among those likely to be uninsured or underinsured [@doi:10.1016/j.jaad.2020.04.046].
As of 2018, Hispanic Americans of all races were much less likely to have health insurance than people from non-Hispanic backgrounds [@url:https://www.census.gov/content/dam/Census/library/publications/2019/demo/p60-267.pdf].
Therefore, access to diagnostics and care prior to the development of severe COVID-19 is likely to vary depending on socioeconomic and social factors, many of which overlap with the risks of exposure and of developing more severe COVID-19 symptoms.
This discrepancy ties into concerns about broad infrastructural challenges imposed by COVID-19.
A major concern in many countries has been the saturation of healthcare systems due to the volume of COVID-19 hospitalizations (e.g., [@doi:10.1073/pnas.2004064117]).
Similarly, there have been shortages of supplies such as ventilators that are critical to the survival of many COVID-19 patients, leading to extensive ethical discussions about how to allocate limited resources among patients [@doi:10.19044/esj.2020.v16n21p24; @doi:10.7249/PEA228-1; @arxiv:2008.00374; @doi:10.1016/j.surg.2020.04.044].
Although it is generally considered unethical to consider demographic factors such as age, sex, race, or ethnicity while making such decisions, and ideally this information would not be shared with triage teams tasked with allocating limited resources among patients [@doi:10.1080/15265161.2020.1764137], there are substantial concerns about implicit and explicit biases against older adults [@doi:10.1111/jgs.16539], premature infants [@doi:10.1111/apa.15334], and people with disabilities or comorbidities [@doi:10.1080/15265161.2020.1764138; @doi:10.2105/AJPH.2020.305837; @doi:10.1080/15265161.2020.1764137].
Because of the greater burden of chronic disease in populations subjected to systemic racism, algorithms intended to be blind to race and ethnicity could, in fact, reinforce systemic inequalities caused by structural racism [@doi:10.1080/15265161.2020.1777347; @doi:10.1016/j.jnma.2020.05.010; @doi:10.1056/NEJMp2023616].
Because of this inequality, it has been argued that groups facing health disparities should be prioritized by these algorithms [@doi:10.1080/15265161.2020.1795538].
This approach would carry its own ethical concerns, including the fact that many resources that need to be distributed do not have well-established risks and benefits [@doi:10.1080/15265161.2020.1795538].

As the pandemic has progressed, it has become clear that ICU beds and ventilators are not the only limited resources that needs to be allocated, and, in fact, the survival rate for patients who receive mechanical ventilation is lower than these discussions would suggest [@doi:10.1136/medethics-2020-106460].
Allocation of interventions that may reduce suffering, including palliative care, has become critically important [@doi:10.1136/medethics-2020-106460; @doi:10.1080/15265161.2020.1788663].
The ambiguities surrounding the risks and benefits associated with therapeutics that have been approved under emergency use authorizations also present ethical concerns related to the distribution of resources [@doi:10.1080/15265161.2020.1795538].
For example, remdesivir, discussed above, is currently available for the treatment of COVID-19 under compassionate use guidelines and through expanded access programs, and in many cases has been donated to hospitals by Gilead [@doi:10.1016/j.mayocp.2020.06.016; @doi:10.1080/15265161.2020.1795529].
Regulations guiding the distribution of drugs in situations like these typically do not address how to determine which patients receive them [@doi:10.1080/15265161.2020.1795529].
Prioritizing marginalized groups for treatment with a drug like remdesivir would also be unethical because it would entail disproportionately exposing these groups to a therapeutic that may or not be beneficial [@doi:10.1080/15265161.2020.1795538].
On the other hand, given that the drug is one of the most promising treatments available for many patients, using a framework that tacitly feeds into structural biases would also be unethical.
At present, the report prepared for the Director of the CDC by Ethics Subcommittee of the CDC fails to address the complexity of this ethical question given the state of structural racism in the United States, instead stating that "prioritizing individuals according to their chances for short-term survival also avoids ethically irrelevant considerations, such as race or socioeconomic status" [@url:https://www.cdc.gov/about/advisory/pdf/VentDocument_Release.pdf].
In many cases, experimental therapeutics are made available only through participation in clinical trials [@doi:10.1080/15265161.2020.1795541].
However, given the history of medical trials abusing minority communities, especially Black Americans, there is a history of unequal representation in clinical trial enrollment [@doi:10.1080/15265161.2020.1795541].
As a result, the standard practice of requiring enrollment in a clinical trial in order to receive experimental treatment may also reinforce patterns established by systemic racism.
<!--Risk of comorbid health conditions associated with more severe outcomes may be influenced by long-term damage caused by chronic stress related to traumatic social experiences [@doi:10.1007/s12170-013-0338-5], perhaps mediated by cardiovascular risk factors [@doi:10.1101/2020.05.10.20097253], although the effects of chronic stress have not yet been researched in the specific case of COVID-19 disparities.-->

#### Access to and Representation in Clinical Trials

Experimental treatments are often made available to patients primarily or even exclusively through clinical trials.
The advantage of this approach is that clinical trials are designed to collect rigorous data about the effects of a treatment on patients.
The disadvantage is that access to clinical trials is not equal among all people who suffer from a disease.
Two important considerations that can impact an individual's access to clinical trials are geography and social perceptions of clinical trials.
For the first, the geographic distribution of trial recruitment efforts are typically bounded and can vary widely among difference locations, and for the second, the social context of medical interactions can impact strategies for and the success of outreach to different communities.
Differential access to clinical trials raises concerns because it introduces biases that can influence scientific and medical research on therapeutics and prophylactics broadly.
Concerns about bias in clinical trials need to address both trial recruitment and operation.
In the present crisis, such biases are particularly salient because COVID-19 is a disease of global concern.
Treatment is needed by people all over the world, and clinical research that characterizes treatment outcomes in a variety of populations is critically important.

Global representation in clinical trials is important to ensuring that experimental treatments are available equally to COVID-19 patients who may need them.
The advantage to a patient of participation in a clinical trial is that they may receive an experimental treatment they would not have been able to access otherwise.
The potential downsides of participation include that the efficacy and side effects of such treatments are often poorly characterized and that patients who enroll in clinical trials will in some cases run the risk of being assigned to a placebo condition where they do not receive the treatment but miss out on opportunities to receive other treatments.
The benefits and burdens of clinical trials therefore need to be weighed carefully to ensure that they don't reinforce existing health disparities.
The WHO Director‐General Tedros Adhanom Ghebreyesus stated his condemnation of utilizing low and middle income countries as test subjects for clinical trials, yet having highly developed countries as the majority of clinical trial representation is also not the answer [@doi:10.1002/eahr.500055].
Figure @fig:ebm-map showcases two choropleths detailing COVID-19 clinical trial recruitment by country.
China, the United States, and France are among the countries with the most clinical trial recruiting for trials with single-country enrollment.
Many countries have little to no clinical trial recruiting, with the continents of Africa and South America much less represented than Asia, Europe, and North America.
Trials that recruit across multiple countries do appear to broaden geographic representation, but these trials seem to be heavily dominated by the United States and European Union.

![
**Geographic distribution of COVID-19 clinical trials.**
The density of clinical trials is reported at the country level.
As of {{ebm_date_pretty}}, there are {{ebm_all_trials}} trials in the University of Oxford Evidence-Based Medicine Data Lab's COVID-19 TrialsTracker [@doi:10.5281/zenodo.3732709], of which {{ebm_interv_trials}} are interventional.
The top figure demonstrates the density of interventional trials recruiting only from a singular country, while the bottom shows the distribution of recruitment for interventional trials that involve more than one country.
]({{ebm_map_figure}} "COVID-19 clinical trials"){#fig:ebm-map secno=1}

A few different concerns arise from this skewed geographic representation in clinical trial recruitment.
First, treatments such as remdesivir that are promising but primarily available to clinical trial participants are unlikely to be accessible by people in many countries.
Second, it raises the concern that the findings of clinical trials will be based on participants from many of the wealthiest countries, which may lead to ambiguity in whether the findings can be extrapolated to COVID-19 patients elsewhere.
Especially with the global nature of COVID-19, equitable access to therapeutics and vaccines has been a concern at the forefront of many discussions about policy (e.g., [@doi:10/ggq7mf], yet data like that shown in Figure @fig:ebm-map demonstrates that accessibility is likely to be a significant issue.
Another concern with the heterogeneous international distribution of clinical trials is that the governments of countries leading these clinical trials might prioritize their own populations once vaccines are developed, causing unequal health outcomes [@doi:10.1001/jama.2020.6641].
Additionally, even within a single state in the United States (Maryland), geography was found to influence the likelihood of being recruited into or enrolled in a clinical trial, with patients in under-served rural areas less likely to enroll [@doi:10.1016/j.cdp.2005.12.001].
Thus, geography both on the global and local levels may influence when treatments and vaccines are available and who is able to access them.
Efforts such as the African Union's efforts to coordinate and promote vaccine development [@doi:10/fgzk] are therefore critical to promoting equity in the COVID-19 response.


Even when patients are located within the geographic recruitment area of clinical trials, however, there can still be demographic inequalities in enrollment.
When efforts are made to ensure equal opportunity to participate in clinical trials, there is no significant difference in participation among racial/ethnic groups [@doi:10.1002/cncr.28483].
However, within the United States, real clinical trial recruitment numbers have indicated for many years that racial minorities, especially African-Americans, tend to be under-represented (e.g., [@doi:10.1001/jama.291.22.2720; @doi:10.1245/s10434-007-9500-y; @doi:10.1089/jwh.2010.2469; @doi:10.1007/s11926-018-0728-2]).
This trend is especially concerning given the disproportionate impact of COVID-19 on African-Americans.
Early evidence suggests that the proportion of Black, Latinx, and Native American participants in clinical trials for drugs such as remdesivir is much lower than the representation of these groups among COVID-19 patients [@doi:10.1056/NEJMp2021971].

One proposed explanation for differences among racial and ethnic groups in clinical trial enrollment refers to different experiences in healthcare settings.
While some plausible reasons for the disparity in communication between physicians and patients could be a lack of awareness and education, mistrust in healthcare professionals, and a lack of health insurance [@doi:10.1002/cncr.28483], a major concern is that patients from certain racial and ethnic groups are marginalized even while seeking healthcare.
In the United States, many patients experience "othering" from physicians and other medical professionals due to their race or other external characteristics such as gender (e.g., [@doi:10.1207/S15327027HC1602_7]).
Many studies have sought to characterize implicit biases in healthcare providers and whether they affect their perceptions or treatment of patients.
A systematic review that examined 37 such studies reported that most (31) identified racial and/or ethnic biases in healthcare providers in many different roles, although the evidence about whether these biases translated to different attitudes towards patients was mixed [@doi:10.1016/j.socscimed.2017.05.009], with similar findings reported by a second systematic review [@doi:10.1111/acem.13214].
However, data about real-world patient outcomes are very limited, with most studies relying on clinical vignette-based exercises [@doi:10.1016/j.socscimed.2017.05.009], and other analyses suggest that physician implicit bias could impact the patient's perception of the negativity/positivity of the interaction regardless of the physician's explicit behavior towards the patient [@doi:10.1016/j.jesp.2009.11.004].
Because racism is a common factor in both, negative patient experiences with medical professionals are likely to compound other issues of systemic inequality, such as a lack of access to adequate care, a lack of insurance, or increased exposure to SARS-CoV-2 [@doi:10.1542/peds.2020-003657].
Furthermore, the experience of being othered is not only expected to impact patients' trust in and comfort with their provider, but also may directly impact whether or not the patient is offered the opportunity to participate in a clinical trial at all.
Some studies suggest communication between physicians and patients impacts whether or not a physician offers a patient participation in a clinical trial.
For example, researchers utilized a linguistic analysis to assess mean word count of phrases related to clinical trial enrollment, such as voluntary participation, clinical trial, etc. [@doi:10.1002/cncr.28483].
The data indicated that the mean word count of the entire visit was 1.5 times more for white patients in comparison to Black patients.
In addition, the greatest disparity between white and Black patients' experience was the discussion of risks, with over 2 times as many risk-related words spoken with white patients than Black patients [@doi:10.1002/cncr.28483].
The trends observed for other clinical trials raise the concern that COVID-19 clinical trial information may not be discussed as thoroughly or as often with Black patients compared to white patients.

 These discrepancies are especially concerning given that many COVID-19 treatments are being or are considered being made available to patients prior to FDA approval through Emergency Use Authorizations.
In the past, African-Americans have been over-represented relative to national demographics in use of the FDA's Exception From Informed Consent (EFIC) pathway [@doi:10.1377/hlthaff.2018.0501].
Through this pathway, people who are incapacitated can receive an experimental treatment even if they are not able to consent and there is not sufficient time to seek approval from an authorized representative.
This pathway presents concerns, however, when it is considered in the context of a long history of systematic abuses in medical experimentation where informed consent was not obtained from people of color, such as the Tuskegee syphilis experiments [@doi:10.1067/mem.2003.17].
While the goal of EFIC approval is to provide treatment to patients who urgently need it, the combination of the ongoing legacy of racism in medicine renders this trend concerning.
With COVID-19, efforts to prioritize people who suffer from systemic racism are often designed with the goal of righting some of these inequalities (e.g., [@url:https://www.businessinsider.com/cdc-official-considering-giving-covid-19-vaccine-most-vulnerable-first-2020-10]), but particular attention to informed consent will be imperative in ensuring these trials are ethical given that the benefits and risks of emerging treatments are still poorly characterized.
Making a substantial effort to run inclusive clinical trials is also important because of the possibility that racism could impact how a patient responds to a treatment.
For example, as discussed above, dexamethasone has been identified as a promising treatment for patients experiencing cytokine release syndrome, but the mechanism of action is tied to the stress response.
A study from 2005 reported that Black asthma patients showed reduced responsiveness to dexamethasone in comparison to white patients and suggested Black patients might therefore require higher doses of the drug [@doi:10.1378/chest.127.2.571].
In the context of chronic stress caused by systemic racism, this result is not surprising: chronic stress is associated with dysregulated production of glucocorticoids [@doi:10.1146/annurev.physiol.67.040403.120816] and glucocorticoid receptor resistance [@doi:10.1073/pnas.1118355109].
However, it underscores the critical need for treatment guidelines to take into account differences in life experience, which would be facilitated by the recruitment of patients from a wide range of backgrounds.
Attention to the social aspects of clinical trial enrollment must therefore be an essential component of the medical research community's response to COVID-19.

<!--Table for future version: ### Indirect Effects of the Pandemic
Besides the direct harms caused by infection, many populations are in indirect risk of serious harm due to the social and economic effects of the pandemic and of the efforts needed to fight it.
These might include individuals with substance use disorder [@doi:10.7326/M20-1141], victims of natural disasters [@doi:10.1038/s41558-020-0804-2], and victims of human trafficking [@doi:10.1016/j.eclinm.2020.100409].
The pandemic could also delay the fight against other major infectious diseases, such as HIV, malaria and tuberculosis, potentially leading to a further increase of mortality [@doi:10.25561/78670].
Although they are beyond the scope of this paper, further research is needed in order to prevent these harms.
[There are already some policy recommendations in literature that we cite - we should probably direct folks there. I think we probably want a stronger synthesis and closing than this] -->

### Conclusions and Future Directions

As the COVID-19 pandemic evolves, the scientific community's response will be critical for identifying potential pharmacological and biotechnological developments that may aid in combating the virus and the disease it causes.
However, this global crisis highlights the importance of mounting a response based on collaboration among a wide variety of disciplines.
Understanding the basic science of the virus and its pathogenesis is imperative for identifying and envisioning possible diagnostic and therapeutic approaches; understanding how social factors can influence outcomes and shape implementation of a response is critical to disseminating any scientific advancements.
Summarizing such a complex and ever-changing topic presents a number of challenges.
This review represents the effort of over 50 contributors <!-- TO DO: check with final number -->to distill and interpret the available information.
However, this text represents a dynamic and evolving document, and we welcome continued contributions from all researchers who have insights into how these topics intersect.
A multidisciplinary perspective is critical to understanding this evolving crisis, and in this review we seek to use open science tools to coordinate a response among a variety of researchers.
We intend to publish additional updates as the situation evolves.

<!-- Additional info on inflammation removed from pathogenesis manuscript, can use here if useful
Inflammation is one of the most visible components of the immune response, as it is responsible for the hallmarks of injury, such as pain, heat, and swelling [@doi:10.18632/oncotarget.23208].
The inflammatory response has received particular attention for its role in both a healthy response to infection and a pathogenic one.
In response to injury or to signaling by pattern recognition receptors indicating the detection of a molecular pattern associated with a pathogen or foreign body, the immune system stimulates leukocytes that travel to the site of the threat, where they then produce cytokines [@doi:10.18632/oncotarget.23208].
Elevated levels of inflammation over the long-term are associated with many chronic health conditions, including type 2 diabetes, dementia and Alzheimer's, and arthritis [@doi:10.1038/s41591-019-0675-0].
Some notable pro-inflammatory cytokines include the interleukins IL-1&beta; and IL-6 and tumor necrosis factor &alpha; (TNF-&alpha;) [@doi:10.1097/AIA.0b013e318034194e].
A number of interleukins and interferons play anti-inflammatory roles, and receptors or receptor antagonists for inflammatory cytokines are also important for regulating inflammation [@doi:10.1097/AIA.0b013e318034194e].
IL-10 is an anti-inflammatory cytokine of particular note because it regulates the expression of TNF-&alpha;, IL-1, and IL-6 [@doi:10.1097/AIA.0b013e318034194e].

Symptoms of a disease can be caused by a pathogen, but they can also be caused by the immune system's reaction to the pathogen.
Cytokines are a diverse group of small proteins that play an important role in intercellular signaling [@doi:10.1128/MMBR.05015-11].
They can be both pro- and anti-inflammatory, meaning they can either stimulate or inhibit the production of additional cytokines [@doi:10.1128/MMBR.05015-11; @doi:10.1097/AIA.0b013e318034194e], with anti-inflammatory cytokines playing an immunoregulatory role complementary to the cascading effect of pro-inflammatory cytokines [@doi:10.1128/MMBR.05015-11; @doi:10.1097/AIA.0b013e318034194e].
When the pro- and anti-inflammatory responses are both commensurate with the threat posed, the immune system drives a shift back to homeostasis [@doi:10.1111/imr.12671].
-->
