## Discussion

As of October 2020 the SARS-CoV-2 virus remains a serious worldwide threat.
The scientific community has responded by rapidly collecting and disseminating information about the SARS-CoV-2 virus and the associated illness, COVID-19.
The rapid identification of the genomic sequence of the virus allowed for early contextualization of SARS-CoV-2 among other known respiratory viruses.
The pathogen is a coronavirus that is closely related to SARS-CoV-1, which caused the SARS pandemics of the early 2000s.
Knowing the phylogenetic context and genomic sequence of the virus then allowed for rapid insights into its structure and pathogenesis.
As with other HCoV, the immune response to SARS-CoV-2 is likely driven by detection of its spike protein, which allows it to enter cells through the ACE2 receptor.
Epithelial cells have also emerged as the major cellular target of the virus, contextualizing the respiratory and gastrointestinal symptoms that are frequently observed in COVID-19.
However, as COVID-19 cases have been more widely characterized, it has become clear that the disease presentation is highly heterogeneous.
Many cases, especially in younger adults, present with mild symptoms or even asymptomatically, while others, especially in older adults, can be severe or fatal.
In children, the SARS-CoV-2 virus can present as two distinct diseases, COVID-19 or MIS-C.
While the overall infection fatality rate remains unknown, estimates suggest that it is not more than 1%; however, the severity of many non-lethal cases makes COVID-19 an ongoing, significant concern.

Characterizing the rate of infection and fatality rates hinges on the availability of rapid and accurate diagnostic testing.
Major advancements have been made in identifying diagnostic approaches.
The development of diagnostic technologies have been rapid, beginning with the release of the SARS-CoV-2 viral genome sequence in January.
As of October 2020, a range of diagnostic tests have become available.
One class of tests uses PCR (RT-PCR or qRT-PCR) to assess the presence of SARS-CoV-2 RNA, while another typically uses ELISA to test for the presence of antibodies to SARS-CoV-2.
The former approach is useful for identifying active infections, while the latter measures hallmarks of the immune response and therefore can detect either active infections or immunity gained from prior infection.
Combining these tests leads to extremely accurate detection of SARS-CoV-2 infection (98.6%), but when used alone, PCR-based tests are recommended before 5.5 days after the onset of the illness and antibody tests after 5.5 days [@doi:10.1001/jama.2020.8259].
Other strategies for testing can also influence the tests' accuracy, such as the use of nasopharyngeal swabs versus BALF [@doi:10.1001/jama.2020.8259], which allow for trade-offs between patient's comfort and test sensitivity.
Additionally, technologies such as digital PCR may allow for scale-up in the throughput of diagnostic testing, facilitating widespread testing.
One major question that remains is whether people who recover from SARS-CoV-2 develop sustained immunity, and over what period this immunity is expected to last.
Some reports have suggested that some patients may develop COVID-19 reinfections (e.g., [@doi:10/ghfgkt]), but the rates of reinfection are currently unknown.
Serologic testing combined with PCR testing will be critical to confirming purported cases of reinfection and to identifying the duration over which immunity is retained and to understanding reinfection risks.

One of the goals of characterizing the immune response is to identify strategies for the prophylactic enhancements of immunity.
Though some concerns remain about the duration of sustained immunity for convalescents, vaccine development efforts are ongoing and show initial promising results.
The Moderna trial, for example, reported that the neutralizing activity in participants who received two doses of the vaccine was similar to that observed in convalescent plasma.
Vaccine development for COVID-19 is progressing rapidly compared to typical timelines, but vaccine development is still a lengthy process.
In the meantime, some advances have also been made in the treatment of patients with COVID-19.
As cases have become better characterized, it has become evident that many patients experience an initial immune response to the virus that is typically characterized by fever, cough, dyspnea, and related symptoms.
However, the most serious concern is cytokine release syndrome, when the body's immune response becomes dysregulated, resulting in an extreme inflammatory response.
The RECOVERY trial, a large-scale, multi-arm trial enrolling about 15% of all COVID-19 patients in the United Kingdom, was the first to identify that the widely available steroid dexamethasone seems to be beneficial for patients suffering from this immune dysregulation [@doi:10.1101/2020.06.22.20137273].
Efforts to identify therapeutic treatments to treat patients early in the course of infection have been more ambiguous.
Early interest in the drugs hydroxychloroquine and chloroquine yielded no promising results from studies with robust experimental designs.
The experimental drug remdesivir, which was developed for Ebola, has received enough support from early analyses to receive FDA approval, but results have been mixed.
The potential for other drugs, such as tocilizumab, to reduce recovery time remains unclear, but some early results were promising.

### Additional Therapeutics of Interest

Given what is currently known about these therapeutics for COVID-19, a number of related therapies beyond those explored above may also prove to be of interest.
For example, the demonstrated benefit of dexamethasone and the ongoing potential of tocilizumab for treatment of COVID-19 suggests that other anti-inflammatory agents might also hold value for the treatment of COVID-19.
Given that current evidence about treating COVID-19 with dexamethasone suggests that the need to curtail the cytokine storm inflammatory response to the virus can transcend the risks of immunosuppression, exploration of more anti-inflammatory agents may be warranted.
While dexamethasone is considered widely available and generally affordable, the high costs of biologics such as tocilizumab therapy may present obstacles to wide-scale distribution of this drug if it proves of value.
At the doses used for rheumatoid arthritis patients, the cost for tocilizumab ranges from $179.20 to $896 per dose for the IV form and $355 for the pre-filled syringe [@url:https://www.ncbi.nlm.nih.gov/books/NBK349513/table/T43/].
There are several anti-inflammatory agents used for the treatment of autoimmune diseases that may also be able to counter the effects of the cytokine storm induced by the virus, some of which, such as cyclosporine, are likely to be more cost-effective and readily available than biologics [@url:https://escholarship.umassmed.edu/meyers_pp/385].
While tocilizumab targets IL-6, several other inflammatory markers could be potential targets, including TNF-alpha.
Inhibition of TNF-alpha by an inhibitor such as Etanercept has been previously suggested for treatment of SARS-CoV-1 [@doi:10.1185/030079903125002757] and may be relevant for SARS-CoV-2 as well.
Another anti-IL-6 antibody, sarilumab, is also being investigated [@url:http://www.news.sanofi.us/2020-03-16-Sanofi-and-Regeneron-begin-global-Kevzara-R-sarilumab-clinical-trial-program-in-patients-with-severe-COVID-19; @clinicaltrials:NCT04327388].
Baricitinib and other small molecule inhibitors of the Janus-activated kinase pathway also curtail the inflammatory response and have been suggested as potential options for SARS-CoV-2 infections [@doi:10/dph5].
Baricitinib in particular may be able to reduce the ability of SARS-CoV-2 to infect lung cells [@doi:10/ggnrsx].
Clinical trials studying baricitinib in COVID-19 have already begun in the US and in Italy [@url:https://investor.lilly.com/news-releases/news-release-details/lilly-begins-clinical-testing-therapies-covid-19; @clinicaltrials:NCT04320277].
Identification and targeting of further inflammatory markers that are relevant in SARS-CoV-2 infection may be of value for curtailing the inflammatory response and lung damage.

In addition to immunosuppressive treatments that are most beneficial late in disease progression, much research is focused on identifying treatments would be likely to benefit early-stage patients.
For example, although studies of hydroxychloroquine have not supported the early theory-driven interest in this antiviral treatment, alternative compounds with related mechanisms may still have potential.
Hydroxyferroquine derivatives of HCQ have been described as a class of bioorganometallic compounds that exert antiviral effects with some selectivity for SARS-CoV-1 _in vitro_ [@doi:10.1021/jm0601856].
Future work could explore whether such compounds exert antiviral effects against SARS-CoV-2 and whether they would be safer for use in COVID-19.
Another potential approach is the development of antivirals, which could be broad-spectrum, specific to coronaviruses, or targeted to SARS-CoV-2.
Development of new antivirals is complicated by the fact that none have yet been approved for human coronaviruses.
Intriguing new options are emerging, however.
Beta-D-N4-hydroxycytidine (NHC) is an orally bioavailable ribonucleotide analog showing broad-spectrum activity against RNA viruses, which may inhibit SARS-CoV-2 replication _in vitro_ and _in vivo_ in mouse models of HCoVs [@doi:10.1126/scitranslmed.abb5883].
A range of other antivirals are also in development.
Development of antivirals will be further facilitated as research reveals more information about the interaction of SARS-CoV-2 with the host cell and host cell genome, mechanisms of viral replication, mechanisms of viral assembly, and mechanisms of viral release to other cells; this can allow researchers to target specific stages and structures of the viral life cycle.
Many researchers have also focused their attention to the potential use of dietary supplements and nutraceuticals.
Indeed, there has been recent interest for the potential use of vitamin D as a prophylactic and therapeutic agent against COVID-19 as several observational studies have linked low vitamin D status to its incidence [@doi:10.1111/joim.13149; @doi:10.1001/jamanetworkopen.2020.19722]. 
These associations have yet to be confirmed and rigorous trials are required before considering supplementation recommendations.
However, the nutritional status and general health of a patient can affect their outcomes in various diseases, thus it would be pertinent to advise people to follow a healthy diet and life style to the best of their ability to prevent nutrient deficiencies and insufficiencies and to maintain a healthy immune system [@doi:10.1093/advances/nmaa125].
Finally, antibodies against viruses, also known as antiviral monoclonal antibodies, could be an alternative as well and are described in detail in an above section.
The goal of antiviral antibodies is to neutralize viruses through either cell-killing activity or blocking of viral replication [@doi:10.1016/j.tim.2015.07.005].
They may also engage the host immune response, encouraging the immune system to hone in on the virus.
Given the cytokine storm that results from immune system activation in response to the virus, which has been implicated in worsening of the disease, a neutralizing antibody (nAb) may be preferable.
Upcoming work may explore the specificity of nAbs for their target, mechanisms by which the nAbs impede the virus, and improvements to antibody structure that may enhance the ability of the antibody to block viral activity.

Some research is also investigating potential therapeutics and prophylactics that would interact with components of the innate immune response.
For example, there are a variety of TLRs, PRRs that recognize PAMPs and DAMPs.
TLRs form a part of innate immune recognition and can more generally contribute to promoting both innate and adaptive responses [@ISBN:9780815332183].
In mouse models, poly(I:C) and CpG, which are agonists of toll-like receptors TLR3 and TLR9, respectively, showed protective effects when administered prior to SARS-CoV-1 infection [@doi:10.1128/JVI.01410-12].
Therefore, TLR agonists hold some potential for broad-spectrum prophylaxis.

Given that a large number of clinical trials are currently in progress, more information about the potential of these and other therapeutics should become available over time.
This information, combined with advances in understanding the molecular structure and viral pathogenesis of SARS-CoV-2, may lead to a more complete understanding of how the virus affects the human host and what strategies can improve outcomes.
To date, investigations of potential therapeutics for COVID-19 have focused primarily on repurposing existing drugs.
This approach is necessary given the urgency of the situation as well as the extensive time required for developing and testing new therapies.
However, in the long-term, new drugs specific for treatment of COVID-19 may also enter development.
Development of novel drugs is likely to be guided by what is known about the pathogenesis and molecular structure of SARS-CoV-2.
For example, understanding the various structural components of SARS-CoV-2 may allow for the development of small molecule inhibitors of those components.
Currently, crystal structures of the SARS-CoV-2 main protease have recently been resolved [@doi:10.1038/s41586-020-2223-y; @url:https://www.diamond.ac.uk/covid-19/for-scientists/Main-protease-structure-and-XChem.html], and efforts are already in place to perform screens for small molecule inhibitors of the main protease, which have yielded potential hits [@doi:10.1038/s41586-020-2223-y].
Much work remains to be done to determine further crystal structures of other viral components, understand the relative utility of targeting different viral components, perform additional small molecule inhibitor screens, and determine the safety and efficacy of the potential inhibitors.
While still nascent, work in this area is promising.
Over the longer term, this approach and others may lead to the development of novel therapeutics specifically for COVID-19 and SARS-CoV-2.

